@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2019, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,49 +111,14 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
 #include "acpi.h"
 #include "accommon.h"
+#include "acapps.h"
 #include "actables.h"
 #include "acutils.h"
-#include "acapps.h"
+#include <errno.h>
 
 #define _COMPONENT          ACPI_UTILITIES
         ACPI_MODULE_NAME    ("acfileio")
@@ -173,36 +138,6 @@ AcCheckTextModeCorruption (
     ACPI_TABLE_HEADER       *Table);
 
 
-/*******************************************************************************
- *
- * FUNCTION:    AcDeleteTableList
- *
- * PARAMETERS:  ListHead            - List to delete
- *
- * RETURN:      Status
- *
- * DESCRIPTION: Delete a list of tables. This is useful for removing memory
- *              allocated by AcGetAllTablesFromFile
- *
- ******************************************************************************/
-
-void
-AcDeleteTableList (
-    ACPI_NEW_TABLE_DESC     *ListHead)
-{
-    ACPI_NEW_TABLE_DESC     *Current = ListHead;
-    ACPI_NEW_TABLE_DESC     *Previous = Current;
-
-
-    while (Current)
-    {
-        Current = Current->Next;
-        AcpiOsFree (Previous);
-        Previous = Current;
-    }
-}
-
-
 /*******************************************************************************
  *
  * FUNCTION:    AcGetAllTablesFromFile
@@ -235,7 +170,7 @@ AcGetAllTablesFromFile (
     File = fopen (Filename, "rb");
     if (!File)
     {
-        fprintf (stderr, "Could not open input file: %s\n", Filename);
+        perror ("Could not open input file");
         if (errno == ENOENT)
         {
             return (AE_NOT_EXIST);
@@ -249,8 +184,7 @@ AcGetAllTablesFromFile (
     FileSize = CmGetFileSize (File);
     if (FileSize == ACPI_UINT32_MAX)
     {
-        Status = AE_ERROR;
-        goto Exit;
+        return (AE_ERROR);
     }
 
     fprintf (stderr,
@@ -261,8 +195,7 @@ AcGetAllTablesFromFile (
 
     if (FileSize < sizeof (ACPI_TABLE_HEADER))
     {
-        Status = AE_BAD_HEADER;
-        goto Exit;
+        return (AE_BAD_HEADER);
     }
 
     /* Check for an non-binary file */
@@ -272,8 +205,7 @@ AcGetAllTablesFromFile (
         fprintf (stderr,
             "    %s: File does not appear to contain a valid AML table\n",
             Filename);
-        Status = AE_TYPE;
-        goto Exit;
+        return (AE_TYPE);
     }
 
     /* Read all tables within the file */
@@ -292,31 +224,23 @@ AcGetAllTablesFromFile (
         }
         else if (Status == AE_TYPE)
         {
-            Status = AE_OK;
-            goto Exit;
+            return (AE_OK);
         }
         else if (ACPI_FAILURE (Status))
         {
-            goto Exit;
+            return (Status);
         }
 
         /* Print table header for iASL/disassembler only */
 
 #ifdef ACPI_ASL_COMPILER
 
-        AcpiTbPrintTableHeader (0, Table);
+            AcpiTbPrintTableHeader (0, Table);
 #endif
 
         /* Allocate and link a table descriptor */
 
         TableDesc = AcpiOsAllocate (sizeof (ACPI_NEW_TABLE_DESC));
-        if (!TableDesc)
-        {
-            AcpiOsFree (Table);
-            Status = AE_NO_MEMORY;
-            goto Exit;
-        }
-
         TableDesc->Table = Table;
         TableDesc->Next = NULL;
 
@@ -351,7 +275,6 @@ AcGetAllTablesFromFile (
         *ReturnListHead = ListHead;
     }
 
-Exit:
     fclose(File);
     return (Status);
 }
@@ -401,21 +324,20 @@ AcGetOneTableFromFile (
         return (AE_CTRL_TERMINATE);
     }
 
+    /* Validate the table signature/header (limited ASCII chars) */
+
+    Status = AcValidateTableHeader (File, TableOffset);
+    if (ACPI_FAILURE (Status))
+    {
+        return (Status);
+    }
+
     if (GetOnlyAmlTables)
     {
-        /* Validate the table signature/header (limited ASCII chars) */
+        /* Table must be an AML table (DSDT/SSDT) or FADT */
 
-        Status = AcValidateTableHeader (File, TableOffset);
-        if (ACPI_FAILURE (Status))
-        {
-            return (Status);
-        }
-
-        /*
-         * Table must be an AML table (DSDT/SSDT).
-         * Used for iASL -e option only.
-         */
-        if (!AcpiUtIsAmlTable (&TableHeader))
+        if (!ACPI_COMPARE_NAME (TableHeader.Signature, ACPI_SIG_FADT) &&
+            !AcpiUtIsAmlTable (&TableHeader))
         {
             fprintf (stderr,
                 "    %s: Table [%4.4s] is not an AML table - ignoring\n",
@@ -427,7 +349,7 @@ AcGetOneTableFromFile (
 
     /* Allocate a buffer for the entire table */
 
-    Table = AcpiOsAllocate ((ACPI_SIZE) TableHeader.Length);
+    Table = AcpiOsAllocate ((size_t) TableHeader.Length);
     if (!Table)
     {
         return (AE_NO_MEMORY);
@@ -438,12 +360,7 @@ AcGetOneTableFromFile (
     fseek (File, TableOffset, SEEK_SET);
 
     Count = fread (Table, 1, TableHeader.Length, File);
-
-    /*
-     * Checks for data table headers happen later in the execution. Only verify
-     * for Aml tables at this point in the code.
-     */
-    if (GetOnlyAmlTables && Count != (INT32) TableHeader.Length)
+    if (Count != (INT32) TableHeader.Length)
     {
         Status = AE_ERROR;
         goto ErrorExit;
@@ -540,13 +457,13 @@ AcValidateTableHeader (
     long                    TableOffset)
 {
     ACPI_TABLE_HEADER       TableHeader;
-    ACPI_SIZE               Actual;
+    size_t                  Actual;
     long                    OriginalOffset;
     UINT32                  FileSize;
     UINT32                  i;
 
 
-    ACPI_FUNCTION_TRACE (AcValidateTableHeader);
+    ACPI_FUNCTION_TRACE ("AcValidateTableHeader");
 
 
     /* Read a potential table header */
@@ -564,8 +481,10 @@ AcValidateTableHeader (
 
     /* Validate the signature (limited ASCII chars) */
 
-    if (!AcpiUtValidNameseg (TableHeader.Signature))
+    if (!AcpiIsValidSignature (TableHeader.Signature))
     {
+        fprintf (stderr, "Invalid table signature: 0x%8.8X\n",
+            *ACPI_CAST_PTR (UINT32, TableHeader.Signature));
         return (AE_BAD_SIGNATURE);
     }
 
@@ -585,7 +504,7 @@ AcValidateTableHeader (
      * These fields must be ASCII: OemId, OemTableId, AslCompilerId.
      * We allow a NULL terminator in OemId and OemTableId.
      */
-    for (i = 0; i < ACPI_NAMESEG_SIZE; i++)
+    for (i = 0; i < ACPI_NAME_SIZE; i++)
     {
         if (!ACPI_IS_ASCII ((UINT8) TableHeader.AslCompilerId[i]))
         {
