@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -113,7 +113,6 @@
  *
  *****************************************************************************/
 
-
 #include "aslcompiler.h"
 #include "actables.h"
 #include "acdisasm.h"
@@ -161,6 +160,7 @@ AslInitializeGlobals (
 
     /* Init compiler globals */
 
+    Gbl_SyntaxError = 0;
     Gbl_CurrentColumn = 0;
     Gbl_CurrentLineNumber = 1;
     Gbl_LogicalLineNumber = 1;
@@ -216,62 +216,63 @@ AslDetectSourceFileType (
     ASL_FILE_INFO           *Info)
 {
     char                    *FileChar;
-    UINT8                   Type;
+    UINT8                   Type = ASL_INPUT_TYPE_ASCII_DATA; /* default */
     ACPI_STATUS             Status;
 
 
-    /* Check for a valid binary ACPI table */
+    /* Check for 100% ASCII source file (comments are ignored) */
 
-    Status = FlCheckForAcpiTable (Info->Handle);
+    Status = FlIsFileAsciiSource (Info->Filename, FALSE);
     if (ACPI_SUCCESS (Status))
     {
-        Type = ASL_INPUT_TYPE_ACPI_TABLE;
+        /*
+         * File contains ASCII source code. Determine if this is an ASL
+         * file or an ACPI data table file.
+         */
+        while (fgets (Gbl_CurrentLineBuffer, Gbl_LineBufferSize, Info->Handle))
+        {
+            /* Uppercase the buffer for caseless compare */
+
+            FileChar = Gbl_CurrentLineBuffer;
+            while (*FileChar)
+            {
+                *FileChar = (char) toupper ((int) *FileChar);
+                FileChar++;
+            }
+
+            /* Presence of "DefinitionBlock" indicates actual ASL code */
+
+            if (strstr (Gbl_CurrentLineBuffer, "DEFINITIONBLOCK"))
+            {
+                /* Appears to be an ASL file */
+
+                Type = ASL_INPUT_TYPE_ASCII_ASL;
+                goto Cleanup;
+            }
+        }
+
+        /* Appears to be an ASCII data table source file */
+
+        Type = ASL_INPUT_TYPE_ASCII_DATA;
         goto Cleanup;
     }
 
-    /* Check for 100% ASCII source file (comments are ignored) */
+    /* We have some sort of binary table, check for valid ACPI table */
 
-    Status = FlCheckForAscii (Info->Handle, Info->Filename, TRUE);
-    if (ACPI_FAILURE (Status))
+    fseek (Info->Handle, 0, SEEK_SET);
+
+    Status = AcValidateTableHeader (Info->Handle, 0);
+    if (ACPI_SUCCESS (Status))
     {
-        printf ("Non-ascii input file - %s\n", Info->Filename);
+        fprintf (stderr,
+            "Binary file appears to be a valid ACPI table, disassembling\n");
 
-        if (!Gbl_IgnoreErrors)
-        {
-            Type = ASL_INPUT_TYPE_BINARY;
-            goto Cleanup;
-        }
+        Type = ASL_INPUT_TYPE_BINARY_ACPI_TABLE;
+        goto Cleanup;
     }
 
-    /*
-     * File is ASCII. Determine if this is an ASL file or an ACPI data
-     * table file.
-     */
-    while (fgets (Gbl_CurrentLineBuffer, Gbl_LineBufferSize, Info->Handle))
-    {
-        /* Uppercase the buffer for caseless compare */
+    Type = ASL_INPUT_TYPE_BINARY;
 
-        FileChar = Gbl_CurrentLineBuffer;
-        while (*FileChar)
-        {
-            *FileChar = (char) toupper ((int) *FileChar);
-            FileChar++;
-        }
-
-        /* Presence of "DefinitionBlock" indicates actual ASL code */
-
-        if (strstr (Gbl_CurrentLineBuffer, "DEFINITIONBLOCK"))
-        {
-            /* Appears to be an ASL file */
-
-            Type = ASL_INPUT_TYPE_ASCII_ASL;
-            goto Cleanup;
-        }
-    }
-
-    /* Not an ASL source file, default to a data table source file */
-
-    Type = ASL_INPUT_TYPE_ASCII_DATA;
 
 Cleanup:
 
@@ -318,12 +319,17 @@ AslDoDisassembly (
         return (Status);
     }
 
+    /* Handle additional output files for disassembler */
+
+    Gbl_FileType = ASL_INPUT_TYPE_BINARY_ACPI_TABLE;
+    Status = FlOpenMiscOutputFiles (Gbl_OutputFilenamePrefix);
+
     /* This is where the disassembly happens */
 
-    AcpiGbl_DbOpt_disasm = TRUE;
+    AcpiGbl_DmOpt_Disasm = TRUE;
     Status = AdAmlDisassemble (AslToFile,
         Gbl_Files[ASL_FILE_INPUT].Filename, Gbl_OutputFilenamePrefix,
-        &Gbl_Files[ASL_FILE_INPUT].Filename, Gbl_GetAllTables);
+        &Gbl_Files[ASL_FILE_INPUT].Filename);
     if (ACPI_FAILURE (Status))
     {
         return (Status);
@@ -333,13 +339,6 @@ AslDoDisassembly (
 
     AcpiDmUnresolvedWarning (0);
 
-#if 0
-    /* TBD: Handle additional output files for disassembler */
-
-    Status = FlOpenMiscOutputFiles (Gbl_OutputFilenamePrefix);
-    NsDisplayNamespace ();
-#endif
-
     /* Shutdown compiler and ACPICA subsystem */
 
     AeClearErrorLog ();
@@ -356,8 +355,11 @@ AslDoDisassembly (
         return (AE_CTRL_CONTINUE);
     }
 
-    ACPI_FREE (Gbl_Files[ASL_FILE_INPUT].Filename);
+    /* No need to free the filename string */
+
     Gbl_Files[ASL_FILE_INPUT].Filename = NULL;
+
+    CmDeleteCaches ();
     return (AE_OK);
 }
 
@@ -397,13 +399,18 @@ AslDoOneFile (
         return (Status);
     }
 
-    Gbl_Files[ASL_FILE_INPUT].Filename = Filename;
-    UtConvertBackslashes (Filename);
+    /* Take a copy of the input filename, convert any backslashes */
+
+    Gbl_Files[ASL_FILE_INPUT].Filename =
+        UtStringCacheCalloc (strlen (Filename) + 1);
+
+    strcpy (Gbl_Files[ASL_FILE_INPUT].Filename, Filename);
+    UtConvertBackslashes (Gbl_Files[ASL_FILE_INPUT].Filename);
 
     /*
      * AML Disassembly (Optional)
      */
-    if (Gbl_DisasmFlag || Gbl_GetAllTables)
+    if (Gbl_DisasmFlag)
     {
         Status = AslDoDisassembly ();
         if (Status != AE_CTRL_CONTINUE)
@@ -423,6 +430,8 @@ AslDoOneFile (
         return (AE_ERROR);
     }
 
+    Gbl_OriginalInputFileSize = FlGetFileSize (ASL_FILE_INPUT);
+
     /* Determine input file type */
 
     Gbl_FileType = AslDetectSourceFileType (&Gbl_Files[ASL_FILE_INPUT]);
@@ -468,7 +477,6 @@ AslDoOneFile (
 
         if (Gbl_Signature)
         {
-            ACPI_FREE (Gbl_Signature);
             Gbl_Signature = NULL;
         }
 
@@ -519,7 +527,7 @@ AslDoOneFile (
     /*
      * Binary ACPI table was auto-detected, disassemble it
      */
-    case ASL_INPUT_TYPE_ACPI_TABLE:
+    case ASL_INPUT_TYPE_BINARY_ACPI_TABLE:
 
         /* We have what appears to be an ACPI table, disassemble it */
 
