@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2017, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,47 +111,12 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
 /* Compile all complex data tables, signatures starting with A-I */
 
 #include "aslcompiler.h"
+#include "dtcompiler.h"
 
 #define _COMPONENT          DT_COMPILER
         ACPI_MODULE_NAME    ("dttable1")
@@ -596,13 +561,7 @@ DtCompileDbg2 (
 
         Status = DtCompileTable (PFieldList, AcpiDmTableInfoDbg2OemData,
             &Subtable, TRUE);
-        if (Status == AE_END_OF_TABLE)
-        {
-            /* optional field was not found and we're at the end of the file */
-
-            goto subtableDone;
-        }
-        else if (ACPI_FAILURE (Status))
+        if (ACPI_FAILURE (Status))
         {
             return (Status);
         }
@@ -621,7 +580,7 @@ DtCompileDbg2 (
 
             DtInsertSubtable (ParentTable, Subtable);
         }
-subtableDone:
+
         SubtableCount--;
         DtPopSubtable (); /* Get next Device Information subtable */
     }
@@ -1254,16 +1213,6 @@ DtCompileHest (
             InfoTable = AcpiDmTableInfoHest9;
             break;
 
-        case ACPI_HEST_TYPE_GENERIC_ERROR_V2:
-
-            InfoTable = AcpiDmTableInfoHest10;
-            break;
-
-        case ACPI_HEST_TYPE_IA32_DEFERRED_CHECK:
-
-            InfoTable = AcpiDmTableInfoHest11;
-            break;
-
         default:
 
             /* Cannot continue on unknown type */
@@ -1298,12 +1247,6 @@ DtCompileHest (
                 Subtable->Buffer))->NumHardwareBanks;
             break;
 
-        case ACPI_HEST_TYPE_IA32_DEFERRED_CHECK:
-
-            BankCount = (ACPI_CAST_PTR (ACPI_HEST_IA_DEFERRED_CHECK,
-                Subtable->Buffer))->NumHardwareBanks;
-            break;
-
         default:
 
             break;
@@ -1327,218 +1270,6 @@ DtCompileHest (
 }
 
 
-/******************************************************************************
- *
- * FUNCTION:    DtCompileHmat
- *
- * PARAMETERS:  List                - Current field list pointer
- *
- * RETURN:      Status
- *
- * DESCRIPTION: Compile HMAT.
- *
- *****************************************************************************/
-
-ACPI_STATUS
-DtCompileHmat (
-    void                    **List)
-{
-    ACPI_STATUS             Status;
-    DT_SUBTABLE             *Subtable;
-    DT_SUBTABLE             *ParentTable;
-    DT_FIELD                **PFieldList = (DT_FIELD **) List;
-    DT_FIELD                *SubtableStart;
-    DT_FIELD                *EntryStart;
-    ACPI_HMAT_STRUCTURE     *HmatStruct;
-    ACPI_HMAT_LOCALITY      *HmatLocality;
-    ACPI_HMAT_CACHE         *HmatCache;
-    ACPI_DMTABLE_INFO       *InfoTable;
-    UINT32                  IntPDNumber;
-    UINT32                  TgtPDNumber;
-    UINT64                  EntryNumber;
-    UINT16                  SMBIOSHandleNumber;
-
-
-    ParentTable = DtPeekSubtable ();
-
-    Status = DtCompileTable (PFieldList, AcpiDmTableInfoHmat,
-        &Subtable, TRUE);
-    if (ACPI_FAILURE (Status))
-    {
-        return (Status);
-    }
-    DtInsertSubtable (ParentTable, Subtable);
-
-    while (*PFieldList)
-    {
-        /* Compile HMAT structure header */
-
-        SubtableStart = *PFieldList;
-        Status = DtCompileTable (PFieldList, AcpiDmTableInfoHmatHdr,
-            &Subtable, TRUE);
-        if (ACPI_FAILURE (Status))
-        {
-            return (Status);
-        }
-        DtInsertSubtable (ParentTable, Subtable);
-
-        HmatStruct = ACPI_CAST_PTR (ACPI_HMAT_STRUCTURE, Subtable->Buffer);
-        HmatStruct->Length = Subtable->Length;
-
-        /* Compile HMAT structure body */
-
-        switch (HmatStruct->Type)
-        {
-        case ACPI_HMAT_TYPE_ADDRESS_RANGE:
-
-            InfoTable = AcpiDmTableInfoHmat0;
-            break;
-
-        case ACPI_HMAT_TYPE_LOCALITY:
-
-            InfoTable = AcpiDmTableInfoHmat1;
-            break;
-
-        case ACPI_HMAT_TYPE_CACHE:
-
-            InfoTable = AcpiDmTableInfoHmat2;
-            break;
-
-        default:
-
-            DtFatal (ASL_MSG_UNKNOWN_SUBTABLE, SubtableStart, "HMAT");
-            return (AE_ERROR);
-        }
-
-        Status = DtCompileTable (PFieldList, InfoTable, &Subtable, TRUE);
-        if (ACPI_FAILURE (Status))
-        {
-            return (Status);
-        }
-        DtInsertSubtable (ParentTable, Subtable);
-        HmatStruct->Length += Subtable->Length;
-
-        /* Compile HMAT structure additionals */
-
-        switch (HmatStruct->Type)
-        {
-        case ACPI_HMAT_TYPE_LOCALITY:
-
-            HmatLocality = ACPI_SUB_PTR (ACPI_HMAT_LOCALITY,
-                Subtable->Buffer, sizeof (ACPI_HMAT_STRUCTURE));
-
-            /* Compile initiator proximity domain list */
-
-            IntPDNumber = 0;
-            while (*PFieldList)
-            {
-                Status = DtCompileTable (PFieldList,
-                    AcpiDmTableInfoHmat1a, &Subtable, TRUE);
-                if (ACPI_FAILURE (Status))
-                {
-                    return (Status);
-                }
-                if (!Subtable)
-                {
-                    break;
-                }
-                DtInsertSubtable (ParentTable, Subtable);
-                HmatStruct->Length += Subtable->Length;
-                IntPDNumber++;
-            }
-            HmatLocality->NumberOfInitiatorPDs = IntPDNumber;
-
-            /* Compile target proximity domain list */
-
-            TgtPDNumber = 0;
-            while (*PFieldList)
-            {
-                Status = DtCompileTable (PFieldList,
-                    AcpiDmTableInfoHmat1b, &Subtable, TRUE);
-                if (ACPI_FAILURE (Status))
-                {
-                    return (Status);
-                }
-                if (!Subtable)
-                {
-                    break;
-                }
-                DtInsertSubtable (ParentTable, Subtable);
-                HmatStruct->Length += Subtable->Length;
-                TgtPDNumber++;
-            }
-            HmatLocality->NumberOfTargetPDs = TgtPDNumber;
-
-            /* Save start of the entries for reporting errors */
-
-            EntryStart = *PFieldList;
-
-            /* Compile latency/bandwidth entries */
-
-            EntryNumber = 0;
-            while (*PFieldList)
-            {
-                Status = DtCompileTable (PFieldList,
-                    AcpiDmTableInfoHmat1c, &Subtable, TRUE);
-                if (ACPI_FAILURE (Status))
-                {
-                    return (Status);
-                }
-                if (!Subtable)
-                {
-                    break;
-                }
-                DtInsertSubtable (ParentTable, Subtable);
-                HmatStruct->Length += Subtable->Length;
-                EntryNumber++;
-            }
-
-            /* Validate number of entries */
-
-            if (EntryNumber !=
-                ((UINT64)IntPDNumber * (UINT64)TgtPDNumber))
-            {
-                DtFatal (ASL_MSG_INVALID_EXPRESSION, EntryStart, "HMAT");
-                return (AE_ERROR);
-            }
-            break;
-
-        case ACPI_HMAT_TYPE_CACHE:
-
-            /* Compile SMBIOS handles */
-
-            HmatCache = ACPI_SUB_PTR (ACPI_HMAT_CACHE,
-                Subtable->Buffer, sizeof (ACPI_HMAT_STRUCTURE));
-            SMBIOSHandleNumber = 0;
-            while (*PFieldList)
-            {
-                Status = DtCompileTable (PFieldList,
-                    AcpiDmTableInfoHmat2a, &Subtable, TRUE);
-                if (ACPI_FAILURE (Status))
-                {
-                    return (Status);
-                }
-                if (!Subtable)
-                {
-                    break;
-                }
-                DtInsertSubtable (ParentTable, Subtable);
-                HmatStruct->Length += Subtable->Length;
-                SMBIOSHandleNumber++;
-            }
-            HmatCache->NumberOfSMBIOSHandles = SMBIOSHandleNumber;
-            break;
-
-        default:
-
-            break;
-        }
-    }
-
-    return (AE_OK);
-}
-
-
 /******************************************************************************
  *
  * FUNCTION:    DtCompileIort
@@ -1584,8 +1315,8 @@ DtCompileIort (
     DtInsertSubtable (ParentTable, Subtable);
 
     /*
-     * Using ACPI_SUB_PTR, We needn't define a separate structure. Care
-     * should be taken to avoid accessing ACPI_TABLE_HEADER fields.
+     * Using ACPI_SUB_PTR, We needn't define a seperate structure. Care
+     * should be taken to avoid accessing ACPI_TABLE_HADER fields.
      */
     Iort = ACPI_SUB_PTR (ACPI_TABLE_IORT,
         Subtable->Buffer, sizeof (ACPI_TABLE_HEADER));
@@ -1816,19 +1547,6 @@ DtCompileIort (
             IortSmmu->PmuInterruptCount = PmuIrptNumber;
             break;
 
-        case ACPI_IORT_NODE_SMMU_V3:
-
-            Status = DtCompileTable (PFieldList, AcpiDmTableInfoIort4,
-                &Subtable, TRUE);
-            if (ACPI_FAILURE (Status))
-            {
-                return (Status);
-            }
-
-            DtInsertSubtable (ParentTable, Subtable);
-            NodeLength += Subtable->Length;
-            break;
-
         default:
 
             DtFatal (ASL_MSG_UNKNOWN_SUBTABLE, SubtableStart, "IORT");
@@ -1859,10 +1577,6 @@ DtCompileIort (
         }
 
         IortNode->MappingCount = IdMappingNumber;
-        if (!IdMappingNumber)
-        {
-            IortNode->MappingOffset = 0;
-        }
 
         /*
          * Node length can be determined by DT_LENGTH option
