@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2019, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,47 +111,12 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
 /* Compile all complex data tables, signatures starting with L-Z */
 
 #include "aslcompiler.h"
+#include "dtcompiler.h"
 
 #define _COMPONENT          DT_COMPILER
         ACPI_MODULE_NAME    ("dttable2")
@@ -191,7 +156,7 @@ DtCompileLpit (
         /* LPIT Subtable header */
 
         Status = DtCompileTable (PFieldList, AcpiDmTableInfoLpitHdr,
-            &Subtable);
+            &Subtable, TRUE);
         if (ACPI_FAILURE (Status))
         {
             return (Status);
@@ -218,7 +183,7 @@ DtCompileLpit (
 
         /* LPIT Subtable */
 
-        Status = DtCompileTable (PFieldList, InfoTable, &Subtable);
+        Status = DtCompileTable (PFieldList, InfoTable, &Subtable, TRUE);
         if (ACPI_FAILURE (Status))
         {
             return (Status);
@@ -259,7 +224,7 @@ DtCompileMadt (
 
 
     Status = DtCompileTable (PFieldList, AcpiDmTableInfoMadt,
-        &Subtable);
+        &Subtable, TRUE);
     if (ACPI_FAILURE (Status))
     {
         return (Status);
@@ -272,7 +237,7 @@ DtCompileMadt (
     {
         SubtableStart = *PFieldList;
         Status = DtCompileTable (PFieldList, AcpiDmTableInfoMadtHdr,
-            &Subtable);
+            &Subtable, TRUE);
         if (ACPI_FAILURE (Status))
         {
             return (Status);
@@ -372,7 +337,7 @@ DtCompileMadt (
             return (AE_ERROR);
         }
 
-        Status = DtCompileTable (PFieldList, InfoTable, &Subtable);
+        Status = DtCompileTable (PFieldList, InfoTable, &Subtable, TRUE);
         if (ACPI_FAILURE (Status))
         {
             return (Status);
@@ -442,7 +407,7 @@ DtCompileMpst (
 
     /* Main table */
 
-    Status = DtCompileTable (PFieldList, AcpiDmTableInfoMpst, &Subtable);
+    Status = DtCompileTable (PFieldList, AcpiDmTableInfoMpst, &Subtable, TRUE);
     if (ACPI_FAILURE (Status))
     {
         return (Status);
@@ -460,7 +425,7 @@ DtCompileMpst (
         /* Subtable: Memory Power Node(s) */
 
         Status = DtCompileTable (PFieldList, AcpiDmTableInfoMpst0,
-            &Subtable);
+            &Subtable, TRUE);
         if (ACPI_FAILURE (Status))
         {
             return (Status);
@@ -481,7 +446,7 @@ DtCompileMpst (
         while (*PFieldList && PowerStateCount)
         {
             Status = DtCompileTable (PFieldList, AcpiDmTableInfoMpst0A,
-                &Subtable);
+                &Subtable, TRUE);
             if (ACPI_FAILURE (Status))
             {
                 return (Status);
@@ -496,7 +461,7 @@ DtCompileMpst (
         while (*PFieldList && ComponentCount)
         {
             Status = DtCompileTable (PFieldList, AcpiDmTableInfoMpst0B,
-                &Subtable);
+                &Subtable, TRUE);
             if (ACPI_FAILURE (Status))
             {
                 return (Status);
@@ -514,7 +479,7 @@ DtCompileMpst (
 
     DtPopSubtable ();
 
-    Status = DtCompileTable (PFieldList, AcpiDmTableInfoMpst1, &Subtable);
+    Status = DtCompileTable (PFieldList, AcpiDmTableInfoMpst1, &Subtable, TRUE);
     if (ACPI_FAILURE (Status))
     {
         return (Status);
@@ -534,7 +499,7 @@ DtCompileMpst (
     while (*PFieldList && SubtableCount)
     {
         Status = DtCompileTable (PFieldList, AcpiDmTableInfoMpst2,
-            &Subtable);
+            &Subtable, TRUE);
         if (ACPI_FAILURE (Status))
         {
             return (Status);
@@ -630,7 +595,7 @@ DtCompileNfit (
     /* Main table */
 
     Status = DtCompileTable (PFieldList, AcpiDmTableInfoNfit,
-        &Subtable);
+        &Subtable, TRUE);
     if (ACPI_FAILURE (Status))
     {
         return (Status);
@@ -646,7 +611,7 @@ DtCompileNfit (
     {
         SubtableStart = *PFieldList;
         Status = DtCompileTable (PFieldList, AcpiDmTableInfoNfitHdr,
-            &Subtable);
+            &Subtable, TRUE);
         if (ACPI_FAILURE (Status))
         {
             return (Status);
@@ -697,18 +662,13 @@ DtCompileNfit (
             InfoTable = AcpiDmTableInfoNfit6;
             break;
 
-        case ACPI_NFIT_TYPE_CAPABILITIES:
-
-            InfoTable = AcpiDmTableInfoNfit7;
-            break;
-
         default:
 
             DtFatal (ASL_MSG_UNKNOWN_SUBTABLE, SubtableStart, "NFIT");
             return (AE_ERROR);
         }
 
-        Status = DtCompileTable (PFieldList, InfoTable, &Subtable);
+        Status = DtCompileTable (PFieldList, InfoTable, &Subtable, TRUE);
         if (ACPI_FAILURE (Status))
         {
             return (Status);
@@ -727,7 +687,7 @@ DtCompileNfit (
             while (*PFieldList)
             {
                 Status = DtCompileTable (PFieldList, AcpiDmTableInfoNfit2a,
-                    &Subtable);
+                    &Subtable, FALSE);
                 if (ACPI_FAILURE (Status))
                 {
                     return (Status);
@@ -745,6 +705,7 @@ DtCompileNfit (
             }
 
             Interleave->LineCount = Count;
+            DtPopSubtable ();
             break;
 
         case ACPI_NFIT_TYPE_SMBIOS:
@@ -752,7 +713,7 @@ DtCompileNfit (
             if (*PFieldList)
             {
                 Status = DtCompileTable (PFieldList, AcpiDmTableInfoNfit3a,
-                    &Subtable);
+                    &Subtable, TRUE);
                 if (ACPI_FAILURE (Status))
                 {
                     return (Status);
@@ -772,7 +733,7 @@ DtCompileNfit (
             while (*PFieldList)
             {
                 Status = DtCompileTable (PFieldList, AcpiDmTableInfoNfit6a,
-                    &Subtable);
+                    &Subtable, FALSE);
                 if (ACPI_FAILURE (Status))
                 {
                     return (Status);
@@ -790,6 +751,7 @@ DtCompileNfit (
             }
 
             Hint->HintCount = (UINT16) Count;
+            DtPopSubtable ();
             break;
 
         default:
@@ -829,7 +791,7 @@ DtCompilePcct (
     /* Main table */
 
     Status = DtCompileTable (PFieldList, AcpiDmTableInfoPcct,
-        &Subtable);
+        &Subtable, TRUE);
     if (ACPI_FAILURE (Status))
     {
         return (Status);
@@ -844,7 +806,7 @@ DtCompilePcct (
     {
         SubtableStart = *PFieldList;
         Status = DtCompileTable (PFieldList, AcpiDmTableInfoPcctHdr,
-            &Subtable);
+            &Subtable, TRUE);
         if (ACPI_FAILURE (Status))
         {
             return (Status);
@@ -868,28 +830,13 @@ DtCompilePcct (
             InfoTable = AcpiDmTableInfoPcct1;
             break;
 
-        case ACPI_PCCT_TYPE_HW_REDUCED_SUBSPACE_TYPE2:
-
-            InfoTable = AcpiDmTableInfoPcct2;
-            break;
-
-        case ACPI_PCCT_TYPE_EXT_PCC_MASTER_SUBSPACE:
-
-            InfoTable = AcpiDmTableInfoPcct3;
-            break;
-
-        case ACPI_PCCT_TYPE_EXT_PCC_SLAVE_SUBSPACE:
-
-            InfoTable = AcpiDmTableInfoPcct4;
-            break;
-
         default:
 
             DtFatal (ASL_MSG_UNKNOWN_SUBTABLE, SubtableStart, "PCCT");
             return (AE_ERROR);
         }
 
-        Status = DtCompileTable (PFieldList, InfoTable, &Subtable);
+        Status = DtCompileTable (PFieldList, InfoTable, &Subtable, TRUE);
         if (ACPI_FAILURE (Status))
         {
             return (Status);
@@ -904,66 +851,6 @@ DtCompilePcct (
 }
 
 
-/******************************************************************************
- *
- * FUNCTION:    DtCompilePdtt
- *
- * PARAMETERS:  List                - Current field list pointer
- *
- * RETURN:      Status
- *
- * DESCRIPTION: Compile PDTT.
- *
- *****************************************************************************/
-
-ACPI_STATUS
-DtCompilePdtt (
-    void                    **List)
-{
-    ACPI_STATUS             Status;
-    DT_SUBTABLE             *Subtable;
-    DT_SUBTABLE             *ParentTable;
-    DT_FIELD                **PFieldList = (DT_FIELD **) List;
-    ACPI_TABLE_PDTT         *PdttHeader;
-    UINT32                  Count = 0;
-
-
-    /* Main table */
-
-    Status = DtCompileTable (PFieldList, AcpiDmTableInfoPdtt, &Subtable);
-    if (ACPI_FAILURE (Status))
-    {
-        return (Status);
-    }
-
-    ParentTable = DtPeekSubtable ();
-    DtInsertSubtable (ParentTable, Subtable);
-
-    PdttHeader = ACPI_CAST_PTR (ACPI_TABLE_PDTT, ParentTable->Buffer);
-    PdttHeader->ArrayOffset = sizeof (ACPI_TABLE_PDTT);
-
-    /* There is only one type of subtable at this time, no need to decode */
-
-    while (*PFieldList)
-    {
-        /* List of subchannel IDs, each 2 bytes */
-
-        Status = DtCompileTable (PFieldList, AcpiDmTableInfoPdtt0,
-            &Subtable);
-        if (ACPI_FAILURE (Status))
-        {
-            return (Status);
-        }
-
-        DtInsertSubtable (ParentTable, Subtable);
-        Count++;
-    }
-
-    PdttHeader->TriggerCount = (UINT8) Count;
-    return (AE_OK);
-}
-
-
 /******************************************************************************
  *
  * FUNCTION:    DtCompilePmtt
@@ -993,7 +880,7 @@ DtCompilePmtt (
 
     /* Main table */
 
-    Status = DtCompileTable (PFieldList, AcpiDmTableInfoPmtt, &Subtable);
+    Status = DtCompileTable (PFieldList, AcpiDmTableInfoPmtt, &Subtable, TRUE);
     if (ACPI_FAILURE (Status))
     {
         return (Status);
@@ -1007,7 +894,7 @@ DtCompilePmtt (
     {
         SubtableStart = *PFieldList;
         Status = DtCompileTable (PFieldList, AcpiDmTableInfoPmttHdr,
-            &Subtable);
+            &Subtable, TRUE);
         if (ACPI_FAILURE (Status))
         {
             return (Status);
@@ -1039,7 +926,7 @@ DtCompilePmtt (
             /* Subtable: Socket Structure */
 
             Status = DtCompileTable (PFieldList, AcpiDmTableInfoPmtt0,
-                &Subtable);
+                &Subtable, TRUE);
             if (ACPI_FAILURE (Status))
             {
                 return (Status);
@@ -1054,7 +941,7 @@ DtCompilePmtt (
             /* Subtable: Memory Controller Structure */
 
             Status = DtCompileTable (PFieldList, AcpiDmTableInfoPmtt1,
-                &Subtable);
+                &Subtable, TRUE);
             if (ACPI_FAILURE (Status))
             {
                 return (Status);
@@ -1070,7 +957,7 @@ DtCompilePmtt (
             while (DomainCount)
             {
                 Status = DtCompileTable (PFieldList, AcpiDmTableInfoPmtt1a,
-                    &Subtable);
+                    &Subtable, TRUE);
                 if (ACPI_FAILURE (Status))
                 {
                     return (Status);
@@ -1086,7 +973,7 @@ DtCompilePmtt (
             /* Subtable: Physical Component Structure */
 
             Status = DtCompileTable (PFieldList, AcpiDmTableInfoPmtt2,
-                &Subtable);
+                &Subtable, TRUE);
             if (ACPI_FAILURE (Status))
             {
                 return (Status);
@@ -1107,125 +994,6 @@ DtCompilePmtt (
 }
 
 
-/******************************************************************************
- *
- * FUNCTION:    DtCompilePptt
- *
- * PARAMETERS:  List                - Current field list pointer
- *
- * RETURN:      Status
- *
- * DESCRIPTION: Compile PPTT.
- *
- *****************************************************************************/
-
-ACPI_STATUS
-DtCompilePptt (
-    void                    **List)
-{
-    ACPI_STATUS             Status;
-    ACPI_SUBTABLE_HEADER    *PpttHeader;
-    ACPI_PPTT_PROCESSOR     *PpttProcessor = NULL;
-    DT_SUBTABLE             *Subtable;
-    DT_SUBTABLE             *ParentTable;
-    ACPI_DMTABLE_INFO       *InfoTable;
-    DT_FIELD                **PFieldList = (DT_FIELD **) List;
-    DT_FIELD                *SubtableStart;
-
-
-    ParentTable = DtPeekSubtable ();
-    while (*PFieldList)
-    {
-        SubtableStart = *PFieldList;
-
-        /* Compile PPTT subtable header */
-
-        Status = DtCompileTable (PFieldList, AcpiDmTableInfoPpttHdr,
-            &Subtable);
-        if (ACPI_FAILURE (Status))
-        {
-            return (Status);
-        }
-        DtInsertSubtable (ParentTable, Subtable);
-        PpttHeader = ACPI_CAST_PTR (ACPI_SUBTABLE_HEADER, Subtable->Buffer);
-        PpttHeader->Length = (UINT8)(Subtable->Length);
-
-        switch (PpttHeader->Type)
-        {
-        case ACPI_PPTT_TYPE_PROCESSOR:
-
-            InfoTable = AcpiDmTableInfoPptt0;
-            break;
-
-        case ACPI_PPTT_TYPE_CACHE:
-
-            InfoTable = AcpiDmTableInfoPptt1;
-            break;
-
-        case ACPI_PPTT_TYPE_ID:
-
-            InfoTable = AcpiDmTableInfoPptt2;
-            break;
-
-        default:
-
-            DtFatal (ASL_MSG_UNKNOWN_SUBTABLE, SubtableStart, "PPTT");
-            return (AE_ERROR);
-        }
-
-        /* Compile PPTT subtable body */
-
-        Status = DtCompileTable (PFieldList, InfoTable, &Subtable);
-        if (ACPI_FAILURE (Status))
-        {
-            return (Status);
-        }
-        DtInsertSubtable (ParentTable, Subtable);
-        PpttHeader->Length += (UINT8)(Subtable->Length);
-
-        /* Compile PPTT subtable additionals */
-
-        switch (PpttHeader->Type)
-        {
-        case ACPI_PPTT_TYPE_PROCESSOR:
-
-            PpttProcessor = ACPI_SUB_PTR (ACPI_PPTT_PROCESSOR,
-                Subtable->Buffer, sizeof (ACPI_SUBTABLE_HEADER));
-            if (PpttProcessor)
-            {
-                /* Compile initiator proximity domain list */
-
-                PpttProcessor->NumberOfPrivResources = 0;
-                while (*PFieldList)
-                {
-                    Status = DtCompileTable (PFieldList,
-                        AcpiDmTableInfoPptt0a, &Subtable);
-                    if (ACPI_FAILURE (Status))
-                    {
-                        return (Status);
-                    }
-                    if (!Subtable)
-                    {
-                        break;
-                    }
-
-                    DtInsertSubtable (ParentTable, Subtable);
-                    PpttHeader->Length += (UINT8)(Subtable->Length);
-                    PpttProcessor->NumberOfPrivResources++;
-                }
-            }
-            break;
-
-        default:
-
-            break;
-        }
-    }
-
-    return (AE_OK);
-}
-
-
 /******************************************************************************
  *
  * FUNCTION:    DtCompileRsdt
@@ -1280,7 +1048,7 @@ DtCompileS3pt (
     DT_FIELD                **PFieldList)
 {
     ACPI_STATUS             Status;
-    ACPI_FPDT_HEADER        *S3ptHeader;
+    ACPI_S3PT_HEADER        *S3ptHeader;
     DT_SUBTABLE             *Subtable;
     DT_SUBTABLE             *ParentTable;
     ACPI_DMTABLE_INFO       *InfoTable;
@@ -1288,19 +1056,19 @@ DtCompileS3pt (
 
 
     Status = DtCompileTable (PFieldList, AcpiDmTableInfoS3pt,
-        &AslGbl_RootTable);
+        &Gbl_RootTable, TRUE);
     if (ACPI_FAILURE (Status))
     {
         return (Status);
     }
 
-    DtPushSubtable (AslGbl_RootTable);
+    DtPushSubtable (Gbl_RootTable);
 
     while (*PFieldList)
     {
         SubtableStart = *PFieldList;
         Status = DtCompileTable (PFieldList, AcpiDmTableInfoS3ptHdr,
-            &Subtable);
+            &Subtable, TRUE);
         if (ACPI_FAILURE (Status))
         {
             return (Status);
@@ -1310,7 +1078,7 @@ DtCompileS3pt (
         DtInsertSubtable (ParentTable, Subtable);
         DtPushSubtable (Subtable);
 
-        S3ptHeader = ACPI_CAST_PTR (ACPI_FPDT_HEADER, Subtable->Buffer);
+        S3ptHeader = ACPI_CAST_PTR (ACPI_S3PT_HEADER, Subtable->Buffer);
 
         switch (S3ptHeader->Type)
         {
@@ -1330,7 +1098,7 @@ DtCompileS3pt (
             return (AE_ERROR);
         }
 
-        Status = DtCompileTable (PFieldList, InfoTable, &Subtable);
+        Status = DtCompileTable (PFieldList, InfoTable, &Subtable, TRUE);
         if (ACPI_FAILURE (Status))
         {
             return (Status);
@@ -1345,220 +1113,6 @@ DtCompileS3pt (
 }
 
 
-/******************************************************************************
- *
- * FUNCTION:    DtCompileSdev
- *
- * PARAMETERS:  List                - Current field list pointer
- *
- * RETURN:      Status
- *
- * DESCRIPTION: Compile SDEV.
- *
- *****************************************************************************/
-
-ACPI_STATUS
-DtCompileSdev (
-    void                    **List)
-{
-    ACPI_STATUS             Status;
-    ACPI_SDEV_HEADER        *SdevHeader;
-    DT_SUBTABLE             *Subtable;
-    DT_SUBTABLE             *ParentTable;
-    ACPI_DMTABLE_INFO       *InfoTable;
-    DT_FIELD                **PFieldList = (DT_FIELD **) List;
-    DT_FIELD                *SubtableStart;
-    ACPI_SDEV_PCIE          *Pcie = NULL;
-    ACPI_SDEV_NAMESPACE     *Namesp = NULL;
-    UINT32                  EntryCount;
-
-
-    /* Subtables */
-
-    while (*PFieldList)
-    {
-        /* Compile common SDEV subtable header */
-
-        SubtableStart = *PFieldList;
-        Status = DtCompileTable (PFieldList, AcpiDmTableInfoSdevHdr,
-            &Subtable);
-        if (ACPI_FAILURE (Status))
-        {
-            return (Status);
-        }
-
-        ParentTable = DtPeekSubtable ();
-        DtInsertSubtable (ParentTable, Subtable);
-        DtPushSubtable (Subtable);
-
-        SdevHeader = ACPI_CAST_PTR (ACPI_SDEV_HEADER, Subtable->Buffer);
-        SdevHeader->Length = (UINT8)(sizeof (ACPI_SDEV_HEADER));
-
-        switch (SdevHeader->Type)
-        {
-        case ACPI_SDEV_TYPE_NAMESPACE_DEVICE:
-
-            InfoTable = AcpiDmTableInfoSdev0;
-            Namesp = ACPI_CAST_PTR (ACPI_SDEV_NAMESPACE, Subtable->Buffer);
-            break;
-
-        case ACPI_SDEV_TYPE_PCIE_ENDPOINT_DEVICE:
-
-            InfoTable = AcpiDmTableInfoSdev1;
-            Pcie = ACPI_CAST_PTR (ACPI_SDEV_PCIE, Subtable->Buffer);
-            break;
-
-        default:
-
-            DtFatal (ASL_MSG_UNKNOWN_SUBTABLE, SubtableStart, "SDEV");
-            return (AE_ERROR);
-        }
-
-        /* Compile SDEV subtable body */
-
-        Status = DtCompileTable (PFieldList, InfoTable, &Subtable);
-        if (ACPI_FAILURE (Status))
-        {
-            return (Status);
-        }
-
-        ParentTable = DtPeekSubtable ();
-        DtInsertSubtable (ParentTable, Subtable);
-
-        /* Optional data fields are appended to the main subtable body */
-
-        switch (SdevHeader->Type)
-        {
-        case ACPI_SDEV_TYPE_NAMESPACE_DEVICE:
-
-            /* Append DeviceId namespace string */
-
-            Status = DtCompileTable (PFieldList, AcpiDmTableInfoSdev0a,
-                &Subtable);
-            if (ACPI_FAILURE (Status))
-            {
-                return (Status);
-            }
-
-            if (!Subtable)
-            {
-                break;
-            }
-
-            ParentTable = DtPeekSubtable ();
-            DtInsertSubtable (ParentTable, Subtable);
-
-            Namesp->DeviceIdOffset = sizeof (ACPI_SDEV_NAMESPACE);
-            Namesp->DeviceIdLength = (UINT16) Subtable->Length;
-
-            /* Append Vendor data */
-
-            Namesp->VendorDataLength = 0;
-            Namesp->VendorDataOffset = 0;
-
-            if (*PFieldList)
-            {
-                Status = DtCompileTable (PFieldList, AcpiDmTableInfoSdev1b,
-                    &Subtable);
-                if (ACPI_FAILURE (Status))
-                {
-                    return (Status);
-                }
-
-                if (Subtable)
-                {
-                    ParentTable = DtPeekSubtable ();
-                    DtInsertSubtable (ParentTable, Subtable);
-
-                    Namesp->VendorDataOffset =
-                        Namesp->DeviceIdOffset + Namesp->DeviceIdLength;
-                    Namesp->VendorDataLength =
-                        (UINT16) Subtable->Length;
-
-                    /* Final size of entire namespace structure */
-
-                    SdevHeader->Length = (UINT16)(sizeof(ACPI_SDEV_NAMESPACE) +
-                        Subtable->Length + Namesp->DeviceIdLength);
-                }
-            }
-
-            break;
-
-        case ACPI_SDEV_TYPE_PCIE_ENDPOINT_DEVICE:
-
-            /* Append the PCIe path info first */
-
-            EntryCount = 0;
-            while (*PFieldList && !strcmp ((*PFieldList)->Name, "Device"))
-            {
-                Status = DtCompileTable (PFieldList, AcpiDmTableInfoSdev1a,
-                    &Subtable);
-                if (ACPI_FAILURE (Status))
-                {
-                    return (Status);
-                }
-
-                if (!Subtable)
-                {
-                    DtPopSubtable ();
-                    break;
-                }
-
-                ParentTable = DtPeekSubtable ();
-                DtInsertSubtable (ParentTable, Subtable);
-                EntryCount++;
-            }
-
-            /* Path offset will point immediately after the main subtable */
-
-            Pcie->PathOffset = sizeof (ACPI_SDEV_PCIE);
-            Pcie->PathLength = (UINT16)
-                (EntryCount * sizeof (ACPI_SDEV_PCIE_PATH));
-
-            /* Append the Vendor Data last */
-
-            Pcie->VendorDataLength = 0;
-            Pcie->VendorDataOffset = 0;
-
-            if (*PFieldList)
-            {
-                Status = DtCompileTable (PFieldList, AcpiDmTableInfoSdev1b,
-                    &Subtable);
-                if (ACPI_FAILURE (Status))
-                {
-                    return (Status);
-                }
-
-                if (Subtable)
-                {
-                    ParentTable = DtPeekSubtable ();
-                    DtInsertSubtable (ParentTable, Subtable);
-
-                    Pcie->VendorDataOffset =
-                        Pcie->PathOffset + Pcie->PathLength;
-                    Pcie->VendorDataLength = (UINT16)
-                        Subtable->Length;
-                }
-            }
-
-            SdevHeader->Length =
-                sizeof (ACPI_SDEV_PCIE) +
-                Pcie->PathLength + Pcie->VendorDataLength;
-            break;
-
-        default:
-
-            DtFatal (ASL_MSG_UNKNOWN_SUBTABLE, SubtableStart, "SDEV");
-            return (AE_ERROR);
-        }
-
-        DtPopSubtable ();
-    }
-
-    return (AE_OK);
-}
-
-
 /******************************************************************************
  *
  * FUNCTION:    DtCompileSlic
@@ -1584,7 +1138,7 @@ DtCompileSlic (
     while (*PFieldList)
     {
         Status = DtCompileTable (PFieldList, AcpiDmTableInfoSlic,
-            &Subtable);
+            &Subtable, TRUE);
         if (ACPI_FAILURE (Status))
         {
             return (Status);
@@ -1621,14 +1175,12 @@ DtCompileSlit (
     DT_SUBTABLE             *ParentTable;
     DT_FIELD                **PFieldList = (DT_FIELD **) List;
     DT_FIELD                *FieldList;
-    DT_FIELD                *EndOfFieldList = NULL;
     UINT32                  Localities;
-    UINT32                  LocalityListLength;
     UINT8                   *LocalityBuffer;
 
 
     Status = DtCompileTable (PFieldList, AcpiDmTableInfoSlit,
-        &Subtable);
+        &Subtable, TRUE);
     if (ACPI_FAILURE (Status))
     {
         return (Status);
@@ -1639,7 +1191,6 @@ DtCompileSlit (
 
     Localities = *ACPI_CAST_PTR (UINT32, Subtable->Buffer);
     LocalityBuffer = UtLocalCalloc (Localities);
-    LocalityListLength = 0;
 
     /* Compile each locality buffer */
 
@@ -1649,23 +1200,11 @@ DtCompileSlit (
         DtCompileBuffer (LocalityBuffer,
             FieldList->Value, FieldList, Localities);
 
-        LocalityListLength++;
         DtCreateSubtable (LocalityBuffer, Localities, &Subtable);
         DtInsertSubtable (ParentTable, Subtable);
-        EndOfFieldList = FieldList;
         FieldList = FieldList->Next;
     }
 
-    if (LocalityListLength != Localities)
-    {
-        sprintf(AslGbl_MsgBuffer,
-            "Found %u entries, must match LocalityCount: %u",
-            LocalityListLength, Localities);
-        DtError (ASL_ERROR, ASL_MSG_ENTRY_LIST, EndOfFieldList, AslGbl_MsgBuffer);
-        ACPI_FREE (LocalityBuffer);
-        return (AE_LIMIT);
-    }
-
     ACPI_FREE (LocalityBuffer);
     return (AE_OK);
 }
@@ -1697,7 +1236,7 @@ DtCompileSrat (
 
 
     Status = DtCompileTable (PFieldList, AcpiDmTableInfoSrat,
-        &Subtable);
+        &Subtable, TRUE);
     if (ACPI_FAILURE (Status))
     {
         return (Status);
@@ -1710,7 +1249,7 @@ DtCompileSrat (
     {
         SubtableStart = *PFieldList;
         Status = DtCompileTable (PFieldList, AcpiDmTableInfoSratHdr,
-            &Subtable);
+            &Subtable, TRUE);
         if (ACPI_FAILURE (Status))
         {
             return (Status);
@@ -1744,23 +1283,13 @@ DtCompileSrat (
             InfoTable = AcpiDmTableInfoSrat3;
             break;
 
-        case ACPI_SRAT_TYPE_GIC_ITS_AFFINITY:
-
-            InfoTable = AcpiDmTableInfoSrat4;
-            break;
-
-        case ACPI_SRAT_TYPE_GENERIC_AFFINITY:
-
-            InfoTable = AcpiDmTableInfoSrat5;
-            break;
-
         default:
 
             DtFatal (ASL_MSG_UNKNOWN_SUBTABLE, SubtableStart, "SRAT");
             return (AE_ERROR);
         }
 
-        Status = DtCompileTable (PFieldList, InfoTable, &Subtable);
+        Status = DtCompileTable (PFieldList, InfoTable, &Subtable, TRUE);
         if (ACPI_FAILURE (Status))
         {
             return (Status);
@@ -1800,7 +1329,7 @@ DtCompileStao (
     /* Compile the main table */
 
     Status = DtCompileTable (PFieldList, AcpiDmTableInfoStao,
-        &Subtable);
+        &Subtable, TRUE);
     if (ACPI_FAILURE (Status))
     {
         return (Status);
@@ -1814,7 +1343,7 @@ DtCompileStao (
     while (*PFieldList)
     {
         Status = DtCompileTable (PFieldList, AcpiDmTableInfoStaoStr,
-            &Subtable);
+            &Subtable, TRUE);
         if (ACPI_FAILURE (Status))
         {
             return (Status);
@@ -1854,7 +1383,7 @@ DtCompileTcpa (
     /* Compile the main table */
 
     Status = DtCompileTable (PFieldList, AcpiDmTableInfoTcpaHdr,
-        &Subtable);
+        &Subtable, TRUE);
     if (ACPI_FAILURE (Status))
     {
         return (Status);
@@ -1874,13 +1403,13 @@ DtCompileTcpa (
     case ACPI_TCPA_CLIENT_TABLE:
 
         Status = DtCompileTable (PFieldList, AcpiDmTableInfoTcpaClient,
-            &Subtable);
+            &Subtable, TRUE);
         break;
 
     case ACPI_TCPA_SERVER_TABLE:
 
         Status = DtCompileTable (PFieldList, AcpiDmTableInfoTcpaServer,
-            &Subtable);
+            &Subtable, TRUE);
         break;
 
     default:
@@ -1897,175 +1426,6 @@ DtCompileTcpa (
 }
 
 
-/******************************************************************************
- *
- * FUNCTION:    DtCompileTpm2Rev3
- *
- * PARAMETERS:  PFieldList          - Current field list pointer
- *
- * RETURN:      Status
- *
- * DESCRIPTION: Compile TPM2 revision 3
- *
- *****************************************************************************/
-static ACPI_STATUS
-DtCompileTpm2Rev3 (
-    void                    **List)
-{
-    DT_FIELD                **PFieldList = (DT_FIELD **) List;
-    DT_SUBTABLE             *Subtable;
-    ACPI_TABLE_TPM23        *Tpm23Header;
-    DT_SUBTABLE             *ParentTable;
-    ACPI_STATUS             Status = AE_OK;
-
-
-    Status = DtCompileTable (PFieldList, AcpiDmTableInfoTpm23,
-        &Subtable);
-
-    ParentTable = DtPeekSubtable ();
-    DtInsertSubtable (ParentTable, Subtable);
-    Tpm23Header = ACPI_CAST_PTR (ACPI_TABLE_TPM23, ParentTable->Buffer);
-
-    /* Subtable type depends on the StartMethod */
-
-    switch (Tpm23Header->StartMethod)
-    {
-    case ACPI_TPM23_ACPI_START_METHOD:
-
-        /* Subtable specific to to ARM_SMC */
-
-        Status = DtCompileTable (PFieldList, AcpiDmTableInfoTpm23a,
-            &Subtable);
-        if (ACPI_FAILURE (Status))
-        {
-            return (Status);
-        }
-
-        ParentTable = DtPeekSubtable ();
-        DtInsertSubtable (ParentTable, Subtable);
-        break;
-
-    default:
-        break;
-    }
-
-    return (Status);
-}
-
-
-/******************************************************************************
- *
- * FUNCTION:    DtCompileTpm2
- *
- * PARAMETERS:  PFieldList          - Current field list pointer
- *
- * RETURN:      Status
- *
- * DESCRIPTION: Compile TPM2.
- *
- *****************************************************************************/
-
-ACPI_STATUS
-DtCompileTpm2 (
-    void                    **List)
-{
-    DT_FIELD                **PFieldList = (DT_FIELD **) List;
-    DT_SUBTABLE             *Subtable;
-    ACPI_TABLE_TPM2         *Tpm2Header;
-    DT_SUBTABLE             *ParentTable;
-    ACPI_STATUS             Status = AE_OK;
-    ACPI_TABLE_HEADER       *Header;
-
-
-    ParentTable = DtPeekSubtable ();
-
-    Header = ACPI_CAST_PTR (ACPI_TABLE_HEADER, ParentTable->Buffer);
-
-    if (Header->Revision == 3)
-    {
-        return (DtCompileTpm2Rev3 (List));
-    }
-
-    /* Compile the main table */
-
-    Status = DtCompileTable (PFieldList, AcpiDmTableInfoTpm2,
-        &Subtable);
-    if (ACPI_FAILURE (Status))
-    {
-        return (Status);
-    }
-
-    ParentTable = DtPeekSubtable ();
-    DtInsertSubtable (ParentTable, Subtable);
-
-    Tpm2Header = ACPI_CAST_PTR (ACPI_TABLE_TPM2, ParentTable->Buffer);
-
-    /* Method parameters */
-    /* Optional: Log area minimum length */
-    /* Optional: Log area start address */
-    /* TBD: Optional fields above not fully implemented (not optional at this time) */
-
-    Status = DtCompileTable (PFieldList, AcpiDmTableInfoTpm2a,
-        &Subtable);
-    if (ACPI_FAILURE (Status))
-    {
-        return (Status);
-    }
-
-    ParentTable = DtPeekSubtable ();
-    DtInsertSubtable (ParentTable, Subtable);
-
-
-    /* Subtable type depends on the StartMethod */
-
-    switch (Tpm2Header->StartMethod)
-    {
-    case ACPI_TPM2_COMMAND_BUFFER_WITH_ARM_SMC:
-
-        /* Subtable specific to to ARM_SMC */
-
-        Status = DtCompileTable (PFieldList, AcpiDmTableInfoTpm211,
-            &Subtable);
-        if (ACPI_FAILURE (Status))
-        {
-            return (Status);
-        }
-
-        ParentTable = DtPeekSubtable ();
-        DtInsertSubtable (ParentTable, Subtable);
-        break;
-
-    case ACPI_TPM2_START_METHOD:
-    case ACPI_TPM2_MEMORY_MAPPED:
-    case ACPI_TPM2_COMMAND_BUFFER:
-    case ACPI_TPM2_COMMAND_BUFFER_WITH_START_METHOD:
-        break;
-
-    case ACPI_TPM2_RESERVED1:
-    case ACPI_TPM2_RESERVED3:
-    case ACPI_TPM2_RESERVED4:
-    case ACPI_TPM2_RESERVED5:
-    case ACPI_TPM2_RESERVED9:
-    case ACPI_TPM2_RESERVED10:
-
-        AcpiOsPrintf ("\n**** Reserved TPM2 Start Method type 0x%X\n",
-            Tpm2Header->StartMethod);
-        Status = AE_ERROR;
-        break;
-
-    case ACPI_TPM2_NOT_ALLOWED:
-    default:
-
-        AcpiOsPrintf ("\n**** Unknown TPM2 Start Method type 0x%X\n",
-            Tpm2Header->StartMethod);
-        Status = AE_ERROR;
-        break;
-    }
-
-    return (Status);
-}
-
-
 /******************************************************************************
  *
  * FUNCTION:    DtGetGenericTableInfo
@@ -2140,7 +1500,7 @@ DtCompileUefi (
     /* Compile the predefined portion of the UEFI table */
 
     Status = DtCompileTable (PFieldList, AcpiDmTableInfoUefi,
-        &Subtable);
+        &Subtable, TRUE);
     if (ACPI_FAILURE (Status))
     {
         return (Status);
@@ -2239,7 +1599,7 @@ DtCompileWpbt (
     /* Compile the main table */
 
     Status = DtCompileTable (PFieldList, AcpiDmTableInfoWpbt,
-        &Subtable);
+        &Subtable, TRUE);
     if (ACPI_FAILURE (Status))
     {
         return (Status);
@@ -2251,7 +1611,7 @@ DtCompileWpbt (
     /* Compile the argument list subtable */
 
     Status = DtCompileTable (PFieldList, AcpiDmTableInfoWpbt0,
-        &Subtable);
+        &Subtable, TRUE);
     if (ACPI_FAILURE (Status))
     {
         return (Status);
@@ -2361,17 +1721,17 @@ DtCompileGeneric (
         Info = DtGetGenericTableInfo ((*PFieldList)->Name);
         if (!Info)
         {
-            sprintf (AslGbl_MsgBuffer, "Generic data type \"%s\" not found",
+            sprintf (MsgBuffer, "Generic data type \"%s\" not found",
                 (*PFieldList)->Name);
             DtNameError (ASL_ERROR, ASL_MSG_INVALID_FIELD_NAME,
-                (*PFieldList), AslGbl_MsgBuffer);
+                (*PFieldList), MsgBuffer);
 
             *PFieldList = (*PFieldList)->Next;
             continue;
         }
 
         Status = DtCompileTable (PFieldList, Info,
-            &Subtable);
+            &Subtable, TRUE);
         if (ACPI_SUCCESS (Status))
         {
             DtInsertSubtable (ParentTable, Subtable);
@@ -2386,10 +1746,10 @@ DtCompileGeneric (
 
             if (Status == AE_NOT_FOUND)
             {
-                sprintf (AslGbl_MsgBuffer, "Generic data type \"%s\" not found",
+                sprintf (MsgBuffer, "Generic data type \"%s\" not found",
                     (*PFieldList)->Name);
                 DtNameError (ASL_ERROR, ASL_MSG_INVALID_FIELD_NAME,
-                    (*PFieldList), AslGbl_MsgBuffer);
+                    (*PFieldList), MsgBuffer);
             }
         }
     }
