@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2019, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,42 +111,6 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
 #include "acpi.h"
@@ -515,112 +479,6 @@ AcpiDmGpioDescriptor (
     }
 }
 
-/*******************************************************************************
- *
- * FUNCTION:    AcpiDmPinFunctionDescriptor
- *
- * PARAMETERS:  Info                - Extra resource info
- *              Resource            - Pointer to the resource descriptor
- *              Length              - Length of the descriptor in bytes
- *              Level               - Current source code indentation level
- *
- * RETURN:      None
- *
- * DESCRIPTION: Decode a PinFunction descriptor
- *
- ******************************************************************************/
-
-void
-AcpiDmPinFunctionDescriptor (
-    ACPI_OP_WALK_INFO       *Info,
-    AML_RESOURCE            *Resource,
-    UINT32                  Length,
-    UINT32                  Level)
-{
-    UINT16                  *PinList;
-    UINT8                   *VendorData;
-    char                    *DeviceName = NULL;
-    UINT32                  PinCount;
-    UINT32                  i;
-
-    AcpiDmIndent (Level);
-    AcpiOsPrintf ("PinFunction (%s, ",
-        AcpiGbl_ShrDecode [ACPI_GET_1BIT_FLAG (Resource->PinFunction.Flags)]);
-
-    if (Resource->PinFunction.PinConfig <= 3)
-    {
-        AcpiOsPrintf ("%s, ",
-            AcpiGbl_PpcDecode[Resource->PinFunction.PinConfig]);
-    }
-    else
-    {
-        AcpiOsPrintf ("0x%2.2X, ", Resource->PinFunction.PinConfig);
-    }
-
-    /* FunctionNumber */
-
-    AcpiOsPrintf ("0x%4.4X, ", Resource->PinFunction.FunctionNumber);
-
-    if (Resource->PinFunction.ResSourceOffset)
-    {
-        DeviceName = ACPI_ADD_PTR (char,
-            Resource, Resource->PinFunction.ResSourceOffset),
-        AcpiUtPrintString (DeviceName, ACPI_UINT16_MAX);
-    }
-
-    AcpiOsPrintf (", ");
-    AcpiOsPrintf ("0x%2.2X,\n", Resource->PinFunction.ResSourceIndex);
-
-    AcpiDmIndent (Level + 1);
-
-    /* Always ResourceConsumer */
-    AcpiOsPrintf ("%s, ", AcpiGbl_ConsumeDecode [ACPI_CONSUMER]);
-
-    /* Insert a descriptor name */
-
-    AcpiDmDescriptorName ();
-
-    AcpiOsPrintf (",");
-
-    /* Dump the vendor data */
-
-    if (Resource->PinFunction.VendorLength)
-    {
-        AcpiOsPrintf ("\n");
-        AcpiDmIndent (Level + 1);
-        VendorData = ACPI_ADD_PTR (UINT8, Resource,
-            Resource->PinFunction.VendorOffset);
-
-        AcpiDmDumpRawDataBuffer (VendorData,
-            Resource->PinFunction.VendorLength, Level);
-    }
-
-    AcpiOsPrintf (")\n");
-
-    AcpiDmIndent (Level + 1);
-
-    /* Dump the interrupt list */
-
-    AcpiOsPrintf ("{   // Pin list\n");
-
-    PinCount = ((UINT32) (Resource->PinFunction.ResSourceOffset -
-        Resource->PinFunction.PinTableOffset)) /
-        sizeof (UINT16);
-
-    PinList = (UINT16 *) ACPI_ADD_PTR (char, Resource,
-        Resource->PinFunction.PinTableOffset);
-
-    for (i = 0; i < PinCount; i++)
-    {
-        AcpiDmIndent (Level + 2);
-        AcpiOsPrintf ("0x%4.4X%s\n", PinList[i],
-            ((i + 1) < PinCount) ? "," : "");
-    }
-
-    AcpiDmIndent (Level + 1);
-    AcpiOsPrintf ("}\n");
-}
-
 
 /*******************************************************************************
  *
@@ -714,7 +572,7 @@ AcpiDmI2cSerialBusDescriptor (
     /* SlaveAddress, SlaveMode, ConnectionSpeed, AddressingMode */
 
     AcpiDmIndent (Level);
-    AcpiOsPrintf ("I2cSerialBusV2 (0x%4.4X, %s, 0x%8.8X,\n",
+    AcpiOsPrintf ("I2cSerialBus (0x%4.4X, %s, 0x%8.8X,\n",
         Resource->I2cSerialBus.SlaveAddress,
         AcpiGbl_SmDecode [ACPI_GET_1BIT_FLAG (Resource->I2cSerialBus.Flags)],
         Resource->I2cSerialBus.ConnectionSpeed);
@@ -728,7 +586,7 @@ AcpiDmI2cSerialBusDescriptor (
     ResourceSourceOffset = sizeof (AML_RESOURCE_COMMON_SERIALBUS) +
         Resource->CommonSerialBus.TypeDataLength;
 
-    DeviceName = ACPI_ADD_PTR (char, Resource, ResourceSourceOffset);
+    DeviceName = ACPI_ADD_PTR (char, Resource, ResourceSourceOffset),
     AcpiUtPrintString (DeviceName, ACPI_UINT16_MAX);
 
     /* ResourceSourceIndex, ResourceUsage */
@@ -743,11 +601,7 @@ AcpiDmI2cSerialBusDescriptor (
     /* Insert a descriptor name */
 
     AcpiDmDescriptorName ();
-
-    /* Share */
-
-    AcpiOsPrintf (", %s,\n",
-        AcpiGbl_ShrDecode [ACPI_EXTRACT_1BIT_FLAG (Resource->I2cSerialBus.Flags, 2)]);
+    AcpiOsPrintf (",\n");
 
     /* Dump the vendor data */
 
@@ -788,7 +642,7 @@ AcpiDmSpiSerialBusDescriptor (
     /* DeviceSelection, DeviceSelectionPolarity, WireMode, DataBitLength */
 
     AcpiDmIndent (Level);
-    AcpiOsPrintf ("SpiSerialBusV2 (0x%4.4X, %s, %s, 0x%2.2X,\n",
+    AcpiOsPrintf ("SpiSerialBus (0x%4.4X, %s, %s, 0x%2.2X,\n",
         Resource->SpiSerialBus.DeviceSelection,
         AcpiGbl_DpDecode [ACPI_EXTRACT_1BIT_FLAG (Resource->SpiSerialBus.TypeSpecificFlags, 1)],
         AcpiGbl_WmDecode [ACPI_GET_1BIT_FLAG (Resource->SpiSerialBus.TypeSpecificFlags)],
@@ -811,7 +665,7 @@ AcpiDmSpiSerialBusDescriptor (
     ResourceSourceOffset = sizeof (AML_RESOURCE_COMMON_SERIALBUS) +
         Resource->CommonSerialBus.TypeDataLength;
 
-    DeviceName = ACPI_ADD_PTR (char, Resource, ResourceSourceOffset);
+    DeviceName = ACPI_ADD_PTR (char, Resource, ResourceSourceOffset),
     AcpiUtPrintString (DeviceName, ACPI_UINT16_MAX);
 
     /* ResourceSourceIndex, ResourceUsage */
@@ -826,11 +680,7 @@ AcpiDmSpiSerialBusDescriptor (
     /* Insert a descriptor name */
 
     AcpiDmDescriptorName ();
-
-    /* Share */
-
-    AcpiOsPrintf (", %s,\n",
-        AcpiGbl_ShrDecode [ACPI_EXTRACT_1BIT_FLAG (Resource->SpiSerialBus.Flags, 2)]);
+    AcpiOsPrintf (",\n");
 
     /* Dump the vendor data */
 
@@ -871,7 +721,7 @@ AcpiDmUartSerialBusDescriptor (
     /* ConnectionSpeed, BitsPerByte, StopBits */
 
     AcpiDmIndent (Level);
-    AcpiOsPrintf ("UartSerialBusV2 (0x%8.8X, %s, %s,\n",
+    AcpiOsPrintf ("UartSerialBus (0x%8.8X, %s, %s,\n",
         Resource->UartSerialBus.DefaultBaudRate,
         AcpiGbl_BpbDecode [ACPI_EXTRACT_3BIT_FLAG (Resource->UartSerialBus.TypeSpecificFlags, 4)],
         AcpiGbl_SbDecode [ACPI_EXTRACT_2BIT_FLAG (Resource->UartSerialBus.TypeSpecificFlags, 2)]);
@@ -897,7 +747,7 @@ AcpiDmUartSerialBusDescriptor (
     ResourceSourceOffset = sizeof (AML_RESOURCE_COMMON_SERIALBUS) +
         Resource->CommonSerialBus.TypeDataLength;
 
-    DeviceName = ACPI_ADD_PTR (char, Resource, ResourceSourceOffset);
+    DeviceName = ACPI_ADD_PTR (char, Resource, ResourceSourceOffset),
     AcpiUtPrintString (DeviceName, ACPI_UINT16_MAX);
 
     /* ResourceSourceIndex, ResourceUsage */
@@ -912,11 +762,7 @@ AcpiDmUartSerialBusDescriptor (
     /* Insert a descriptor name */
 
     AcpiDmDescriptorName ();
-
-    /* Share */
-
-    AcpiOsPrintf (", %s,\n",
-        AcpiGbl_ShrDecode [ACPI_EXTRACT_1BIT_FLAG (Resource->UartSerialBus.Flags, 2)]);
+    AcpiOsPrintf (",\n");
 
     /* Dump the vendor data */
 
@@ -954,363 +800,3 @@ AcpiDmSerialBusDescriptor (
     SerialBusResourceDispatch [Resource->CommonSerialBus.Type] (
         Info, Resource, Length, Level);
 }
-
-/*******************************************************************************
- *
- * FUNCTION:    AcpiDmPinConfig
- *
- * PARAMETERS:  PinConfigType       - Pin configuration type
- *              PinConfigValue      - Pin configuration value
- *
- * RETURN:      None
- *
- * DESCRIPTION: Pretty prints PinConfig type and value.
- *
- ******************************************************************************/
-
-static void
-AcpiDmPinConfig(
-    UINT8                   PinConfigType,
-    UINT32                  PinConfigValue)
-{
-    if (PinConfigType <= 13)
-    {
-        AcpiOsPrintf ("0x%2.2X /* %s */, ", PinConfigType,
-            AcpiGbl_PtypDecode[PinConfigType]);
-    }
-    else
-    {
-        AcpiOsPrintf ("0x%2.2X, /* Vendor Defined */ ", PinConfigType);
-    }
-
-    /* PinConfigValue */
-
-    AcpiOsPrintf ("0x%4.4X,\n", PinConfigValue);
-}
-
-/*******************************************************************************
- *
- * FUNCTION:    AcpiDmPinConfigDescriptor
- *
- * PARAMETERS:  Info                - Extra resource info
- *              Resource            - Pointer to the resource descriptor
- *              Length              - Length of the descriptor in bytes
- *              Level               - Current source code indentation level
- *
- * RETURN:      None
- *
- * DESCRIPTION: Decode a PinConfig descriptor
- *
- ******************************************************************************/
-
-void
-AcpiDmPinConfigDescriptor (
-    ACPI_OP_WALK_INFO       *Info,
-    AML_RESOURCE            *Resource,
-    UINT32                  Length,
-    UINT32                  Level)
-{
-    UINT16                  *PinList;
-    UINT8                   *VendorData;
-    char                    *DeviceName = NULL;
-    UINT32                  PinCount;
-    UINT32                  i;
-
-    AcpiDmIndent (Level);
-    AcpiOsPrintf ("PinConfig (%s, ",
-        AcpiGbl_ShrDecode [ACPI_GET_1BIT_FLAG (Resource->PinConfig.Flags)]);
-
-    AcpiDmPinConfig (Resource->PinConfig.PinConfigType,
-        Resource->PinConfig.PinConfigValue);
-
-    AcpiDmIndent (Level + 1);
-
-    if (Resource->PinConfig.ResSourceOffset)
-    {
-        DeviceName = ACPI_ADD_PTR (char,
-            Resource, Resource->PinConfig.ResSourceOffset),
-        AcpiUtPrintString (DeviceName, ACPI_UINT16_MAX);
-    }
-
-    AcpiOsPrintf (", ");
-    AcpiOsPrintf ("0x%2.2X, ", Resource->PinConfig.ResSourceIndex);
-
-    AcpiOsPrintf ("%s, ",
-        AcpiGbl_ConsumeDecode [ACPI_EXTRACT_1BIT_FLAG (Resource->PinConfig.Flags, 1)]);
-
-    /* Insert a descriptor name */
-
-    AcpiDmDescriptorName ();
-
-    AcpiOsPrintf (",");
-
-    /* Dump the vendor data */
-
-    if (Resource->PinConfig.VendorLength)
-    {
-        AcpiOsPrintf ("\n");
-        AcpiDmIndent (Level + 1);
-        VendorData = ACPI_ADD_PTR (UINT8, Resource,
-            Resource->PinConfig.VendorOffset);
-
-        AcpiDmDumpRawDataBuffer (VendorData,
-            Resource->PinConfig.VendorLength, Level);
-    }
-
-    AcpiOsPrintf (")\n");
-
-    AcpiDmIndent (Level + 1);
-
-    /* Dump the interrupt list */
-
-    AcpiOsPrintf ("{   // Pin list\n");
-
-    PinCount = ((UINT32) (Resource->PinConfig.ResSourceOffset -
-        Resource->PinConfig.PinTableOffset)) /
-        sizeof (UINT16);
-
-    PinList = (UINT16 *) ACPI_ADD_PTR (char, Resource,
-        Resource->PinConfig.PinTableOffset);
-
-    for (i = 0; i < PinCount; i++)
-    {
-        AcpiDmIndent (Level + 2);
-        AcpiOsPrintf ("0x%4.4X%s\n", PinList[i],
-            ((i + 1) < PinCount) ? "," : "");
-    }
-
-    AcpiDmIndent (Level + 1);
-    AcpiOsPrintf ("}\n");
-}
-
-/*******************************************************************************
- *
- * FUNCTION:    AcpiDmPinGroupDescriptor
- *
- * PARAMETERS:  Info                - Extra resource info
- *              Resource            - Pointer to the resource descriptor
- *              Length              - Length of the descriptor in bytes
- *              Level               - Current source code indentation level
- *
- * RETURN:      None
- *
- * DESCRIPTION: Decode a PinGroup descriptor
- *
- ******************************************************************************/
-
-void
-AcpiDmPinGroupDescriptor (
-    ACPI_OP_WALK_INFO       *Info,
-    AML_RESOURCE            *Resource,
-    UINT32                  Length,
-    UINT32                  Level)
-{
-    char                    *Label;
-    UINT16                  *PinList;
-    UINT8                   *VendorData;
-    UINT32                  PinCount;
-    UINT32                  i;
-
-    AcpiDmIndent (Level);
-    /* Always producer */
-    AcpiOsPrintf ("PinGroup (");
-
-    Label = ACPI_ADD_PTR (char,
-        Resource, Resource->PinGroup.LabelOffset),
-    AcpiUtPrintString (Label, ACPI_UINT16_MAX);
-
-    AcpiOsPrintf (", ");
-
-    AcpiOsPrintf ("%s, ",
-        AcpiGbl_ConsumeDecode [ACPI_GET_1BIT_FLAG (Resource->PinGroup.Flags)]);
-
-    /* Insert a descriptor name */
-
-    AcpiDmDescriptorName ();
-
-    AcpiOsPrintf (",");
-
-    /* Dump the vendor data */
-
-    if (Resource->PinGroup.VendorLength)
-    {
-        AcpiOsPrintf ("\n");
-        AcpiDmIndent (Level + 1);
-        VendorData = ACPI_ADD_PTR (UINT8, Resource,
-            Resource->PinGroup.VendorOffset);
-
-        AcpiDmDumpRawDataBuffer (VendorData,
-            Resource->PinGroup.VendorLength, Level);
-    }
-
-    AcpiOsPrintf (")\n");
-
-    AcpiDmIndent (Level + 1);
-
-    /* Dump the interrupt list */
-
-    AcpiOsPrintf ("{   // Pin list\n");
-
-    PinCount = (Resource->PinGroup.LabelOffset -
-        Resource->PinGroup.PinTableOffset) / sizeof (UINT16);
-
-    PinList = (UINT16 *) ACPI_ADD_PTR (char, Resource,
-        Resource->PinGroup.PinTableOffset);
-
-    for (i = 0; i < PinCount; i++)
-    {
-        AcpiDmIndent (Level + 2);
-        AcpiOsPrintf ("0x%4.4X%s\n", PinList[i],
-            ((i + 1) < PinCount) ? "," : "");
-    }
-
-    AcpiDmIndent (Level + 1);
-    AcpiOsPrintf ("}\n");
-}
-
-/*******************************************************************************
- *
- * FUNCTION:    AcpiDmPinGroupFunctionDescriptor
- *
- * PARAMETERS:  Info                - Extra resource info
- *              Resource            - Pointer to the resource descriptor
- *              Length              - Length of the descriptor in bytes
- *              Level               - Current source code indentation level
- *
- * RETURN:      None
- *
- * DESCRIPTION: Decode a PinGroupFunction descriptor
- *
- ******************************************************************************/
-
-void
-AcpiDmPinGroupFunctionDescriptor (
-    ACPI_OP_WALK_INFO       *Info,
-    AML_RESOURCE            *Resource,
-    UINT32                  Length,
-    UINT32                  Level)
-{
-    UINT8                   *VendorData;
-    char                    *DeviceName = NULL;
-    char                    *Label = NULL;
-
-    AcpiDmIndent (Level);
-    AcpiOsPrintf ("PinGroupFunction (%s, ",
-        AcpiGbl_ShrDecode [ACPI_GET_1BIT_FLAG (Resource->PinGroupFunction.Flags)]);
-
-    /* FunctionNumber */
-
-    AcpiOsPrintf ("0x%4.4X, ", Resource->PinGroupFunction.FunctionNumber);
-
-    DeviceName = ACPI_ADD_PTR (char,
-        Resource, Resource->PinGroupFunction.ResSourceOffset),
-    AcpiUtPrintString (DeviceName, ACPI_UINT16_MAX);
-
-    AcpiOsPrintf (", ");
-    AcpiOsPrintf ("0x%2.2X,\n", Resource->PinGroupFunction.ResSourceIndex);
-
-    AcpiDmIndent (Level + 1);
-
-    Label = ACPI_ADD_PTR (char, Resource,
-        Resource->PinGroupFunction.ResSourceLabelOffset);
-    AcpiUtPrintString (Label, ACPI_UINT16_MAX);
-
-    AcpiOsPrintf (", ");
-
-    AcpiOsPrintf ("%s, ",
-        AcpiGbl_ConsumeDecode [ACPI_EXTRACT_1BIT_FLAG (Resource->PinGroupFunction.Flags, 1)]);
-
-    /* Insert a descriptor name */
-
-    AcpiDmDescriptorName ();
-
-    AcpiOsPrintf (",");
-
-    /* Dump the vendor data */
-
-    if (Resource->PinGroupFunction.VendorLength)
-    {
-        AcpiOsPrintf ("\n");
-        AcpiDmIndent (Level + 1);
-        VendorData = ACPI_ADD_PTR (UINT8, Resource,
-            Resource->PinGroupFunction.VendorOffset);
-
-        AcpiDmDumpRawDataBuffer (VendorData,
-            Resource->PinGroupFunction.VendorLength, Level);
-    }
-
-    AcpiOsPrintf (")\n");
-}
-
-/*******************************************************************************
- *
- * FUNCTION:    AcpiDmPinGroupConfigDescriptor
- *
- * PARAMETERS:  Info                - Extra resource info
- *              Resource            - Pointer to the resource descriptor
- *              Length              - Length of the descriptor in bytes
- *              Level               - Current source code indentation level
- *
- * RETURN:      None
- *
- * DESCRIPTION: Decode a PinGroupConfig descriptor
- *
- ******************************************************************************/
-
-void
-AcpiDmPinGroupConfigDescriptor (
-    ACPI_OP_WALK_INFO       *Info,
-    AML_RESOURCE            *Resource,
-    UINT32                  Length,
-    UINT32                  Level)
-{
-    UINT8                   *VendorData;
-    char                    *DeviceName = NULL;
-    char                    *Label = NULL;
-
-    AcpiDmIndent (Level);
-    AcpiOsPrintf ("PinGroupConfig (%s, ",
-        AcpiGbl_ShrDecode [ACPI_GET_1BIT_FLAG (Resource->PinGroupConfig.Flags)]);
-
-    AcpiDmPinConfig(Resource->PinGroupConfig.PinConfigType,
-        Resource->PinGroupConfig.PinConfigValue);
-
-    AcpiDmIndent (Level + 1);
-
-    DeviceName = ACPI_ADD_PTR (char,
-        Resource, Resource->PinGroupConfig.ResSourceOffset),
-    AcpiUtPrintString (DeviceName, ACPI_UINT16_MAX);
-
-    AcpiOsPrintf (", ");
-    AcpiOsPrintf ("0x%2.2X, ", Resource->PinGroupConfig.ResSourceIndex);
-
-    Label = ACPI_ADD_PTR (char, Resource,
-        Resource->PinGroupConfig.ResSourceLabelOffset);
-    AcpiUtPrintString (Label, ACPI_UINT16_MAX);
-
-    AcpiOsPrintf (", ");
-
-    AcpiOsPrintf ("%s, ",
-        AcpiGbl_ConsumeDecode [ACPI_EXTRACT_1BIT_FLAG (Resource->PinGroupConfig.Flags, 1)]);
-
-    /* Insert a descriptor name */
-
-    AcpiDmDescriptorName ();
-
-    AcpiOsPrintf (",");
-
-    /* Dump the vendor data */
-
-    if (Resource->PinGroupConfig.VendorLength)
-    {
-        AcpiOsPrintf ("\n");
-        AcpiDmIndent (Level + 1);
-        VendorData = ACPI_ADD_PTR (UINT8, Resource,
-            Resource->PinGroupConfig.VendorOffset);
-
-        AcpiDmDumpRawDataBuffer (VendorData,
-            Resource->PinGroupConfig.VendorLength, Level);
-    }
-
-    AcpiOsPrintf (")\n");
-}
