@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2017, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,42 +111,6 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
 #include "acpi.h"
@@ -154,13 +118,14 @@
 #include "acparser.h"
 #include "amlcode.h"
 #include "acdebug.h"
-#include "acconvert.h"
 
 
 #define _COMPONENT          ACPI_CA_DEBUGGER
         ACPI_MODULE_NAME    ("dmwalk")
 
 
+#define DB_FULL_OP_INFO     "[%4.4s] @%5.5X #%4.4X:  "
+
 /* Stub for non-compiler code */
 
 #ifndef ACPI_ASL_COMPILER
@@ -170,14 +135,6 @@ AcpiDmEmitExternals (
 {
     return;
 }
-
-void
-AcpiDmEmitExternal (
-    ACPI_PARSE_OBJECT       *NameOp,
-    ACPI_PARSE_OBJECT       *TypeOp)
-{
-    return;
-}
 #endif
 
 /* Local prototypes */
@@ -194,6 +151,10 @@ AcpiDmAscendingOp (
     UINT32                  Level,
     void                    *Context);
 
+static UINT32
+AcpiDmBlockType (
+    ACPI_PARSE_OBJECT       *Op);
+
 
 /*******************************************************************************
  *
@@ -359,7 +320,7 @@ AcpiDmWalkParseTree (
  *
  ******************************************************************************/
 
-UINT32
+static UINT32
 AcpiDmBlockType (
     ACPI_PARSE_OBJECT       *Op)
 {
@@ -381,7 +342,7 @@ AcpiDmBlockType (
     case AML_DEVICE_OP:
     case AML_SCOPE_OP:
     case AML_PROCESSOR_OP:
-    case AML_POWER_RESOURCE_OP:
+    case AML_POWER_RES_OP:
     case AML_THERMAL_ZONE_OP:
     case AML_IF_OP:
     case AML_WHILE_OP:
@@ -403,7 +364,7 @@ AcpiDmBlockType (
         /*lint -fallthrough */
 
     case AML_PACKAGE_OP:
-    case AML_VARIABLE_PACKAGE_OP:
+    case AML_VAR_PACKAGE_OP:
 
         return (BLOCK_PAREN | BLOCK_BRACE);
 
@@ -415,7 +376,7 @@ AcpiDmBlockType (
 
         if (Op->Common.Parent &&
             ((Op->Common.Parent->Common.AmlOpcode == AML_PACKAGE_OP) ||
-             (Op->Common.Parent->Common.AmlOpcode == AML_VARIABLE_PACKAGE_OP)))
+             (Op->Common.Parent->Common.AmlOpcode == AML_VAR_PACKAGE_OP)))
         {
             /* This is a reference to a method, not an invocation */
 
@@ -468,7 +429,7 @@ AcpiDmListType (
     case AML_METHOD_OP:
     case AML_DEVICE_OP:
     case AML_SCOPE_OP:
-    case AML_POWER_RESOURCE_OP:
+    case AML_POWER_RES_OP:
     case AML_PROCESSOR_OP:
     case AML_THERMAL_ZONE_OP:
     case AML_IF_OP:
@@ -481,7 +442,7 @@ AcpiDmListType (
 
     case AML_BUFFER_OP:
     case AML_PACKAGE_OP:
-    case AML_VARIABLE_PACKAGE_OP:
+    case AML_VAR_PACKAGE_OP:
 
         return (BLOCK_COMMA_LIST);
 
@@ -521,26 +482,9 @@ AcpiDmDescendingOp (
     const ACPI_OPCODE_INFO  *OpInfo;
     UINT32                  Name;
     ACPI_PARSE_OBJECT       *NextOp;
-    ACPI_PARSE_OBJECT       *NextOp2;
     UINT32                  AmlOffset;
 
 
-    /* Determine which file this parse node is contained in. */
-
-    if (AcpiGbl_CaptureComments)
-    {
-        ASL_CV_LABEL_FILENODE (Op);
-
-        if (Level != 0 && ASL_CV_FILE_HAS_SWITCHED (Op))
-        {
-            ASL_CV_SWITCH_FILES (Level, Op);
-        }
-
-        /* If this parse node has regular comments, print them here. */
-
-        ASL_CV_PRINT_ONE_COMMENT (Op, AML_COMMENT_STANDARD, NULL, Level);
-    }
-
     OpInfo = AcpiPsGetOpcodeInfo (Op->Common.AmlOpcode);
 
     /* Listing support to dump the AML code after the ASL statement */
@@ -564,7 +508,8 @@ AcpiDmDescendingOp (
                     AcpiUtDumpBuffer (
                         (Info->StartAml + Info->AmlOffset),
                         (Op->Common.Aml - Info->PreviousAml),
-                        DB_BYTE_DISPLAY, Info->AmlOffset);
+                        DB_BYTE_DISPLAY,
+                        Info->AmlOffset);
                     AcpiOsPrintf ("\n");
                 }
 
@@ -582,45 +527,6 @@ AcpiDmDescendingOp (
         return (AE_CTRL_DEPTH);
     }
 
-    if (Op->Common.DisasmOpcode == ACPI_DASM_IGNORE_SINGLE)
-    {
-        /* Ignore this op, but not it's children */
-
-        return (AE_OK);
-    }
-
-    if (Op->Common.AmlOpcode == AML_IF_OP)
-    {
-        NextOp = AcpiPsGetDepthNext (NULL, Op);
-        if (NextOp)
-        {
-            NextOp->Common.DisasmFlags |= ACPI_PARSEOP_PARAMETER_LIST;
-
-            /* Don't emit the actual embedded externals unless asked */
-
-            if (!AcpiGbl_DmEmitExternalOpcodes)
-            {
-                /*
-                 * A Zero predicate indicates the possibility of one or more
-                 * External() opcodes within the If() block.
-                 */
-                if (NextOp->Common.AmlOpcode == AML_ZERO_OP)
-                {
-                    NextOp2 = NextOp->Common.Next;
-
-                    if (NextOp2 &&
-                        (NextOp2->Common.AmlOpcode == AML_EXTERNAL_OP))
-                    {
-                        /* Ignore the If 0 block and all children */
-
-                        Op->Common.DisasmFlags |= ACPI_PARSEOP_IGNORE;
-                        return (AE_CTRL_DEPTH);
-                    }
-                }
-            }
-        }
-    }
-
     /* Level 0 is at the Definition Block level */
 
     if (Level == 0)
@@ -633,16 +539,10 @@ AcpiDmDescendingOp (
                 Info->WalkState->ParserState.AmlStart);
             if (AcpiGbl_DmOpt_Verbose)
             {
-                if (AcpiGbl_CmSingleStep)
-                {
-                    AcpiOsPrintf ("%5.5X/%4.4X: ",
-                        AmlOffset, (UINT32) Op->Common.AmlOpcode);
-                }
-                else
-                {
-                    AcpiOsPrintf ("AML Offset %5.5X, Opcode %4.4X: ",
-                        AmlOffset, (UINT32) Op->Common.AmlOpcode);
-                }
+                AcpiOsPrintf (DB_FULL_OP_INFO,
+                    (Info->WalkState->MethodNode ?
+                        Info->WalkState->MethodNode->Name.Ascii : "   "),
+                    AmlOffset, (UINT32) Op->Common.AmlOpcode);
             }
         }
 
@@ -654,16 +554,12 @@ AcpiDmDescendingOp (
 
             /* Emit all External() declarations here */
 
-            if (!AcpiGbl_DmEmitExternalOpcodes)
-            {
-                AcpiDmEmitExternals ();
-            }
-
+            AcpiDmEmitExternals ();
             return (AE_OK);
         }
     }
     else if ((AcpiDmBlockType (Op->Common.Parent) & BLOCK_BRACE) &&
-         (!(Op->Common.DisasmFlags & ACPI_PARSEOP_PARAMETER_LIST)) &&
+         (!(Op->Common.DisasmFlags & ACPI_PARSEOP_PARAMLIST)) &&
          (!(Op->Common.DisasmFlags & ACPI_PARSEOP_ELSEIF)) &&
          (Op->Common.AmlOpcode != AML_INT_BYTELIST_OP))
     {
@@ -737,12 +633,6 @@ AcpiDmDescendingOp (
         Info->Level--;
     }
 
-    if (Op->Common.AmlOpcode == AML_EXTERNAL_OP)
-    {
-        Op->Common.DisasmFlags |= ACPI_PARSEOP_IGNORE;
-        return (AE_CTRL_DEPTH);
-    }
-
     /* Start the opcode argument list if necessary */
 
     if ((OpInfo->Flags & AML_HAS_ARGS) ||
@@ -753,10 +643,6 @@ AcpiDmDescendingOp (
         if (AcpiDmBlockType (Op) & BLOCK_PAREN)
         {
             AcpiOsPrintf (" (");
-            if (!(AcpiDmBlockType (Op) & BLOCK_BRACE))
-            {
-                ASL_CV_PRINT_ONE_COMMENT (Op, AMLCOMMENT_INLINE, " ", 0);
-            }
         }
 
         /* If this is a named opcode, print the associated name value */
@@ -779,7 +665,7 @@ AcpiDmDescendingOp (
                 Name = AcpiPsGetName (Op);
                 if (Op->Named.Path)
                 {
-                    AcpiDmNamestring (Op->Named.Path);
+                    AcpiDmNamestring ((char *) Op->Named.Path);
                 }
                 else
                 {
@@ -801,7 +687,7 @@ AcpiDmDescendingOp (
             case AML_METHOD_OP:
 
                 AcpiDmMethodFlags (Op);
-                ASL_CV_CLOSE_PAREN (Op, Level);
+                AcpiOsPrintf (")");
 
                 /* Emit description comment for Method() with a predefined ACPI name */
 
@@ -814,7 +700,6 @@ AcpiDmDescendingOp (
 
                 AcpiDmCheckForHardwareId (Op);
                 AcpiOsPrintf (", ");
-                ASL_CV_PRINT_ONE_COMMENT (Op, AML_NAMECOMMENT, NULL, 0);
                 break;
 
             case AML_REGION_OP:
@@ -822,16 +707,16 @@ AcpiDmDescendingOp (
                 AcpiDmRegionFlags (Op);
                 break;
 
-            case AML_POWER_RESOURCE_OP:
+            case AML_POWER_RES_OP:
 
                 /* Mark the next two Ops as part of the parameter list */
 
                 AcpiOsPrintf (", ");
                 NextOp = AcpiPsGetDepthNext (NULL, Op);
-                NextOp->Common.DisasmFlags |= ACPI_PARSEOP_PARAMETER_LIST;
+                NextOp->Common.DisasmFlags |= ACPI_PARSEOP_PARAMLIST;
 
                 NextOp = NextOp->Common.Next;
-                NextOp->Common.DisasmFlags |= ACPI_PARSEOP_PARAMETER_LIST;
+                NextOp->Common.DisasmFlags |= ACPI_PARSEOP_PARAMLIST;
                 return (AE_OK);
 
             case AML_PROCESSOR_OP:
@@ -840,13 +725,13 @@ AcpiDmDescendingOp (
 
                 AcpiOsPrintf (", ");
                 NextOp = AcpiPsGetDepthNext (NULL, Op);
-                NextOp->Common.DisasmFlags |= ACPI_PARSEOP_PARAMETER_LIST;
+                NextOp->Common.DisasmFlags |= ACPI_PARSEOP_PARAMLIST;
 
                 NextOp = NextOp->Common.Next;
-                NextOp->Common.DisasmFlags |= ACPI_PARSEOP_PARAMETER_LIST;
+                NextOp->Common.DisasmFlags |= ACPI_PARSEOP_PARAMLIST;
 
                 NextOp = NextOp->Common.Next;
-                NextOp->Common.DisasmFlags |= ACPI_PARSEOP_PARAMETER_LIST;
+                NextOp->Common.DisasmFlags |= ACPI_PARSEOP_PARAMLIST;
                 return (AE_OK);
 
             case AML_MUTEX_OP:
@@ -864,7 +749,7 @@ AcpiDmDescendingOp (
             case AML_DEVICE_OP:
             case AML_THERMAL_ZONE_OP:
 
-                ASL_CV_CLOSE_PAREN (Op, Level);
+                AcpiOsPrintf (")");
                 break;
 
             default:
@@ -905,12 +790,12 @@ AcpiDmDescendingOp (
                  * Bank Value. This is a TermArg in the middle of the parameter
                  * list, must handle it here.
                  *
-                 * Disassemble the TermArg parse tree. ACPI_PARSEOP_PARAMETER_LIST
+                 * Disassemble the TermArg parse tree. ACPI_PARSEOP_PARAMLIST
                  * eliminates newline in the output.
                  */
                 NextOp = NextOp->Common.Next;
 
-                Info->Flags = ACPI_PARSEOP_PARAMETER_LIST;
+                Info->Flags = ACPI_PARSEOP_PARAMLIST;
                 AcpiDmWalkParseTree (NextOp, AcpiDmDescendingOp,
                     AcpiDmAscendingOp, Info);
                 Info->Flags = 0;
@@ -958,7 +843,7 @@ AcpiDmDescendingOp (
                  */
                 NextOp->Common.DisasmFlags |= ACPI_PARSEOP_IGNORE;
                 NextOp = NextOp->Common.Next;
-                ASL_CV_CLOSE_PAREN (Op, Level);
+                AcpiOsPrintf (")");
 
                 /* Emit description comment for Name() with a predefined ACPI name */
 
@@ -972,11 +857,11 @@ AcpiDmDescendingOp (
 
             /* Normal Buffer, mark size as in the parameter list */
 
-            NextOp->Common.DisasmFlags |= ACPI_PARSEOP_PARAMETER_LIST;
+            NextOp->Common.DisasmFlags |= ACPI_PARSEOP_PARAMLIST;
             return (AE_OK);
 
+        case AML_VAR_PACKAGE_OP:
         case AML_IF_OP:
-        case AML_VARIABLE_PACKAGE_OP:
         case AML_WHILE_OP:
 
             /* The next op is the size or predicate parameter */
@@ -984,7 +869,7 @@ AcpiDmDescendingOp (
             NextOp = AcpiPsGetDepthNext (NULL, Op);
             if (NextOp)
             {
-                NextOp->Common.DisasmFlags |= ACPI_PARSEOP_PARAMETER_LIST;
+                NextOp->Common.DisasmFlags |= ACPI_PARSEOP_PARAMLIST;
             }
             return (AE_OK);
 
@@ -995,7 +880,7 @@ AcpiDmDescendingOp (
             NextOp = AcpiPsGetDepthNext (NULL, Op);
             if (NextOp)
             {
-                NextOp->Common.DisasmFlags |= ACPI_PARSEOP_PARAMETER_LIST;
+                NextOp->Common.DisasmFlags |= ACPI_PARSEOP_PARAMLIST;
             }
             return (AE_OK);
 
@@ -1044,22 +929,7 @@ AcpiDmAscendingOp (
     ACPI_PARSE_OBJECT       *ParentOp;
 
 
-    /* Point the Op's filename pointer to the proper file */
-
-    if (AcpiGbl_CaptureComments)
-    {
-        ASL_CV_LABEL_FILENODE (Op);
-
-        /* Switch the output of these files if necessary */
-
-        if (ASL_CV_FILE_HAS_SWITCHED (Op))
-        {
-            ASL_CV_SWITCH_FILES (Level, Op);
-        }
-    }
-
-    if (Op->Common.DisasmFlags & ACPI_PARSEOP_IGNORE ||
-        Op->Common.DisasmOpcode == ACPI_DASM_IGNORE_SINGLE)
+    if (Op->Common.DisasmFlags & ACPI_PARSEOP_IGNORE)
     {
         /* Ignore this op -- it was handled elsewhere */
 
@@ -1070,17 +940,7 @@ AcpiDmAscendingOp (
     {
         /* Indicates the end of the current descriptor block (table) */
 
-        ASL_CV_CLOSE_BRACE (Op, Level);
-
-        /* Print any comments that are at the end of the file here */
-
-        if (AcpiGbl_CaptureComments && AcpiGbl_LastListHead)
-        {
-            AcpiOsPrintf ("\n");
-            ASL_CV_PRINT_ONE_COMMENT_LIST (AcpiGbl_LastListHead, 0);
-        }
-        AcpiOsPrintf ("\n\n");
-
+        AcpiOsPrintf ("}\n\n");
         return (AE_OK);
     }
 
@@ -1119,14 +979,14 @@ AcpiDmAscendingOp (
         if (!AcpiDmCommaIfListMember (Op))
         {
             if ((AcpiDmBlockType (Op->Common.Parent) & BLOCK_BRACE) &&
-                 (!(Op->Common.DisasmFlags & ACPI_PARSEOP_PARAMETER_LIST)) &&
+                 (!(Op->Common.DisasmFlags & ACPI_PARSEOP_PARAMLIST)) &&
                  (Op->Common.AmlOpcode != AML_INT_BYTELIST_OP))
             {
                 /*
                  * This is a first-level element of a term list
                  * start a new line
                  */
-                if (!(Info->Flags & ACPI_PARSEOP_PARAMETER_LIST))
+                if (!(Info->Flags & ACPI_PARSEOP_PARAMLIST))
                 {
                     AcpiOsPrintf ("\n");
                 }
@@ -1141,12 +1001,12 @@ AcpiDmAscendingOp (
 
         if (Op->Common.DisasmFlags & ACPI_PARSEOP_EMPTY_TERMLIST)
         {
-            ASL_CV_CLOSE_BRACE (Op, Level);
+            AcpiOsPrintf ("}");
         }
         else
         {
             AcpiDmIndent (Level);
-            ASL_CV_CLOSE_BRACE (Op, Level);
+            AcpiOsPrintf ("}");
         }
 
         AcpiDmCommaIfListMember (Op);
@@ -1181,7 +1041,7 @@ AcpiDmAscendingOp (
         if (!AcpiDmCommaIfListMember (Op))
         {
             if ((AcpiDmBlockType (Op->Common.Parent) & BLOCK_BRACE) &&
-                 (!(Op->Common.DisasmFlags & ACPI_PARSEOP_PARAMETER_LIST)) &&
+                 (!(Op->Common.DisasmFlags & ACPI_PARSEOP_PARAMLIST)) &&
                  (Op->Common.AmlOpcode != AML_INT_BYTELIST_OP))
             {
                 /*
@@ -1196,9 +1056,9 @@ AcpiDmAscendingOp (
             switch (Op->Common.Parent->Common.AmlOpcode)
             {
             case AML_PACKAGE_OP:
-            case AML_VARIABLE_PACKAGE_OP:
+            case AML_VAR_PACKAGE_OP:
 
-                if (!(Op->Common.DisasmFlags & ACPI_PARSEOP_PARAMETER_LIST))
+                if (!(Op->Common.DisasmFlags & ACPI_PARSEOP_PARAMLIST))
                 {
                     AcpiOsPrintf ("\n");
                 }
@@ -1212,31 +1072,28 @@ AcpiDmAscendingOp (
         break;
     }
 
-    if (Op->Common.DisasmFlags & ACPI_PARSEOP_PARAMETER_LIST)
+    if (Op->Common.DisasmFlags & ACPI_PARSEOP_PARAMLIST)
     {
         if ((Op->Common.Next) &&
-            (Op->Common.Next->Common.DisasmFlags & ACPI_PARSEOP_PARAMETER_LIST))
+            (Op->Common.Next->Common.DisasmFlags & ACPI_PARSEOP_PARAMLIST))
         {
             return (AE_OK);
         }
 
         /*
          * The parent Op is guaranteed to be valid because of the flag
-         * ACPI_PARSEOP_PARAMETER_LIST -- which means that this op is part of
+         * ACPI_PARSEOP_PARAMLIST -- which means that this op is part of
          * a parameter list and thus has a valid parent.
          */
         ParentOp = Op->Common.Parent;
 
         /*
          * Just completed a parameter node for something like "Buffer (param)".
-         * Close the paren and open up the term list block with a brace.
-         *
-         * Switch predicates don't have a Next node but require a closing paren
-         * and opening brace.
+         * Close the paren and open up the term list block with a brace
          */
-        if (Op->Common.Next || Op->Common.DisasmOpcode == ACPI_DASM_SWITCH_PREDICATE)
+        if (Op->Common.Next)
         {
-            ASL_CV_CLOSE_PAREN (Op, Level);
+            AcpiOsPrintf (")");
 
             /*
              * Emit a description comment for a Name() operator that is a
@@ -1249,13 +1106,6 @@ AcpiDmAscendingOp (
                 AcpiDmPredefinedDescription (ParentOp);
             }
 
-            /* Correct the indentation level for Switch and Case predicates */
-
-            if (Op->Common.DisasmOpcode == ACPI_DASM_SWITCH_PREDICATE)
-            {
-                --Level;
-            }
-
             AcpiOsPrintf ("\n");
             AcpiDmIndent (Level - 1);
             AcpiOsPrintf ("{\n");
@@ -1263,8 +1113,7 @@ AcpiDmAscendingOp (
         else
         {
             ParentOp->Common.DisasmFlags |= ACPI_PARSEOP_EMPTY_TERMLIST;
-            ASL_CV_CLOSE_PAREN (Op, Level);
-            AcpiOsPrintf ("{");
+            AcpiOsPrintf (") {");
         }
     }
 
