@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2020, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,42 +111,6 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
 #include "acpi.h"
@@ -216,8 +180,8 @@ AcpiHwLowSetGpe (
     UINT32                  Action)
 {
     ACPI_GPE_REGISTER_INFO  *GpeRegisterInfo;
-    ACPI_STATUS             Status = AE_OK;
-    UINT64                  EnableMask;
+    ACPI_STATUS             Status;
+    UINT32                  EnableMask;
     UINT32                  RegisterBit;
 
 
@@ -254,7 +218,7 @@ AcpiHwLowSetGpe (
             return (AE_BAD_PARAMETER);
         }
 
-        ACPI_FALLTHROUGH;
+        /*lint -fallthrough */
 
     case ACPI_GPE_ENABLE:
 
@@ -272,12 +236,9 @@ AcpiHwLowSetGpe (
         return (AE_BAD_PARAMETER);
     }
 
-    if (!(RegisterBit & GpeRegisterInfo->MaskForRun))
-    {
-        /* Write the updated enable mask */
+    /* Write the updated enable mask */
 
-        Status = AcpiHwWrite (EnableMask, &GpeRegisterInfo->EnableAddress);
-    }
+    Status = AcpiHwWrite (EnableMask, &GpeRegisterInfo->EnableAddress);
     return (Status);
 }
 
@@ -342,7 +303,7 @@ AcpiHwGetGpeStatus (
     ACPI_GPE_EVENT_INFO     *GpeEventInfo,
     ACPI_EVENT_STATUS       *EventStatus)
 {
-    UINT64                  InByte;
+    UINT32                  InByte;
     UINT32                  RegisterBit;
     ACPI_GPE_REGISTER_INFO  *GpeRegisterInfo;
     ACPI_EVENT_STATUS       LocalEventStatus = 0;
@@ -380,13 +341,6 @@ AcpiHwGetGpeStatus (
         LocalEventStatus |= ACPI_EVENT_FLAG_ENABLED;
     }
 
-    /* GPE currently masked? (masked for runtime?) */
-
-    if (RegisterBit & GpeRegisterInfo->MaskForRun)
-    {
-        LocalEventStatus |= ACPI_EVENT_FLAG_MASKED;
-    }
-
     /* GPE enabled for wake? */
 
     if (RegisterBit & GpeRegisterInfo->EnableForWake)
@@ -558,7 +512,6 @@ AcpiHwEnableRuntimeGpeBlock (
     UINT32                  i;
     ACPI_STATUS             Status;
     ACPI_GPE_REGISTER_INFO  *GpeRegisterInfo;
-    UINT8                   EnableMask;
 
 
     /* NOTE: assumes that all GPEs are currently disabled */
@@ -575,9 +528,8 @@ AcpiHwEnableRuntimeGpeBlock (
 
         /* Enable all "runtime" GPEs in this register */
 
-        EnableMask = GpeRegisterInfo->EnableForRun &
-            ~GpeRegisterInfo->MaskForRun;
-        Status = AcpiHwGpeEnableWrite (EnableMask, GpeRegisterInfo);
+        Status = AcpiHwGpeEnableWrite (GpeRegisterInfo->EnableForRun,
+            GpeRegisterInfo);
         if (ACPI_FAILURE (Status))
         {
             return (Status);
@@ -635,58 +587,6 @@ AcpiHwEnableWakeupGpeBlock (
 }
 
 
-/******************************************************************************
- *
- * FUNCTION:    AcpiHwGetGpeBlockStatus
- *
- * PARAMETERS:  GpeXruptInfo    - GPE Interrupt info
- *              GpeBlock        - Gpe Block info
- *
- * RETURN:      Success
- *
- * DESCRIPTION: Produce a combined GPE status bits mask for the given block.
- *
- ******************************************************************************/
-
-static ACPI_STATUS
-AcpiHwGetGpeBlockStatus(
-    ACPI_GPE_XRUPT_INFO     *GpeXruptInfo,
-    ACPI_GPE_BLOCK_INFO     *GpeBlock,
-    void *RetPtr)
-{
-    ACPI_GPE_REGISTER_INFO  *GpeRegisterInfo;
-    UINT64                  InEnable;
-    UINT64                  InStatus;
-    ACPI_STATUS             Status;
-    UINT8                   *Ret = RetPtr;
-    UINT32                  i;
-
-
-    /* Examine each GPE Register within the block */
-
-    for (i = 0; i < GpeBlock->RegisterCount; i++)
-    {
-        GpeRegisterInfo = &GpeBlock->RegisterInfo[i];
-
-        Status = AcpiHwRead (&InEnable, &GpeRegisterInfo->EnableAddress);
-        if (ACPI_FAILURE (Status))
-        {
-            continue;
-        }
-
-        Status = AcpiHwRead (&InStatus, &GpeRegisterInfo->StatusAddress);
-        if (ACPI_FAILURE (Status))
-        {
-            continue;
-        }
-
-        *Ret |= InEnable & InStatus;
-    }
-
-    return (AE_OK);
-}
-
-
 /******************************************************************************
  *
  * FUNCTION:    AcpiHwDisableAllGpes
@@ -710,6 +610,7 @@ AcpiHwDisableAllGpes (
 
 
     Status = AcpiEvWalkGpeList (AcpiHwDisableGpeBlock, NULL);
+    Status = AcpiEvWalkGpeList (AcpiHwClearGpeBlock, NULL);
     return_ACPI_STATUS (Status);
 }
 
@@ -767,31 +668,4 @@ AcpiHwEnableAllWakeupGpes (
     return_ACPI_STATUS (Status);
 }
 
-
-/******************************************************************************
- *
- * FUNCTION:    AcpiHwCheckAllGpes
- *
- * PARAMETERS:  None
- *
- * RETURN:      Combined status of all GPEs
- *
- * DESCRIPTION: Check all enabled GPEs in all GPE blocks and return TRUE if the
- *              status bit is set for at least one of them of FALSE otherwise.
- *
- ******************************************************************************/
-
-UINT8
-AcpiHwCheckAllGpes (
-    void)
-{
-    UINT8                      Ret = 0;
-
-
-    ACPI_FUNCTION_TRACE (AcpiHwCheckAllGpes);
-
-    (void) AcpiEvWalkGpeList (AcpiHwGetGpeBlockStatus, &Ret);
-    return (Ret != 0);
-}
-
 #endif /* !ACPI_REDUCED_HARDWARE */
