@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2019, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,42 +111,6 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
 #include "acpi.h"
@@ -155,7 +119,6 @@
 #include "amlcode.h"
 #include "acnamesp.h"
 #include "acdispat.h"
-#include "acconvert.h"
 
 #define _COMPONENT          ACPI_PARSER
         ACPI_MODULE_NAME    ("psargs")
@@ -314,21 +277,21 @@ AcpiPsGetNextNamestring (
 
         /* Two name segments */
 
-        End += 1 + (2 * ACPI_NAMESEG_SIZE);
+        End += 1 + (2 * ACPI_NAME_SIZE);
         break;
 
-    case AML_MULTI_NAME_PREFIX:
+    case AML_MULTI_NAME_PREFIX_OP:
 
         /* Multiple name segments, 4 chars each, count in next byte */
 
-        End += 2 + (*(End + 1) * ACPI_NAMESEG_SIZE);
+        End += 2 + (*(End + 1) * ACPI_NAME_SIZE);
         break;
 
     default:
 
         /* Single name segment */
 
-        End += ACPI_NAMESEG_SIZE;
+        End += ACPI_NAME_SIZE;
         break;
     }
 
@@ -407,26 +370,23 @@ AcpiPsGetNextNamepath (
         PossibleMethodCall &&
         (Node->Type == ACPI_TYPE_METHOD))
     {
-        if ((GET_CURRENT_ARG_TYPE (WalkState->ArgTypes) == ARGP_SUPERNAME) ||
-            (GET_CURRENT_ARG_TYPE (WalkState->ArgTypes) == ARGP_TARGET))
+        if (GET_CURRENT_ARG_TYPE (WalkState->ArgTypes) == ARGP_SUPERNAME)
         {
             /*
-             * AcpiPsGetNextNamestring has increased the AML pointer past
-             * the method invocation namestring, so we need to restore the
-             * saved AML pointer back to the original method invocation
-             * namestring.
+             * AcpiPsGetNextNamestring has increased the AML pointer,
+             * so we need to restore the saved AML pointer for method call.
              */
             WalkState->ParserState.Aml = Start;
             WalkState->ArgCount = 1;
             AcpiPsInitOp (Arg, AML_INT_METHODCALL_OP);
+            return_ACPI_STATUS (AE_OK);
         }
 
         /* This name is actually a control method invocation */
 
         MethodDesc = AcpiNsGetAttachedObject (Node);
         ACPI_DEBUG_PRINT ((ACPI_DB_PARSE,
-            "Control Method invocation %4.4s - %p Desc %p Path=%p\n",
-            Node->Name.Ascii, Node, MethodDesc, Path));
+            "Control Method - %p Desc %p Path=%p\n", Node, MethodDesc, Path));
 
         NameOp = AcpiPsAllocOp (AML_INT_NAMEPATH_OP, Start);
         if (!NameOp)
@@ -478,7 +438,7 @@ AcpiPsGetNextNamepath (
 
         /* 2) NotFound during a CondRefOf(x) is ok by definition */
 
-        else if (WalkState->Op->Common.AmlOpcode == AML_CONDITIONAL_REF_OF_OP)
+        else if (WalkState->Op->Common.AmlOpcode == AML_COND_REF_OF_OP)
         {
             Status = AE_OK;
         }
@@ -490,7 +450,7 @@ AcpiPsGetNextNamepath (
          */
         else if ((Arg->Common.Parent) &&
             ((Arg->Common.Parent->Common.AmlOpcode == AML_PACKAGE_OP) ||
-             (Arg->Common.Parent->Common.AmlOpcode == AML_VARIABLE_PACKAGE_OP)))
+             (Arg->Common.Parent->Common.AmlOpcode == AML_VAR_PACKAGE_OP)))
         {
             Status = AE_OK;
         }
@@ -500,7 +460,7 @@ AcpiPsGetNextNamepath (
 
     if (ACPI_FAILURE (Status))
     {
-        ACPI_ERROR_NAMESPACE (WalkState->ScopeInfo, Path, Status);
+        ACPI_ERROR_NAMESPACE (Path, Status);
 
         if ((WalkState->ParseFlags & ACPI_PARSE_MODE_MASK) ==
             ACPI_PARSE_EXECUTE)
@@ -652,7 +612,6 @@ AcpiPsGetNextField (
     ACPI_FUNCTION_TRACE (PsGetNextField);
 
 
-    ASL_CV_CAPTURE_COMMENTS_ONLY (ParserState);
     Aml = ParserState->Aml;
 
     /* Determine field type */
@@ -699,7 +658,6 @@ AcpiPsGetNextField (
 
     /* Decode the field type */
 
-    ASL_CV_CAPTURE_COMMENTS_ONLY (ParserState);
     switch (Opcode)
     {
     case AML_INT_NAMEDFIELD_OP:
@@ -708,24 +666,7 @@ AcpiPsGetNextField (
 
         ACPI_MOVE_32_TO_32 (&Name, ParserState->Aml);
         AcpiPsSetName (Field, Name);
-        ParserState->Aml += ACPI_NAMESEG_SIZE;
-
-
-        ASL_CV_CAPTURE_COMMENTS_ONLY (ParserState);
-
-#ifdef ACPI_ASL_COMPILER
-        /*
-         * Because the package length isn't represented as a parse tree object,
-         * take comments surrounding this and add to the previously created
-         * parse node.
-         */
-        if (Field->Common.InlineComment)
-        {
-            Field->Common.NameComment = Field->Common.InlineComment;
-        }
-        Field->Common.InlineComment  = AcpiGbl_CurrentInlineComment;
-        AcpiGbl_CurrentInlineComment = NULL;
-#endif
+        ParserState->Aml += ACPI_NAME_SIZE;
 
         /* Get the length which is encoded as a package length */
 
@@ -783,12 +724,10 @@ AcpiPsGetNextField (
         {
             ParserState->Aml++;
 
-            ASL_CV_CAPTURE_COMMENTS_ONLY (ParserState);
             PkgEnd = ParserState->Aml;
             PkgLength = AcpiPsGetNextPackageLength (ParserState);
             PkgEnd += PkgLength;
 
-            ASL_CV_CAPTURE_COMMENTS_ONLY (ParserState);
             if (ParserState->Aml < PkgEnd)
             {
                 /* Non-empty list */
@@ -805,7 +744,6 @@ AcpiPsGetNextField (
                 Opcode = ACPI_GET8 (ParserState->Aml);
                 ParserState->Aml++;
 
-                ASL_CV_CAPTURE_COMMENTS_ONLY (ParserState);
                 switch (Opcode)
                 {
                 case AML_BYTE_OP:       /* AML_BYTEDATA_ARG */
@@ -834,7 +772,6 @@ AcpiPsGetNextField (
 
                 /* Fill in bytelist data */
 
-                ASL_CV_CAPTURE_COMMENTS_ONLY (ParserState);
                 Arg->Named.Value.Size = BufferLength;
                 Arg->Named.Data = ParserState->Aml;
             }
@@ -879,7 +816,7 @@ AcpiPsGetNextField (
  *
  * PARAMETERS:  WalkState           - Current state
  *              ParserState         - Current parser state object
- *              ArgType             - The argument type (AML_*_ARG)
+ *              ArgType             - The parser argument type (ARGP_*)
  *              ReturnArg           - Where the next arg is returned
  *
  * RETURN:      Status, and an op object containing the next argument.
@@ -906,10 +843,6 @@ AcpiPsGetNextArg (
     ACPI_FUNCTION_TRACE_PTR (PsGetNextArg, ParserState);
 
 
-    ACPI_DEBUG_PRINT ((ACPI_DB_PARSE,
-        "Expected argument type ARGP: %s (%2.2X)\n",
-        AcpiUtGetArgumentTypeName (ArgType), ArgType));
-
     switch (ArgType)
     {
     case ARGP_BYTEDATA:
@@ -993,13 +926,11 @@ AcpiPsGetNextArg (
         }
         break;
 
+    case ARGP_TARGET:
+    case ARGP_SUPERNAME:
     case ARGP_SIMPLENAME:
     case ARGP_NAME_OR_REF:
 
-        ACPI_DEBUG_PRINT ((ACPI_DB_PARSE,
-            "**** SimpleName/NameOrRef: %s (%2.2X)\n",
-            AcpiUtGetArgumentTypeName (ArgType), ArgType));
-
         Subop = AcpiPsPeekOpcode (ParserState);
         if (Subop == 0                  ||
             AcpiPsIsLeadingChar (Subop) ||
@@ -1014,49 +945,27 @@ AcpiPsGetNextArg (
                 return_ACPI_STATUS (AE_NO_MEMORY);
             }
 
-            Status = AcpiPsGetNextNamepath (WalkState, ParserState,
-                Arg, ACPI_NOT_METHOD_CALL);
-        }
-        else
-        {
-            /* Single complex argument, nothing returned */
+            /* SuperName allows argument to be a method call */
 
-            WalkState->ArgCount = 1;
-        }
-        break;
-
-    case ARGP_TARGET:
-    case ARGP_SUPERNAME:
-
-        ACPI_DEBUG_PRINT ((ACPI_DB_PARSE,
-            "**** Target/Supername: %s (%2.2X)\n",
-            AcpiUtGetArgumentTypeName (ArgType), ArgType));
-
-        Subop = AcpiPsPeekOpcode (ParserState);
-        if (Subop == 0                  ||
-            AcpiPsIsLeadingChar (Subop) ||
-            ACPI_IS_ROOT_PREFIX (Subop) ||
-            ACPI_IS_PARENT_PREFIX (Subop))
-        {
-            /* NULL target (zero). Convert to a NULL namepath */
-
-            Arg = AcpiPsAllocOp (AML_INT_NAMEPATH_OP, ParserState->Aml);
-            if (!Arg)
+            if (ArgType == ARGP_SUPERNAME)
             {
-                return_ACPI_STATUS (AE_NO_MEMORY);
+                Status = AcpiPsGetNextNamepath (WalkState, ParserState,
+                    Arg, ACPI_POSSIBLE_METHOD_CALL);
+
+                /*
+                 * If the SuperName argument is a method call, we have
+                 * already restored the AML pointer, just free this Arg
+                 */
+                if (Arg->Common.AmlOpcode == AML_INT_METHODCALL_OP)
+                {
+                    AcpiPsFreeOp (Arg);
+                    Arg = NULL;
+                }
             }
-
-            Status = AcpiPsGetNextNamepath (WalkState, ParserState,
-                Arg, ACPI_POSSIBLE_METHOD_CALL);
-
-            if (Arg->Common.AmlOpcode == AML_INT_METHODCALL_OP)
+            else
             {
-                /* Free method call op and corresponding namestring sub-ob */
-
-                AcpiPsFreeOp (Arg->Common.Value.Arg);
-                AcpiPsFreeOp (Arg);
-                Arg = NULL;
-                WalkState->ArgCount = 1;
+                Status = AcpiPsGetNextNamepath (WalkState, ParserState,
+                    Arg, ACPI_NOT_METHOD_CALL);
             }
         }
         else
@@ -1070,10 +979,6 @@ AcpiPsGetNextArg (
     case ARGP_DATAOBJ:
     case ARGP_TERMARG:
 
-        ACPI_DEBUG_PRINT ((ACPI_DB_PARSE,
-            "**** TermArg/DataObj: %s (%2.2X)\n",
-            AcpiUtGetArgumentTypeName (ArgType), ArgType));
-
         /* Single complex argument, nothing returned */
 
         WalkState->ArgCount = 1;
