@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2018, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,42 +111,6 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
 /*
@@ -163,8 +127,6 @@
 #include "acparser.h"
 #include "acdispat.h"
 #include "amlcode.h"
-#include "acconvert.h"
-#include "acnamesp.h"
 
 #define _COMPONENT          ACPI_PARSER
         ACPI_MODULE_NAME    ("psloop")
@@ -214,9 +176,6 @@ AcpiPsGetArguments (
     ACPI_FUNCTION_TRACE_PTR (PsGetArguments, WalkState);
 
 
-    ACPI_DEBUG_PRINT ((ACPI_DB_PARSE,
-        "Get arguments for opcode [%s]\n", Op->Common.AmlOpName));
-
     switch (Op->Common.AmlOpcode)
     {
     case AML_BYTE_OP:       /* AML_BYTEDATA_ARG */
@@ -252,22 +211,6 @@ AcpiPsGetArguments (
         {
             WalkState->Aml = WalkState->ParserState.Aml;
 
-            switch (Op->Common.AmlOpcode)
-            {
-            case AML_METHOD_OP:
-            case AML_BUFFER_OP:
-            case AML_PACKAGE_OP:
-            case AML_VARIABLE_PACKAGE_OP:
-            case AML_WHILE_OP:
-
-                break;
-
-            default:
-
-                ASL_CV_CAPTURE_COMMENTS (WalkState);
-                break;
-            }
-
             Status = AcpiPsGetNextArg (WalkState, &(WalkState->ParserState),
                 GET_CURRENT_ARG_TYPE (WalkState->ArgTypes), &Arg);
             if (ACPI_FAILURE (Status))
@@ -283,23 +226,12 @@ AcpiPsGetArguments (
             INCREMENT_ARG_LIST (WalkState->ArgTypes);
         }
 
-        ACPI_DEBUG_PRINT ((ACPI_DB_PARSE,
-            "Final argument count: %8.8X pass %u\n",
-            WalkState->ArgCount, WalkState->PassNumber));
 
         /*
-         * This case handles the legacy option that groups all module-level
-         * code blocks together and defers execution until all of the tables
-         * are loaded. Execute all of these blocks at this time.
-         * Execute any module-level code that was detected during the table
-         * load phase.
-         *
-         * Note: this option is deprecated and will be eliminated in the
-         * future. Use of this option can cause problems with AML code that
-         * depends upon in-order immediate execution of module-level code.
+         * Handle executable code at "module-level". This refers to
+         * executable opcodes that appear outside of any control method.
          */
-        if (!AcpiGbl_ExecuteTablesAsMethods &&
-            (WalkState->PassNumber <= ACPI_IMODE_LOAD_PASS2) &&
+        if ((WalkState->PassNumber <= ACPI_IMODE_LOAD_PASS2) &&
             ((WalkState->ParseFlags & ACPI_PARSE_DISASSEMBLE) == 0))
         {
             /*
@@ -386,16 +318,12 @@ AcpiPsGetArguments (
 
         case AML_BUFFER_OP:
         case AML_PACKAGE_OP:
-        case AML_VARIABLE_PACKAGE_OP:
+        case AML_VAR_PACKAGE_OP:
 
             if ((Op->Common.Parent) &&
                 (Op->Common.Parent->Common.AmlOpcode == AML_NAME_OP) &&
                 (WalkState->PassNumber <= ACPI_IMODE_LOAD_PASS2))
             {
-                ACPI_DEBUG_PRINT ((ACPI_DB_PARSE,
-                    "Setup Package/Buffer: Pass %u, AML Ptr: %p\n",
-                    WalkState->PassNumber, AmlOpStart));
-
                 /*
                  * Skip parsing of Buffers and Packages because we don't have
                  * enough info in the first pass to parse them correctly.
@@ -449,16 +377,6 @@ AcpiPsGetArguments (
  *              object to the global list. Note, the mutex field of the method
  *              object is used to link multiple module-level code objects.
  *
- * NOTE: In this legacy option, each block of detected executable AML
- * code that is outside of any control method is wrapped with a temporary
- * control method object and placed on a global list below.
- *
- * This function executes the module-level code for all tables only after
- * all of the tables have been loaded. It is a legacy option and is
- * not compatible with other ACPI implementations. See AcpiNsLoadTable.
- *
- * This function will be removed when the legacy option is removed.
- *
  ******************************************************************************/
 
 static void
@@ -566,7 +484,6 @@ AcpiPsParseLoop (
     ACPI_PARSE_OBJECT       *Op = NULL;     /* current op */
     ACPI_PARSE_STATE        *ParserState;
     UINT8                   *AmlOpStart = NULL;
-    UINT8                   OpcodeLength;
 
 
     ACPI_FUNCTION_TRACE_PTR (PsParseLoop, WalkState);
@@ -580,7 +497,7 @@ AcpiPsParseLoop (
     ParserState = &WalkState->ParserState;
     WalkState->ArgTypes = 0;
 
-#ifndef ACPI_CONSTANT_EVAL_ONLY
+#if (!defined (ACPI_NO_METHOD_EXECUTION) && !defined (ACPI_CONSTANT_EVAL_ONLY))
 
     if (WalkState->WalkType & ACPI_WALK_METHOD_RESTART)
     {
@@ -639,26 +556,12 @@ AcpiPsParseLoop (
 
     while ((ParserState->Aml < ParserState->AmlEnd) || (Op))
     {
-        ASL_CV_CAPTURE_COMMENTS (WalkState);
-
         AmlOpStart = ParserState->Aml;
         if (!Op)
         {
             Status = AcpiPsCreateOp (WalkState, AmlOpStart, &Op);
             if (ACPI_FAILURE (Status))
             {
-                /*
-                 * ACPI_PARSE_MODULE_LEVEL means that we are loading a table by
-                 * executing it as a control method. However, if we encounter
-                 * an error while loading the table, we need to keep trying to
-                 * load the table rather than aborting the table load. Set the
-                 * status to AE_OK to proceed with the table load.
-                 */
-                if ((WalkState->ParseFlags & ACPI_PARSE_MODULE_LEVEL) &&
-                    ((Status == AE_ALREADY_EXISTS) || (Status == AE_NOT_FOUND)))
-                {
-                    Status = AE_OK;
-                }
                 if (Status == AE_CTRL_PARSE_CONTINUE)
                 {
                     continue;
@@ -679,32 +582,6 @@ AcpiPsParseLoop (
                 {
                     return_ACPI_STATUS (Status);
                 }
-                if (AcpiNsOpensScope (
-                    AcpiPsGetOpcodeInfo (WalkState->Opcode)->ObjectType))
-                {
-                    /*
-                     * If the scope/device op fails to parse, skip the body of
-                     * the scope op because the parse failure indicates that
-                     * the device may not exist.
-                     */
-                    ACPI_INFO (("Skipping parse of AML opcode: %s (0x%4.4X)",
-                        AcpiPsGetOpcodeName (WalkState->Opcode), WalkState->Opcode));
-
-                    /*
-                     * Determine the opcode length before skipping the opcode.
-                     * An opcode can be 1 byte or 2 bytes in length.
-                     */
-                    OpcodeLength = 1;
-                    if ((WalkState->Opcode & 0xFF00) == AML_EXTENDED_OPCODE)
-                    {
-                        OpcodeLength = 2;
-                    }
-                    WalkState->ParserState.Aml = WalkState->Aml + OpcodeLength;
-
-                    WalkState->ParserState.Aml =
-                        AcpiPsGetNextPackageEnd(&WalkState->ParserState);
-                    WalkState->Aml = WalkState->ParserState.Aml;
-                }
 
                 continue;
             }
@@ -712,26 +589,12 @@ AcpiPsParseLoop (
             AcpiExStartTraceOpcode (Op, WalkState);
         }
 
+
         /*
          * Start ArgCount at zero because we don't know if there are
          * any args yet
          */
-        WalkState->ArgCount = 0;
-
-        switch (Op->Common.AmlOpcode)
-        {
-        case AML_BYTE_OP:
-        case AML_WORD_OP:
-        case AML_DWORD_OP:
-        case AML_QWORD_OP:
-
-            break;
-
-        default:
-
-            ASL_CV_CAPTURE_COMMENTS (WalkState);
-            break;
-        }
+        WalkState->ArgCount  = 0;
 
         /* Are there any arguments that must be processed? */
 
@@ -747,41 +610,13 @@ AcpiPsParseLoop (
                 {
                     return_ACPI_STATUS (Status);
                 }
-                if ((WalkState->ControlState) &&
-                    ((WalkState->ControlState->Control.Opcode == AML_IF_OP) ||
-                    (WalkState->ControlState->Control.Opcode == AML_WHILE_OP)))
-                {
-                    /*
-                     * If the if/while op fails to parse, we will skip parsing
-                     * the body of the op.
-                     */
-                    ParserState->Aml =
-                        WalkState->ControlState->Control.AmlPredicateStart + 1;
-                    ParserState->Aml =
-                        AcpiPsGetNextPackageEnd (ParserState);
-                    WalkState->Aml = ParserState->Aml;
 
-                    ACPI_ERROR ((AE_INFO, "Skipping While/If block"));
-                    if (*WalkState->Aml == AML_ELSE_OP)
-                    {
-                        ACPI_ERROR ((AE_INFO, "Skipping Else block"));
-                        WalkState->ParserState.Aml = WalkState->Aml + 1;
-                        WalkState->ParserState.Aml =
-                            AcpiPsGetNextPackageEnd (ParserState);
-                        WalkState->Aml = ParserState->Aml;
-                    }
-                    ACPI_FREE(AcpiUtPopGenericState (&WalkState->ControlState));
-                }
-                Op = NULL;
                 continue;
             }
         }
 
         /* Check for arguments that need to be processed */
 
-        ACPI_DEBUG_PRINT ((ACPI_DB_PARSE,
-            "Parseloop: argument count: %8.8X\n", WalkState->ArgCount));
-
         if (WalkState->ArgCount)
         {
             /*
@@ -861,22 +696,6 @@ AcpiPsParseLoop (
             {
                 Status = AE_OK;
             }
-            else if ((WalkState->ParseFlags & ACPI_PARSE_MODULE_LEVEL) &&
-                (ACPI_AML_EXCEPTION(Status) || Status == AE_ALREADY_EXISTS ||
-                Status == AE_NOT_FOUND))
-            {
-                /*
-                 * ACPI_PARSE_MODULE_LEVEL flag means that we are currently
-                 * loading a table by executing it as a control method.
-                 * However, if we encounter an error while loading the table,
-                 * we need to keep trying to load the table rather than
-                 * aborting the table load (setting the status to AE_OK
-                 * continues the table load). If we get a failure at this
-                 * point, it means that the dispatcher got an error while
-                 * trying to execute the Op.
-                 */
-                Status = AE_OK;
-            }
         }
 
         Status = AcpiPsCompleteOp (WalkState, &Op, Status);
