@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2017, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,49 +111,12 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
 #include "acpi.h"
 #include "accommon.h"
 #include "acparser.h"
 #include "amlcode.h"
-#include "acconvert.h"
 
 #define _COMPONENT          ACPI_PARSER
         ACPI_MODULE_NAME    ("psobject")
@@ -237,23 +200,12 @@ AcpiPsGetAmlOpcode (
                 WalkState->Opcode,
                 (UINT32) (AmlOffset + sizeof (ACPI_TABLE_HEADER)));
 
-            ACPI_ERROR ((AE_INFO,
-                "Aborting disassembly, AML byte code is corrupt"));
-
             /* Dump the context surrounding the invalid opcode */
 
             AcpiUtDumpBuffer (((UINT8 *) WalkState->ParserState.Aml - 16),
                 48, DB_BYTE_DISPLAY,
                 (AmlOffset + sizeof (ACPI_TABLE_HEADER) - 16));
             AcpiOsPrintf (" */\n");
-
-            /*
-             * Just abort the disassembly, cannot continue because the
-             * parser is essentially lost. The disassembler can then
-             * randomly fail because an ill-constructed parse tree
-             * can result.
-             */
-            return_ACPI_STATUS (AE_AML_BAD_OPCODE);
 #endif
         }
 
@@ -321,7 +273,6 @@ AcpiPsBuildNamedOp (
     while (GET_CURRENT_ARG_TYPE (WalkState->ArgTypes) &&
           (GET_CURRENT_ARG_TYPE (WalkState->ArgTypes) != ARGP_NAME))
     {
-        ASL_CV_CAPTURE_COMMENTS (WalkState);
         Status = AcpiPsGetNextArg (WalkState, &(WalkState->ParserState),
             GET_CURRENT_ARG_TYPE (WalkState->ArgTypes), &Arg);
         if (ACPI_FAILURE (Status))
@@ -333,18 +284,6 @@ AcpiPsBuildNamedOp (
         INCREMENT_ARG_LIST (WalkState->ArgTypes);
     }
 
-    /* are there any inline comments associated with the NameSeg?? If so, save this. */
-
-    ASL_CV_CAPTURE_COMMENTS (WalkState);
-
-#ifdef ACPI_ASL_COMPILER
-    if (AcpiGbl_CurrentInlineComment != NULL)
-    {
-        UnnamedOp->Common.NameComment = AcpiGbl_CurrentInlineComment;
-        AcpiGbl_CurrentInlineComment = NULL;
-    }
-#endif
-
     /*
      * Make sure that we found a NAME and didn't run out of arguments
      */
@@ -390,28 +329,6 @@ AcpiPsBuildNamedOp (
 
     AcpiPsAppendArg (*Op, UnnamedOp->Common.Value.Arg);
 
-#ifdef ACPI_ASL_COMPILER
-
-    /* save any comments that might be associated with UnnamedOp. */
-
-    (*Op)->Common.InlineComment     = UnnamedOp->Common.InlineComment;
-    (*Op)->Common.EndNodeComment    = UnnamedOp->Common.EndNodeComment;
-    (*Op)->Common.CloseBraceComment = UnnamedOp->Common.CloseBraceComment;
-    (*Op)->Common.NameComment       = UnnamedOp->Common.NameComment;
-    (*Op)->Common.CommentList       = UnnamedOp->Common.CommentList;
-    (*Op)->Common.EndBlkComment     = UnnamedOp->Common.EndBlkComment;
-    (*Op)->Common.CvFilename        = UnnamedOp->Common.CvFilename;
-    (*Op)->Common.CvParentFilename  = UnnamedOp->Common.CvParentFilename;
-    (*Op)->Named.Aml                = UnnamedOp->Common.Aml;
-
-    UnnamedOp->Common.InlineComment     = NULL;
-    UnnamedOp->Common.EndNodeComment    = NULL;
-    UnnamedOp->Common.CloseBraceComment = NULL;
-    UnnamedOp->Common.NameComment       = NULL;
-    UnnamedOp->Common.CommentList       = NULL;
-    UnnamedOp->Common.EndBlkComment     = NULL;
-#endif
-
     if ((*Op)->Common.AmlOpcode == AML_REGION_OP ||
         (*Op)->Common.AmlOpcode == AML_DATA_REGION_OP)
     {
@@ -469,10 +386,6 @@ AcpiPsCreateOp (
     {
         return_ACPI_STATUS (AE_CTRL_PARSE_CONTINUE);
     }
-    if (ACPI_FAILURE (Status))
-    {
-        return_ACPI_STATUS (Status);
-    }
 
     /* Create Op structure and append to parent's argument list */
 
@@ -487,26 +400,6 @@ AcpiPsCreateOp (
     {
         Status = AcpiPsBuildNamedOp (WalkState, AmlOpStart, Op, &NamedOp);
         AcpiPsFreeOp (Op);
-
-#ifdef ACPI_ASL_COMPILER
-        if (AcpiGbl_DisasmFlag && WalkState->Opcode == AML_EXTERNAL_OP &&
-            Status == AE_NOT_FOUND)
-        {
-            /*
-             * If parsing of AML_EXTERNAL_OP's name path fails, then skip
-             * past this opcode and keep parsing. This is a much better
-             * alternative than to abort the entire disassembler. At this
-             * point, the ParserState is at the end of the namepath of the
-             * external declaration opcode. Setting WalkState->Aml to
-             * WalkState->ParserState.Aml + 2 moves increments the
-             * WalkState->Aml past the object type and the paramcount of the
-             * external opcode.
-             */
-            WalkState->Aml = WalkState->ParserState.Aml + 2;
-            WalkState->ParserState.Aml = WalkState->Aml;
-            return_ACPI_STATUS (AE_CTRL_PARSE_CONTINUE);
-        }
-#endif
         if (ACPI_FAILURE (Status))
         {
             return_ACPI_STATUS (Status);
@@ -552,13 +445,7 @@ AcpiPsCreateOp (
                 Op->Common.Flags |= ACPI_PARSEOP_TARGET;
             }
         }
-
-        /*
-         * Special case for both Increment() and Decrement(), where
-         * the lone argument is both a source and a target.
-         */
-        else if ((ParentScope->Common.AmlOpcode == AML_INCREMENT_OP) ||
-                (ParentScope->Common.AmlOpcode == AML_DECREMENT_OP))
+        else if (ParentScope->Common.AmlOpcode == AML_INCREMENT_OP)
         {
             Op->Common.Flags |= ACPI_PARSEOP_TARGET;
         }
