@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2019, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,42 +111,6 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
 #include "acpi.h"
@@ -307,9 +271,6 @@ AcpiPsExecuteMethod (
         goto Cleanup;
     }
 
-    WalkState->MethodPathname = Info->FullPathname;
-    WalkState->MethodIsNested = FALSE;
-
     if (Info->ObjDesc->Method.InfoFlags & ACPI_METHOD_MODULE_LEVEL)
     {
         WalkState->ParseFlags |= ACPI_PARSE_MODULE_LEVEL;
@@ -384,103 +345,6 @@ Cleanup:
 }
 
 
-/*******************************************************************************
- *
- * FUNCTION:    AcpiPsExecuteTable
- *
- * PARAMETERS:  Info            - Method info block, contains:
- *              Node            - Node to where the is entered into the
- *                                namespace
- *              ObjDesc         - Pseudo method object describing the AML
- *                                code of the entire table
- *              PassNumber      - Parse or execute pass
- *
- * RETURN:      Status
- *
- * DESCRIPTION: Execute a table
- *
- ******************************************************************************/
-
-ACPI_STATUS
-AcpiPsExecuteTable (
-    ACPI_EVALUATE_INFO      *Info)
-{
-    ACPI_STATUS             Status;
-    ACPI_PARSE_OBJECT       *Op = NULL;
-    ACPI_WALK_STATE         *WalkState = NULL;
-
-
-    ACPI_FUNCTION_TRACE (PsExecuteTable);
-
-
-    /* Create and init a Root Node */
-
-    Op = AcpiPsCreateScopeOp (Info->ObjDesc->Method.AmlStart);
-    if (!Op)
-    {
-        Status = AE_NO_MEMORY;
-        goto Cleanup;
-    }
-
-    /* Create and initialize a new walk state */
-
-    WalkState = AcpiDsCreateWalkState (
-        Info->ObjDesc->Method.OwnerId, NULL, NULL, NULL);
-    if (!WalkState)
-    {
-        Status = AE_NO_MEMORY;
-        goto Cleanup;
-    }
-
-    Status = AcpiDsInitAmlWalk (WalkState, Op, Info->Node,
-        Info->ObjDesc->Method.AmlStart,
-        Info->ObjDesc->Method.AmlLength, Info, Info->PassNumber);
-    if (ACPI_FAILURE (Status))
-    {
-        goto Cleanup;
-    }
-
-    WalkState->MethodPathname = Info->FullPathname;
-    WalkState->MethodIsNested = FALSE;
-
-    if (Info->ObjDesc->Method.InfoFlags & ACPI_METHOD_MODULE_LEVEL)
-    {
-        WalkState->ParseFlags |= ACPI_PARSE_MODULE_LEVEL;
-    }
-
-    /* Info->Node is the default location to load the table  */
-
-    if (Info->Node && Info->Node != AcpiGbl_RootNode)
-    {
-        Status = AcpiDsScopeStackPush (
-            Info->Node, ACPI_TYPE_METHOD, WalkState);
-        if (ACPI_FAILURE (Status))
-        {
-            goto Cleanup;
-        }
-    }
-
-    /*
-     * Parse the AML, WalkState will be deleted by ParseAml
-     */
-    AcpiExEnterInterpreter ();
-    Status = AcpiPsParseAml (WalkState);
-    AcpiExExitInterpreter ();
-    WalkState = NULL;
-
-Cleanup:
-    if (WalkState)
-    {
-        AcpiDsDeleteWalkState (WalkState);
-    }
-    if (Op)
-    {
-        AcpiPsDeleteParseTree (Op);
-    }
-    return_ACPI_STATUS (Status);
-}
-
-
 /*******************************************************************************
  *
  * FUNCTION:    AcpiPsUpdateParameterList
