@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -113,8 +113,6 @@
  *
  *****************************************************************************/
 
-#define __UTALLOC_C__
-
 #include "acpi.h"
 #include "accommon.h"
 #include "acdebug.h"
@@ -153,7 +151,7 @@ AcpiOsAllocateZeroed (
     {
         /* Clear the memory block */
 
-        ACPI_MEMSET (Allocation, 0, Size);
+        memset (Allocation, 0, Size);
     }
 
     return (Allocation);
@@ -184,35 +182,35 @@ AcpiUtCreateCaches (
     /* Object Caches, for frequently used objects */
 
     Status = AcpiOsCreateCache ("Acpi-Namespace", sizeof (ACPI_NAMESPACE_NODE),
-                ACPI_MAX_NAMESPACE_CACHE_DEPTH, &AcpiGbl_NamespaceCache);
+        ACPI_MAX_NAMESPACE_CACHE_DEPTH, &AcpiGbl_NamespaceCache);
     if (ACPI_FAILURE (Status))
     {
         return (Status);
     }
 
     Status = AcpiOsCreateCache ("Acpi-State", sizeof (ACPI_GENERIC_STATE),
-                ACPI_MAX_STATE_CACHE_DEPTH, &AcpiGbl_StateCache);
+        ACPI_MAX_STATE_CACHE_DEPTH, &AcpiGbl_StateCache);
     if (ACPI_FAILURE (Status))
     {
         return (Status);
     }
 
     Status = AcpiOsCreateCache ("Acpi-Parse", sizeof (ACPI_PARSE_OBJ_COMMON),
-                ACPI_MAX_PARSE_CACHE_DEPTH, &AcpiGbl_PsNodeCache);
+        ACPI_MAX_PARSE_CACHE_DEPTH, &AcpiGbl_PsNodeCache);
     if (ACPI_FAILURE (Status))
     {
         return (Status);
     }
 
     Status = AcpiOsCreateCache ("Acpi-ParseExt", sizeof (ACPI_PARSE_OBJ_NAMED),
-                ACPI_MAX_EXTPARSE_CACHE_DEPTH, &AcpiGbl_PsNodeExtCache);
+        ACPI_MAX_EXTPARSE_CACHE_DEPTH, &AcpiGbl_PsNodeExtCache);
     if (ACPI_FAILURE (Status))
     {
         return (Status);
     }
 
     Status = AcpiOsCreateCache ("Acpi-Operand", sizeof (ACPI_OPERAND_OBJECT),
-                ACPI_MAX_OBJECT_CACHE_DEPTH, &AcpiGbl_OperandCache);
+        ACPI_MAX_OBJECT_CACHE_DEPTH, &AcpiGbl_OperandCache);
     if (ACPI_FAILURE (Status))
     {
         return (Status);
@@ -224,14 +222,14 @@ AcpiUtCreateCaches (
     /* Memory allocation lists */
 
     Status = AcpiUtCreateList ("Acpi-Global", 0,
-                &AcpiGbl_GlobalList);
+        &AcpiGbl_GlobalList);
     if (ACPI_FAILURE (Status))
     {
         return (Status);
     }
 
     Status = AcpiUtCreateList ("Acpi-Namespace", sizeof (ACPI_NAMESPACE_NODE),
-                &AcpiGbl_NsNodeList);
+        &AcpiGbl_NsNodeList);
     if (ACPI_FAILURE (Status))
     {
         return (Status);
@@ -261,9 +259,10 @@ AcpiUtDeleteCaches (
 #ifdef ACPI_DBG_TRACK_ALLOCATIONS
     char                    Buffer[7];
 
+
     if (AcpiGbl_DisplayFinalMemStats)
     {
-        ACPI_STRCPY (Buffer, "MEMORY");
+        strcpy (Buffer, "MEMORY");
         (void) AcpiDbDisplayStatistics (Buffer);
     }
 #endif
@@ -433,6 +432,6 @@ AcpiUtInitializeBuffer (
 
     /* Have a valid buffer, clear it */
 
-    ACPI_MEMSET (Buffer->Pointer, 0, RequiredLength);
+    memset (Buffer->Pointer, 0, RequiredLength);
     return (AE_OK);
 }
