@@ -343,6 +343,15 @@ AcpiUtRepairName (
     ACPI_FUNCTION_NAME (UtRepairName);
 
 
+    /*
+     * Special case for the root node. This can happen if we get an
+     * error during the execution of module-level code.
+     */
+    if (ACPI_COMPARE_NAME (Name, "\\___"))
+    {
+        return;
+    }
+
     ACPI_MOVE_NAME (&OriginalName, Name);
 
     /* Check each character in the name */
