@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -113,8 +113,6 @@
  *
  *****************************************************************************/
 
-
-#define __UTXFINIT_C__
 #define EXPORT_ACPI_INTERFACES
 
 #include "acpi.h"
@@ -127,6 +125,11 @@
 #define _COMPONENT          ACPI_UTILITIES
         ACPI_MODULE_NAME    ("utxfinit")
 
+/* For AcpiExec only */
+void
+AeDoObjectOverrides (
+    void);
+
 
 /*******************************************************************************
  *
@@ -201,16 +204,24 @@ AcpiInitializeSubsystem (
         return_ACPI_STATUS (Status);
     }
 
-    /* If configured, initialize the AML debugger */
-
-#ifdef ACPI_DEBUGGER
-    Status = AcpiDbInitialize ();
-    if (ACPI_FAILURE (Status))
+    if (!AcpiGbl_OverrideDefaultRegionHandlers)
     {
-        ACPI_EXCEPTION ((AE_INFO, Status, "During Debugger initialization"));
-        return_ACPI_STATUS (Status);
+        /*
+         * Install the default operation region handlers. These are the
+         * handlers that are defined by the ACPI specification to be
+         * "always accessible" -- namely, SystemMemory, SystemIO, and
+         * PCI_Config. This also means that no _REG methods need to be
+         * run for these address spaces. We need to have these handlers
+         * installed before any AML code can be executed, especially any
+         * module-level code (11/2015).
+         */
+        Status = AcpiEvInstallRegionHandlers ();
+        if (ACPI_FAILURE (Status))
+        {
+            ACPI_EXCEPTION ((AE_INFO, Status, "During Region initialization"));
+            return_ACPI_STATUS (Status);
+        }
     }
-#endif
 
     return_ACPI_STATUS (AE_OK);
 }
@@ -241,6 +252,33 @@ AcpiEnableSubsystem (
     ACPI_FUNCTION_TRACE (AcpiEnableSubsystem);
 
 
+    /*
+     * The early initialization phase is complete. The namespace is loaded,
+     * and we can now support address spaces other than Memory, I/O, and
+     * PCI_Config.
+     */
+    AcpiGbl_EarlyInitialization = FALSE;
+
+    if (AcpiGbl_OverrideDefaultRegionHandlers)
+    {
+        /*
+         * Install the default operation region handlers. These are the
+         * handlers that are defined by the ACPI specification to be
+         * "always accessible" -- namely, SystemMemory, SystemIO, and
+         * PCI_Config. This also means that no _REG methods need to be
+         * run for these address spaces. We need to have these handlers
+         * installed before any AML code can be executed, especially any
+         * module-level code (11/2015).
+         */
+        Status = AcpiEvInstallRegionHandlers ();
+        if (ACPI_FAILURE (Status))
+        {
+            ACPI_EXCEPTION ((AE_INFO, Status, "During Region initialization"));
+            return_ACPI_STATUS (Status);
+        }
+    }
+
+
 #if (!ACPI_REDUCED_HARDWARE)
 
     /* Enable ACPI mode */
@@ -263,33 +301,16 @@ AcpiEnableSubsystem (
      * Obtain a permanent mapping for the FACS. This is required for the
      * Global Lock and the Firmware Waking Vector
      */
-    Status = AcpiTbInitializeFacs ();
-    if (ACPI_FAILURE (Status))
+    if (!(Flags & ACPI_NO_FACS_INIT))
     {
-        ACPI_WARNING ((AE_INFO, "Could not map the FACS table"));
-        return_ACPI_STATUS (Status);
-    }
-
-#endif /* !ACPI_REDUCED_HARDWARE */
-
-    /*
-     * Install the default OpRegion handlers. These are installed unless
-     * other handlers have already been installed via the
-     * InstallAddressSpaceHandler interface.
-     */
-    if (!(Flags & ACPI_NO_ADDRESS_SPACE_INIT))
-    {
-        ACPI_DEBUG_PRINT ((ACPI_DB_EXEC,
-            "[Init] Installing default address space handlers\n"));
-
-        Status = AcpiEvInstallRegionHandlers ();
+        Status = AcpiTbInitializeFacs ();
         if (ACPI_FAILURE (Status))
         {
+            ACPI_WARNING ((AE_INFO, "Could not map the FACS table"));
             return_ACPI_STATUS (Status);
         }
     }
 
-#if (!ACPI_REDUCED_HARDWARE)
     /*
      * Initialize ACPI Event handling (Fixed and General Purpose)
      *
@@ -382,6 +403,14 @@ AcpiInitializeObjects (
         }
     }
 
+#ifdef ACPI_EXEC_APP
+    /*
+     * This call implements the "initialization file" option for AcpiExec.
+     * This is the precise point that we want to perform the overrides.
+     */
+    AeDoObjectOverrides ();
+#endif
+
     /*
      * Execute any module-level code that was detected during the table load
      * phase. Although illegal since ACPI 2.0, there are many machines that
@@ -389,8 +418,15 @@ AcpiInitializeObjects (
      * outside of any control method is wrapped with a temporary control
      * method object and placed on a global list. The methods on this list
      * are executed below.
+     *
+     * This case executes the module-level code for all tables only after
+     * all of the tables have been loaded. It is a legacy option and is
+     * not compatible with other ACPI implementations. See AcpiNsLoadTable.
      */
-    AcpiNsExecModuleCodeList ();
+    if (AcpiGbl_GroupModuleLevelCode)
+    {
+        AcpiNsExecModuleCodeList ();
+    }
 
     /*
      * Initialize the objects that remain uninitialized. This runs the
