@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2016, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -250,22 +250,6 @@ void
 AcpiTbUninstallTable (
     ACPI_TABLE_DESC        *TableDesc);
 
-ACPI_STATUS
-AcpiTbLoadTable (
-    UINT32                  TableIndex,
-    ACPI_NAMESPACE_NODE     *ParentNode);
-
-ACPI_STATUS
-AcpiTbInstallAndLoadTable (
-    ACPI_PHYSICAL_ADDRESS   Address,
-    UINT8                   Flags,
-    BOOLEAN                 Override,
-    UINT32                  *TableIndex);
-
-ACPI_STATUS
-AcpiTbUnloadTable (
-    UINT32                  TableIndex);
-
 void
 AcpiTbTerminate (
     void);
@@ -324,18 +308,19 @@ AcpiTbInstallTableWithOverride (
     BOOLEAN                 Override,
     UINT32                  *TableIndex);
 
+ACPI_STATUS
+AcpiTbInstallFixedTable (
+    ACPI_PHYSICAL_ADDRESS   Address,
+    char                    *Signature,
+    UINT32                  *TableIndex);
+
 ACPI_STATUS
 AcpiTbParseRootTable (
     ACPI_PHYSICAL_ADDRESS   RsdpAddress);
 
-ACPI_STATUS
-AcpiTbGetTable (
-    ACPI_TABLE_DESC        *TableDesc,
-    ACPI_TABLE_HEADER      **OutTable);
-
-void
-AcpiTbPutTable (
-    ACPI_TABLE_DESC        *TableDesc);
+BOOLEAN
+AcpiIsValidSignature (
+    char                    *Signature);
 
 
 /*
