@@ -192,7 +192,7 @@
 #define AML_CREATE_WORD_FIELD_OP    (UINT16) 0x8b
 #define AML_CREATE_BYTE_FIELD_OP    (UINT16) 0x8c
 #define AML_CREATE_BIT_FIELD_OP     (UINT16) 0x8d
-#define AML_TYPE_OP                 (UINT16) 0x8e
+#define AML_OBJECT_TYPE_OP          (UINT16) 0x8e
 #define AML_CREATE_QWORD_FIELD_OP   (UINT16) 0x8f     /* ACPI 2.0 */
 #define AML_LAND_OP                 (UINT16) 0x90
 #define AML_LOR_OP                  (UINT16) 0x91
@@ -313,7 +313,8 @@
 #define ARGP_TERMLIST               0x0F
 #define ARGP_WORDDATA               0x10
 #define ARGP_QWORDDATA              0x11
-#define ARGP_SIMPLENAME             0x12
+#define ARGP_SIMPLENAME             0x12 /* NameString | LocalTerm | ArgTerm */
+#define ARGP_NAME_OR_REF            0x13 /* For ObjectType only */
 
 /*
  * Resolved argument types for the AML Interpreter
