@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2016, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -115,7 +115,7 @@
 
 #include "acpidump.h"
 
-#if defined(__FreeBSD__) || defined(__FreeBSD_kernel__) || defined (__DragonFly__)
+#if defined(__FreeBSD__) || defined(__FreeBSD_kernel__)
 #include <kenv.h>
 #endif
 #include <unistd.h>
@@ -448,7 +448,7 @@ static ACPI_STATUS
 OslTableInitialize (
     void)
 {
-#if defined(__FreeBSD__) || defined(__FreeBSD_kernel__) || defined(__DragonFly__)
+#if defined(__FreeBSD__) || defined(__FreeBSD_kernel__)
     char                    Buffer[32];
 #endif
     ACPI_TABLE_HEADER       *MappedTable;
@@ -458,9 +458,7 @@ OslTableInitialize (
     ACPI_SIZE               RsdpSize;
     ACPI_STATUS             Status;
     u_long                  Address = 0;
-#if defined(SYSTEM_SYSCTL)
     size_t                  Length = sizeof (Address);
-#endif
 
 
     /* Get main ACPI tables from memory on first invocation of this function */
@@ -476,13 +474,12 @@ OslTableInitialize (
     {
         Address = Gbl_RsdpBase;
     }
-#if defined(__FreeBSD__) || defined(__FreeBSD_kernel__) || defined (__DragonFly__)
+#if defined(__FreeBSD__) || defined(__FreeBSD_kernel__)
     else if (kenv (KENV_GET, SYSTEM_KENV, Buffer, sizeof (Buffer)) > 0)
     {
         Address = strtoul (Buffer, NULL, 0);
     }
 #endif
-#if defined(SYSTEM_SYSCTL)
     if (!Address)
     {
         if (sysctlbyname (SYSTEM_SYSCTL, &Address, &Length, NULL, 0) != 0)
@@ -490,7 +487,6 @@ OslTableInitialize (
             Address = 0;
         }
     }
-#endif
     if (Address)
     {
         RsdpBase = Address;
