@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -147,12 +147,6 @@ AbCompareAmlFiles (
     char                    *File1Path,
     char                    *File2Path);
 
-int
-AbExtractAmlFile (
-    char                    *TableSig,
-    char                    *File1Path,
-    char                    *File2Path);
-
 int
 AbDumpAmlFile (
     char                    *File1Path,
