@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2017, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,45 +111,10 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
 #include "aecommon.h"
+#include "errno.h"
 
 #define _COMPONENT          ACPI_TOOLS
         ACPI_MODULE_NAME    ("aemain")
@@ -166,6 +131,7 @@
  * Windows: The setargv.obj module must be linked in to automatically
  * expand wildcards.
  */
+extern BOOLEAN              AcpiGbl_DebugTimeout;
 
 /* Local prototypes */
 
@@ -174,6 +140,10 @@ AeDoOptions (
     int                     argc,
     char                    **argv);
 
+static ACPI_STATUS
+AcpiDbRunBatchMode (
+    void);
+
 
 #define AE_BUFFER_SIZE              1024
 #define ASL_MAX_FILES               256
@@ -189,7 +159,6 @@ AeDoOptions (
 
 UINT8                       AcpiGbl_RegionFillValue = 0;
 BOOLEAN                     AcpiGbl_IgnoreErrors = FALSE;
-BOOLEAN                     AcpiGbl_AbortLoopOnTimeout = FALSE;
 BOOLEAN                     AcpiGbl_DbOpt_NoRegionSupport = FALSE;
 UINT8                       AcpiGbl_UseHwReducedFadt = FALSE;
 BOOLEAN                     AcpiGbl_DoInterfaceTests = FALSE;
@@ -199,7 +168,7 @@ static UINT8                AcpiGbl_ExecutionMode = AE_MODE_COMMAND_LOOP;
 static char                 BatchBuffer[AE_BUFFER_SIZE];    /* Batch command buffer */
 
 #define ACPIEXEC_NAME               "AML Execution/Debug Utility"
-#define AE_SUPPORTED_OPTIONS        "?b:d:e:f^ghlm^rt^v^:x:"
+#define AE_SUPPORTED_OPTIONS        "?b:d:e:f^ghi:lm^rv^:x:"
 
 
 /* Stubs for the disassembler */
@@ -260,7 +229,6 @@ usage (
     ACPI_OPTION ("-ei",                 "Enable additional tests for ACPICA interfaces");
     ACPI_OPTION ("-el",                 "Enable loading of additional test tables");
     ACPI_OPTION ("-em",                 "Enable grouping of module-level code");
-    ACPI_OPTION ("-ep",                 "Enable TermList parsing for scope objects");
     ACPI_OPTION ("-es",                 "Enable Interpreter Slack Mode");
     ACPI_OPTION ("-et",                 "Enable debug semaphore timeout");
     printf ("\n");
@@ -269,14 +237,10 @@ usage (
     ACPI_OPTION ("-fv <Value>",         "Operation Region initialization fill value");
     printf ("\n");
 
+    ACPI_OPTION ("-i <Count>",          "Maximum iterations for AML while loops");
     ACPI_OPTION ("-l",                  "Load tables and namespace only");
     ACPI_OPTION ("-r",                  "Use hardware-reduced FADT V5");
-    ACPI_OPTION ("-te",                 "Exit loop on timeout instead of aborting method");
-    ACPI_OPTION ("-to <Seconds>",       "Set timeout period for AML while loops");
-    printf ("\n");
-
     ACPI_OPTION ("-v",                  "Display version information");
-    ACPI_OPTION ("-vd",                 "Display build date and time");
     ACPI_OPTION ("-vi",                 "Verbose initialization output");
     ACPI_OPTION ("-vr",                 "Verbose region handler output");
     ACPI_OPTION ("-x <DebugLevel>",     "Debug output level");
@@ -395,11 +359,6 @@ AeDoOptions (
             AcpiGbl_GroupModuleLevelCode = TRUE;
             break;
 
-        case 'p':
-
-            AcpiGbl_ParseTableAsTermList = TRUE;
-            break;
-
         case 's':
 
             AcpiGbl_EnableInterpreterSlack = TRUE;
@@ -463,6 +422,20 @@ AeDoOptions (
         usage();
         return (1);
 
+    case 'i':
+
+        Temp = strtoul (AcpiGbl_Optarg, NULL, 0);
+        if (!Temp || (Temp > ACPI_UINT16_MAX))
+        {
+            printf ("%s: Invalid max loops value\n", AcpiGbl_Optarg);
+            return (-1);
+        }
+
+        AcpiGbl_MaxLoopIterations = (UINT16) Temp;
+        printf ("Max Loop Iterations is %u (0x%X)\n",
+            AcpiGbl_MaxLoopIterations, AcpiGbl_MaxLoopIterations);
+        break;
+
     case 'l':
 
         AcpiGbl_AeLoadOnly = TRUE;
@@ -491,53 +464,13 @@ AeDoOptions (
         printf ("Using ACPI 5.0 Hardware Reduced Mode via version 5 FADT\n");
         break;
 
-    case 't':
-
-        switch (AcpiGbl_Optarg[0])
-        {
-        case 'o':  /* -to: Set loop timeout in seconds */
-
-            if (AcpiGetoptArgument (argc, argv))
-            {
-                return (-1);
-            }
-
-            Temp = strtoul (AcpiGbl_Optarg, NULL, 0);
-            if (!Temp || (Temp > ACPI_UINT16_MAX))
-            {
-                printf ("%s: Invalid loop timeout value\n",
-                    AcpiGbl_Optarg);
-                return (-1);
-            }
-
-            AcpiGbl_MaxLoopIterations = (UINT16) Temp;
-            printf ("Automatic loop timeout after %u seconds\n",
-                AcpiGbl_MaxLoopIterations);
-            break;
-
-        case 'e':
-
-            AcpiGbl_AbortLoopOnTimeout = TRUE;
-            break;
-
-        default:
-
-            printf ("Unknown option: -t%s\n", AcpiGbl_Optarg);
-            return (-1);
-        }
-        break;
-
     case 'v':
 
         switch (AcpiGbl_Optarg[0])
         {
         case '^':  /* -v: (Version): signon already emitted, just exit */
 
-            return (1);
-
-        case 'd':
-
-            printf (ACPI_COMMON_BUILD_TIME);
+            (void) AcpiOsTerminate ();
             return (1);
 
         case 'i':
@@ -598,22 +531,16 @@ main (
 
 
     ACPI_DEBUG_INITIALIZE (); /* For debug version only */
-
-    signal (SIGINT, AeSignalHandler);
-    signal (SIGSEGV, AeSignalHandler);
+    signal (SIGINT, AeCtrlCHandler);
 
     /* Init debug globals */
 
     AcpiDbgLevel = ACPI_NORMAL_DEFAULT;
     AcpiDbgLayer = 0xFFFFFFFF;
 
-    /*
-     * Initialize ACPICA and start debugger thread.
-     *
-     * NOTE: After ACPICA initialization, AcpiTerminate MUST be called
-     * before this procedure exits -- otherwise, the console may be
-     * left in an incorrect state.
-     */
+    /* Init ACPICA and start debugger thread */
+
+    AcpiGbl_OverrideDefaultRegionHandlers = TRUE;
     Status = AcpiInitializeSubsystem ();
     ACPI_CHECK_OK (AcpiInitializeSubsystem, Status);
     if (ACPI_FAILURE (Status))
@@ -621,9 +548,10 @@ main (
         goto ErrorExit;
     }
 
-    /* Use a shorter timeout value for acpiexec */
+    /* ACPICA runtime configuration */
+
+    AcpiGbl_MaxLoopIterations = 400;
 
-    AcpiGbl_MaxLoopIterations = 1;
 
     /* Initialize the AML debugger */
 
@@ -638,7 +566,8 @@ main (
     if (argc < 2)
     {
         usage ();
-        goto NormalExit;
+        (void) AcpiOsTerminate ();
+        return (0);
     }
 
     /* Get the command line options */
@@ -670,7 +599,7 @@ main (
         /* Get all ACPI AML tables in this file */
 
         Status = AcGetAllTablesFromFile (argv[AcpiGbl_Optind],
-            ACPI_GET_ALL_TABLES, &ListHead);
+            ACPI_GET_ONLY_AML_TABLES, &ListHead);
         if (ACPI_FAILURE (Status))
         {
             ExitCode = -1;
@@ -693,6 +622,7 @@ main (
     /* Install all of the ACPI tables */
 
     Status = AeInstallTables ();
+
     if (ACPI_FAILURE (Status))
     {
         printf ("**** Could not install ACPI tables, %s\n",
@@ -721,13 +651,7 @@ main (
 
     /*
      * Main initialization for ACPICA subsystem
-     * TBD: Need a way to call this after the ACPI table "LOAD" command?
-     *
-     * NOTE: This initialization does not match the _Lxx and _Exx methods
-     * to individual GPEs, as there are no real GPEs when the hardware
-     * is simulated - because there is no namespace until AeLoadTables is
-     * executed. This may have to change if AcpiExec is ever run natively
-     * on actual hardware (such as under UEFI).
+     * TBD: Need a way to call this after the ACPI table "LOAD" command
      */
     Status = AcpiEnableSubsystem (InitFlags);
     if (ACPI_FAILURE (Status))
@@ -791,33 +715,89 @@ EnterDebugger:
     default:
     case AE_MODE_COMMAND_LOOP:
 
-        AcpiRunDebugger (NULL);
+        AcpiDbUserCommands (ACPI_DEBUGGER_COMMAND_PROMPT, NULL);
         break;
 
     case AE_MODE_BATCH_MULTIPLE:
 
-        AcpiRunDebugger (BatchBuffer);
+        AcpiDbRunBatchMode ();
         break;
 
     case AE_MODE_BATCH_SINGLE:
 
         AcpiDbExecute (BatchBuffer, NULL, NULL, EX_NO_SINGLE_STEP);
+
+        /* Shut down the debugger */
+
+        AcpiTerminateDebugger ();
+        Status = AcpiTerminate ();
         break;
     }
 
-    /* Shut down the debugger and ACPICA */
+    (void) AcpiOsTerminate ();
+    return (0);
 
-    AcpiTerminateDebugger ();
-
-    /* re-enable debug output for AcpiTerminate output */
-
-    AcpiGbl_DbOutputFlags = ACPI_DB_CONSOLE_OUTPUT;
-
-NormalExit:
-    ExitCode = 0;
 
 ErrorExit:
-    (void) AcpiTerminate ();
-    AcDeleteTableList (ListHead);
+    (void) AcpiOsTerminate ();
     return (ExitCode);
 }
+
+
+/******************************************************************************
+ *
+ * FUNCTION:    AcpiDbRunBatchMode
+ *
+ * PARAMETERS:  BatchCommandLine    - A semicolon separated list of commands
+ *                                    to be executed.
+ *                                    Use only commas to separate elements of
+ *                                    particular command.
+ * RETURN:      Status
+ *
+ * DESCRIPTION: For each command of list separated by ';' prepare the command
+ *              buffer and pass it to AcpiDbCommandDispatch.
+ *
+ *****************************************************************************/
+
+static ACPI_STATUS
+AcpiDbRunBatchMode (
+    void)
+{
+    ACPI_STATUS             Status;
+    char                    *Ptr = BatchBuffer;
+    char                    *Cmd = Ptr;
+    UINT8                   Run = 0;
+
+
+    AcpiGbl_MethodExecuting = FALSE;
+    AcpiGbl_StepToNextCall = FALSE;
+
+    while (*Ptr)
+    {
+        if (*Ptr == ',')
+        {
+            /* Convert commas to spaces */
+            *Ptr = ' ';
+        }
+        else if (*Ptr == ';')
+        {
+            *Ptr = '\0';
+            Run = 1;
+        }
+
+        Ptr++;
+
+        if (Run || (*Ptr == '\0'))
+        {
+            (void) AcpiDbCommandDispatch (Cmd, NULL, NULL);
+            Run = 0;
+            Cmd = Ptr;
+        }
+    }
+
+    /* Shut down the debugger */
+
+    AcpiTerminateDebugger ();
+    Status = AcpiTerminate ();
+    return (Status);
+}
