@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -121,15 +121,17 @@
 
 /* Local prototypes */
 
+static void
+AeInitializeTableHeader (
+    ACPI_TABLE_HEADER       *Header,
+    char                    *Signature,
+    UINT32                  Length);
+
 void
 AeTableOverride (
     ACPI_TABLE_HEADER       *ExistingTable,
     ACPI_TABLE_HEADER       **NewTable);
 
-ACPI_PHYSICAL_ADDRESS
-AeLocalGetRootPointer (
-    void);
-
 /* User table (DSDT) */
 
 static ACPI_TABLE_HEADER        *DsdtToInstallOverride;
@@ -153,12 +155,10 @@ static ACPI_TABLE_FADT          LocalFADT;
  */
 static ACPI_TABLE_XSDT          *LocalXSDT;
 
-#define BASE_XSDT_TABLES        10
-#define BASE_XSDT_SIZE          (sizeof (ACPI_TABLE_XSDT) + \
-                                    ((BASE_XSDT_TABLES -1) * sizeof (UINT64)))
+#define BASE_XSDT_TABLES        9
+#define BASE_XSDT_SIZE          ((BASE_XSDT_TABLES) * sizeof (UINT64))
 
 #define ACPI_MAX_INIT_TABLES    (32)
-static ACPI_TABLE_DESC          Tables[ACPI_MAX_INIT_TABLES];
 
 
 /******************************************************************************
@@ -176,6 +176,12 @@ AeTableOverride (
     ACPI_TABLE_HEADER       **NewTable)
 {
 
+    if (!AcpiGbl_LoadTestTables)
+    {
+        *NewTable = NULL;
+        return;
+    }
+
     /* This code exercises the table override mechanism in the core */
 
     if (ACPI_COMPARE_NAME (ExistingTable->Signature, ACPI_SIG_DSDT))
@@ -192,12 +198,50 @@ AeTableOverride (
 }
 
 
+/******************************************************************************
+ *
+ * FUNCTION:    AeInitializeTableHeader
+ *
+ * PARAMETERS:  Header          - A valid standard ACPI table header
+ *              Signature       - Signature to insert
+ *              Length          - Length of the table
+ *
+ * RETURN:      None. Header is modified.
+ *
+ * DESCRIPTION: Initialize the table header for a local ACPI table.
+ *
+ *****************************************************************************/
+
+static void
+AeInitializeTableHeader (
+    ACPI_TABLE_HEADER       *Header,
+    char                    *Signature,
+    UINT32                  Length)
+{
+
+    ACPI_MOVE_NAME (Header->Signature, Signature);
+    Header->Length = Length;
+
+    Header->OemRevision = 0x1001;
+    strncpy (Header->OemId, "Intel", ACPI_OEM_ID_SIZE);
+    strncpy (Header->OemTableId, "AcpiExec", ACPI_OEM_TABLE_ID_SIZE);
+    strncpy (Header->AslCompilerId, "INTL", ACPI_NAME_SIZE);
+    Header->AslCompilerRevision = ACPI_CA_VERSION;
+
+    /* Set the checksum, must set to zero first */
+
+    Header->Checksum = 0;
+    Header->Checksum = (UINT8) -AcpiTbChecksum (
+        (void *) Header, Header->Length);
+}
+
+
 /******************************************************************************
  *
  * FUNCTION:    AeBuildLocalTables
  *
  * PARAMETERS:  TableCount      - Number of tables on the command line
- *              TableList       - List of actual tables from files
+ *              ListHead        - List of actual tables from files
  *
  * RETURN:      Status
  *
@@ -208,33 +252,39 @@ AeTableOverride (
 
 ACPI_STATUS
 AeBuildLocalTables (
-    UINT32                  TableCount,
-    AE_TABLE_DESC           *TableList)
+    ACPI_NEW_TABLE_DESC     *ListHead)
 {
+    UINT32                  TableCount = 1;
     ACPI_PHYSICAL_ADDRESS   DsdtAddress = 0;
     UINT32                  XsdtSize;
-    AE_TABLE_DESC           *NextTable;
+    ACPI_NEW_TABLE_DESC     *NextTable;
     UINT32                  NextIndex;
     ACPI_TABLE_FADT         *ExternalFadt = NULL;
 
 
     /*
-     * Update the table count. For DSDT, it is not put into the XSDT. For
-     * FADT, this is already accounted for since we usually install a
-     * local FADT.
+     * Update the table count. For the DSDT, it is not put into the XSDT.
+     * For the FADT, this table is already accounted for since we usually
+     * install a local FADT.
      */
-    NextTable = TableList;
+    NextTable = ListHead;
     while (NextTable)
     {
-        if (ACPI_COMPARE_NAME (NextTable->Table->Signature, ACPI_SIG_DSDT) ||
-            ACPI_COMPARE_NAME (NextTable->Table->Signature, ACPI_SIG_FADT))
+        if (!ACPI_COMPARE_NAME (NextTable->Table->Signature, ACPI_SIG_DSDT) &&
+            !ACPI_COMPARE_NAME (NextTable->Table->Signature, ACPI_SIG_FADT))
         {
-            TableCount--;
+            TableCount++;
         }
+
         NextTable = NextTable->Next;
     }
 
-    XsdtSize = BASE_XSDT_SIZE + (TableCount * sizeof (UINT64));
+    XsdtSize = (((TableCount + 1) * sizeof (UINT64)) +
+        sizeof (ACPI_TABLE_HEADER));
+    if (AcpiGbl_LoadTestTables)
+    {
+        XsdtSize += BASE_XSDT_SIZE;
+    }
 
     /* Build an XSDT */
 
@@ -244,43 +294,15 @@ AeBuildLocalTables (
         return (AE_NO_MEMORY);
     }
 
-    ACPI_MEMSET (LocalXSDT, 0, XsdtSize);
-    ACPI_MOVE_NAME (LocalXSDT->Header.Signature, ACPI_SIG_XSDT);
-    LocalXSDT->Header.Length = XsdtSize;
-    LocalXSDT->Header.Revision = 1;
-
-    LocalXSDT->TableOffsetEntry[0] = ACPI_PTR_TO_PHYSADDR (&LocalTEST);
-    LocalXSDT->TableOffsetEntry[1] = ACPI_PTR_TO_PHYSADDR (&LocalBADTABLE);
-    LocalXSDT->TableOffsetEntry[2] = ACPI_PTR_TO_PHYSADDR (&LocalFADT);
-
-    /* Install two SSDTs to test multiple table support */
-
-    LocalXSDT->TableOffsetEntry[3] = ACPI_PTR_TO_PHYSADDR (&Ssdt1Code);
-    LocalXSDT->TableOffsetEntry[4] = ACPI_PTR_TO_PHYSADDR (&Ssdt2Code);
-
-    /* Install the OEM1 table to test LoadTable */
-
-    LocalXSDT->TableOffsetEntry[5] = ACPI_PTR_TO_PHYSADDR (&Oem1Code);
-
-    /* Install the OEMx table to test LoadTable */
-
-    LocalXSDT->TableOffsetEntry[6] = ACPI_PTR_TO_PHYSADDR (&OemxCode);
-
-     /* Install the ECDT table to test _REG */
-
-    LocalXSDT->TableOffsetEntry[7] = ACPI_PTR_TO_PHYSADDR (&EcdtCode);
-
-    /* Install two UEFIs to test multiple table support */
-
-    LocalXSDT->TableOffsetEntry[8] = ACPI_PTR_TO_PHYSADDR (&Uefi1Code);
-    LocalXSDT->TableOffsetEntry[9] = ACPI_PTR_TO_PHYSADDR (&Uefi2Code);
+    memset (LocalXSDT, 0, XsdtSize);
+    LocalXSDT->TableOffsetEntry[0] = ACPI_PTR_TO_PHYSADDR (&LocalFADT);
+    NextIndex = 1;
 
     /*
      * Install the user tables. The DSDT must be installed in the FADT.
      * All other tables are installed directly into the XSDT.
      */
-    NextIndex = BASE_XSDT_TABLES;
-    NextTable = TableList;
+    NextTable = ListHead;
     while (NextTable)
     {
         /*
@@ -297,38 +319,71 @@ AeBuildLocalTables (
 
             /* The incoming user table is a DSDT */
 
-            DsdtAddress = ACPI_PTR_TO_PHYSADDR (&DsdtCode);
+            DsdtAddress = ACPI_PTR_TO_PHYSADDR (NextTable->Table);
             DsdtToInstallOverride = NextTable->Table;
         }
         else if (ACPI_COMPARE_NAME (NextTable->Table->Signature, ACPI_SIG_FADT))
         {
             ExternalFadt = ACPI_CAST_PTR (ACPI_TABLE_FADT, NextTable->Table);
-            LocalXSDT->TableOffsetEntry[2] = ACPI_PTR_TO_PHYSADDR (NextTable->Table);
+            LocalXSDT->TableOffsetEntry[0] = ACPI_PTR_TO_PHYSADDR (NextTable->Table);
         }
         else
         {
             /* Install the table in the XSDT */
 
-            LocalXSDT->TableOffsetEntry[NextIndex] = ACPI_PTR_TO_PHYSADDR (NextTable->Table);
+            LocalXSDT->TableOffsetEntry[NextIndex] =
+                ACPI_PTR_TO_PHYSADDR (NextTable->Table);
             NextIndex++;
         }
 
         NextTable = NextTable->Next;
     }
 
-    /* Build an RSDP */
+    /* Install the optional extra local tables */
 
-    ACPI_MEMSET (&LocalRSDP, 0, sizeof (ACPI_TABLE_RSDP));
+    if (AcpiGbl_LoadTestTables)
+    {
+        LocalXSDT->TableOffsetEntry[NextIndex++] = ACPI_PTR_TO_PHYSADDR (&LocalTEST);
+        LocalXSDT->TableOffsetEntry[NextIndex++] = ACPI_PTR_TO_PHYSADDR (&LocalBADTABLE);
+
+        /* Install two SSDTs to test multiple table support */
+
+        LocalXSDT->TableOffsetEntry[NextIndex++] = ACPI_PTR_TO_PHYSADDR (&Ssdt1Code);
+        LocalXSDT->TableOffsetEntry[NextIndex++] = ACPI_PTR_TO_PHYSADDR (&Ssdt2Code);
+
+        /* Install the OEM1 table to test LoadTable */
+
+        LocalXSDT->TableOffsetEntry[NextIndex++] = ACPI_PTR_TO_PHYSADDR (&Oem1Code);
+
+        /* Install the OEMx table to test LoadTable */
+
+        LocalXSDT->TableOffsetEntry[NextIndex++] = ACPI_PTR_TO_PHYSADDR (&OemxCode);
+
+         /* Install the ECDT table to test _REG */
+
+        LocalXSDT->TableOffsetEntry[NextIndex++] = ACPI_PTR_TO_PHYSADDR (&EcdtCode);
+
+        /* Install two UEFIs to test multiple table support */
+
+        LocalXSDT->TableOffsetEntry[NextIndex++] = ACPI_PTR_TO_PHYSADDR (&Uefi1Code);
+        LocalXSDT->TableOffsetEntry[NextIndex++] = ACPI_PTR_TO_PHYSADDR (&Uefi2Code);
+    }
+
+    /* Build an RSDP. Contains a valid XSDT only, no RSDT */
+
+    memset (&LocalRSDP, 0, sizeof (ACPI_TABLE_RSDP));
     ACPI_MAKE_RSDP_SIG (LocalRSDP.Signature);
-    ACPI_MEMCPY (LocalRSDP.OemId, "I_TEST", 6);
+    memcpy (LocalRSDP.OemId, "Intel", 6);
+
     LocalRSDP.Revision = 2;
     LocalRSDP.XsdtPhysicalAddress = ACPI_PTR_TO_PHYSADDR (LocalXSDT);
-    LocalRSDP.Length = sizeof (ACPI_TABLE_XSDT);
+    LocalRSDP.Length = sizeof (ACPI_TABLE_RSDP);
 
     /* Set checksums for both XSDT and RSDP */
 
-    LocalXSDT->Header.Checksum = (UINT8) -AcpiTbChecksum (
-        (void *) LocalXSDT, LocalXSDT->Header.Length);
+    AeInitializeTableHeader ((void *) LocalXSDT, ACPI_SIG_XSDT, XsdtSize);
+
+    LocalRSDP.Checksum = 0;
     LocalRSDP.Checksum = (UINT8) -AcpiTbChecksum (
         (void *) &LocalRSDP, ACPI_RSDP_CHECKSUM_LENGTH);
 
@@ -340,29 +395,44 @@ AeBuildLocalTables (
         DsdtToInstallOverride = ACPI_CAST_PTR (ACPI_TABLE_HEADER, LocalDsdtCode);
     }
 
+    /*
+     * Build an FADT. There are three options for the FADT:
+     * 1) Incoming external FADT specified on the command line
+     * 2) A "hardware reduced" local FADT
+     * 3) A fully featured local FADT
+     */
+    memset (&LocalFADT, 0, sizeof (ACPI_TABLE_FADT));
+
     if (ExternalFadt)
     {
         /*
-         * Use the external FADT, but we must update the DSDT/FACS addresses
-         * as well as the checksum
+         * Use the external FADT, but we must update the DSDT/FACS
+         * addresses as well as the checksum
          */
-        ExternalFadt->Dsdt = DsdtAddress;
+        ExternalFadt->Dsdt = (UINT32) DsdtAddress;
         if (!AcpiGbl_ReducedHardware)
         {
             ExternalFadt->Facs = ACPI_PTR_TO_PHYSADDR (&LocalFACS);
         }
 
-        if (ExternalFadt->Header.Length > ACPI_PTR_DIFF (&ExternalFadt->XDsdt, ExternalFadt))
+        /*
+         * If there room in the FADT for the XDsdt and XFacs 64-bit
+         * pointers, use them.
+         */
+        if (ExternalFadt->Header.Length > ACPI_PTR_DIFF (
+            &ExternalFadt->XDsdt, ExternalFadt))
         {
-            ExternalFadt->XDsdt = DsdtAddress;
+            ExternalFadt->Dsdt = 0;
+            ExternalFadt->Facs = 0;
 
+            ExternalFadt->XDsdt = DsdtAddress;
             if (!AcpiGbl_ReducedHardware)
             {
                 ExternalFadt->XFacs = ACPI_PTR_TO_PHYSADDR (&LocalFACS);
             }
         }
 
-        /* Complete the FADT with the checksum */
+        /* Complete the external FADT with the checksum */
 
         ExternalFadt->Header.Checksum = 0;
         ExternalFadt->Header.Checksum = (UINT8) -AcpiTbChecksum (
@@ -370,21 +440,16 @@ AeBuildLocalTables (
     }
     else if (AcpiGbl_UseHwReducedFadt)
     {
-        ACPI_MEMCPY (&LocalFADT, HwReducedFadtCode, sizeof (ACPI_TABLE_FADT));
-        LocalFADT.Dsdt = DsdtAddress;
+        memcpy (&LocalFADT, HwReducedFadtCode, ACPI_FADT_V5_SIZE);
+        LocalFADT.Dsdt = 0;
         LocalFADT.XDsdt = DsdtAddress;
-
-        LocalFADT.Header.Checksum = 0;
-        LocalFADT.Header.Checksum = (UINT8) -AcpiTbChecksum (
-            (void *) &LocalFADT, LocalFADT.Header.Length);
     }
     else
     {
         /*
          * Build a local FADT so we can test the hardware/event init
          */
-        ACPI_MEMSET (&LocalFADT, 0, sizeof (ACPI_TABLE_FADT));
-        ACPI_MOVE_NAME (LocalFADT.Header.Signature, ACPI_SIG_FADT);
+        LocalFADT.Header.Revision = 5;
 
         /* Setup FADT header and DSDT/FACS addresses */
 
@@ -394,17 +459,14 @@ AeBuildLocalTables (
         LocalFADT.XDsdt = DsdtAddress;
         LocalFADT.XFacs = ACPI_PTR_TO_PHYSADDR (&LocalFACS);
 
-        LocalFADT.Header.Revision = 3;
-        LocalFADT.Header.Length = sizeof (ACPI_TABLE_FADT);
-
         /* Miscellaneous FADT fields */
 
-        LocalFADT.Gpe0BlockLength = 16;
+        LocalFADT.Gpe0BlockLength = 0x08;
         LocalFADT.Gpe0Block = 0x00001234;
 
-        LocalFADT.Gpe1BlockLength = 6;
+        LocalFADT.Gpe1BlockLength = 0x80;
         LocalFADT.Gpe1Block = 0x00005678;
-        LocalFADT.Gpe1Base = 96;
+        LocalFADT.Gpe1Base = 100;
 
         LocalFADT.Pm1EventLength = 4;
         LocalFADT.Pm1aEventBlock = 0x00001aaa;
@@ -419,50 +481,57 @@ AeBuildLocalTables (
         LocalFADT.Pm2ControlBlock = 0xC0;
         LocalFADT.Pm2ControlLength = 1;
 
-        /* Setup one example X-64 field */
+        /* Setup one example X-64 GAS field */
 
         LocalFADT.XPm1bEventBlock.SpaceId = ACPI_ADR_SPACE_SYSTEM_IO;
         LocalFADT.XPm1bEventBlock.Address = LocalFADT.Pm1bEventBlock;
-        LocalFADT.XPm1bEventBlock.BitWidth = (UINT8) ACPI_MUL_8 (LocalFADT.Pm1EventLength);
-
-        /* Complete the FADT with the checksum */
-
-        LocalFADT.Header.Checksum = 0;
-        LocalFADT.Header.Checksum = (UINT8) -AcpiTbChecksum (
-            (void *) &LocalFADT, LocalFADT.Header.Length);
+        LocalFADT.XPm1bEventBlock.BitWidth = (UINT8)
+            ACPI_MUL_8 (LocalFADT.Pm1EventLength);
     }
 
+    AeInitializeTableHeader ((void *) &LocalFADT,
+        ACPI_SIG_FADT, sizeof (ACPI_TABLE_FADT));
+
     /* Build a FACS */
 
-    ACPI_MEMSET (&LocalFACS, 0, sizeof (ACPI_TABLE_FACS));
+    memset (&LocalFACS, 0, sizeof (ACPI_TABLE_FACS));
     ACPI_MOVE_NAME (LocalFACS.Signature, ACPI_SIG_FACS);
 
     LocalFACS.Length = sizeof (ACPI_TABLE_FACS);
     LocalFACS.GlobalLock = 0x11AA0011;
 
-    /*
-     * Build a fake table [TEST] so that we make sure that the
-     * ACPICA core ignores it
-     */
-    ACPI_MEMSET (&LocalTEST, 0, sizeof (ACPI_TABLE_HEADER));
-    ACPI_MOVE_NAME (LocalTEST.Signature, "TEST");
+    /* Build the optional local tables */
 
-    LocalTEST.Revision = 1;
-    LocalTEST.Length = sizeof (ACPI_TABLE_HEADER);
-    LocalTEST.Checksum = (UINT8) -AcpiTbChecksum (
-        (void *) &LocalTEST, LocalTEST.Length);
+    if (AcpiGbl_LoadTestTables)
+    {
+        /*
+         * Build a fake table [TEST] so that we make sure that the
+         * ACPICA core ignores it
+         */
+        memset (&LocalTEST, 0, sizeof (ACPI_TABLE_HEADER));
+        ACPI_MOVE_NAME (LocalTEST.Signature, "TEST");
 
-    /*
-     * Build a fake table with a bad signature [BAD!] so that we make
-     * sure that the ACPICA core ignores it
-     */
-    ACPI_MEMSET (&LocalBADTABLE, 0, sizeof (ACPI_TABLE_HEADER));
-    ACPI_MOVE_NAME (LocalBADTABLE.Signature, "BAD!");
+        LocalTEST.Revision = 1;
+        LocalTEST.Length = sizeof (ACPI_TABLE_HEADER);
 
-    LocalBADTABLE.Revision = 1;
-    LocalBADTABLE.Length = sizeof (ACPI_TABLE_HEADER);
-    LocalBADTABLE.Checksum = (UINT8) -AcpiTbChecksum (
-        (void *) &LocalBADTABLE, LocalBADTABLE.Length);
+        LocalTEST.Checksum = 0;
+        LocalTEST.Checksum = (UINT8) -AcpiTbChecksum (
+            (void *) &LocalTEST, LocalTEST.Length);
+
+        /*
+         * Build a fake table with a bad signature [BAD!] so that we make
+         * sure that the ACPICA core ignores it
+         */
+        memset (&LocalBADTABLE, 0, sizeof (ACPI_TABLE_HEADER));
+        ACPI_MOVE_NAME (LocalBADTABLE.Signature, "BAD!");
+
+        LocalBADTABLE.Revision = 1;
+        LocalBADTABLE.Length = sizeof (ACPI_TABLE_HEADER);
+
+        LocalBADTABLE.Checksum = 0;
+        LocalBADTABLE.Checksum = (UINT8) -AcpiTbChecksum (
+            (void *) &LocalBADTABLE, LocalBADTABLE.Length);
+    }
 
     return (AE_OK);
 }
@@ -487,16 +556,75 @@ AeInstallTables (
     ACPI_STATUS             Status;
     ACPI_TABLE_HEADER       Header;
     ACPI_TABLE_HEADER       *Table;
+    UINT32                  i;
 
 
-    Status = AcpiInitializeTables (Tables, ACPI_MAX_INIT_TABLES, TRUE);
-    AE_CHECK_OK (AcpiInitializeTables, Status);
+    Status = AcpiInitializeTables (NULL, ACPI_MAX_INIT_TABLES, TRUE);
+    ACPI_CHECK_OK (AcpiInitializeTables, Status);
+
+    if (AcpiGbl_LoadTestTables)
+    {
+        /* Test multiple table/UEFI support. First, get the headers */
+
+        Status = AcpiGetTableHeader (ACPI_SIG_UEFI, 1, &Header);
+        ACPI_CHECK_OK (AcpiGetTableHeader, Status);
+
+        Status = AcpiGetTableHeader (ACPI_SIG_UEFI, 2, &Header);
+        ACPI_CHECK_OK (AcpiGetTableHeader, Status);
+
+        Status = AcpiGetTableHeader (ACPI_SIG_UEFI, 3, &Header);
+        ACPI_CHECK_STATUS (AcpiGetTableHeader, Status, AE_NOT_FOUND);
+
+        /* Now get the actual tables */
+
+        Status = AcpiGetTable (ACPI_SIG_UEFI, 1, &Table);
+        ACPI_CHECK_OK (AcpiGetTable, Status);
+
+        Status = AcpiGetTable (ACPI_SIG_UEFI, 2, &Table);
+        ACPI_CHECK_OK (AcpiGetTable, Status);
+
+        Status = AcpiGetTable (ACPI_SIG_UEFI, 3, &Table);
+        ACPI_CHECK_STATUS (AcpiGetTable, Status, AE_NOT_FOUND);
+    }
+
+    /* Check that we can get all of the ACPI tables */
+
+    for (i = 0; ; i++)
+    {
+        Status = AcpiGetTableByIndex (i, &Table);
+        if ((Status == AE_BAD_PARAMETER) || !Table)
+        {
+            break;
+        }
+
+        ACPI_CHECK_OK (AcpiGetTableByIndex, Status);
+    }
+
+    return (AE_OK);
+}
+
+
+/******************************************************************************
+ *
+ * FUNCTION:    AeLoadTables
+ *
+ * PARAMETERS:  None
+ *
+ * RETURN:      Status
+ *
+ * DESCRIPTION: Load the definition block ACPI tables
+ *
+ *****************************************************************************/
+
+ACPI_STATUS
+AeLoadTables (
+    void)
+{
+    ACPI_STATUS             Status;
 
-    Status = AcpiReallocateRootTable ();
-    AE_CHECK_OK (AcpiReallocateRootTable, Status);
 
     Status = AcpiLoadTables ();
-    AE_CHECK_OK (AcpiLoadTables, Status);
+    ACPI_CHECK_OK (AcpiLoadTables, Status);
 
     /*
      * Test run-time control method installation. Do it twice to test code
@@ -516,35 +644,13 @@ AeInstallTables (
             AcpiFormatException (Status));
     }
 
-    /* Test multiple table/UEFI support. First, get the headers */
-
-    Status = AcpiGetTableHeader (ACPI_SIG_UEFI, 1, &Header);
-    AE_CHECK_OK (AcpiGetTableHeader, Status);
-
-    Status = AcpiGetTableHeader (ACPI_SIG_UEFI, 2, &Header);
-    AE_CHECK_OK (AcpiGetTableHeader, Status);
-
-    Status = AcpiGetTableHeader (ACPI_SIG_UEFI, 3, &Header);
-    AE_CHECK_STATUS (AcpiGetTableHeader, Status, AE_NOT_FOUND);
-
-    /* Now get the actual tables */
-
-    Status = AcpiGetTable (ACPI_SIG_UEFI, 1, &Table);
-    AE_CHECK_OK (AcpiGetTable, Status);
-
-    Status = AcpiGetTable (ACPI_SIG_UEFI, 2, &Table);
-    AE_CHECK_OK (AcpiGetTable, Status);
-
-    Status = AcpiGetTable (ACPI_SIG_UEFI, 3, &Table);
-    AE_CHECK_STATUS (AcpiGetTable, Status, AE_NOT_FOUND);
-
     return (AE_OK);
 }
 
 
 /******************************************************************************
  *
- * FUNCTION:    AeLocalGetRootPointer
+ * FUNCTION:    AcpiOsGetRootPointer
  *
  * PARAMETERS:  Flags       - not used
  *              Address     - Where the root pointer is returned
@@ -557,9 +663,9 @@ AeInstallTables (
  *****************************************************************************/
 
 ACPI_PHYSICAL_ADDRESS
-AeLocalGetRootPointer (
+AcpiOsGetRootPointer (
     void)
 {
 
-    return ((ACPI_PHYSICAL_ADDRESS) &LocalRSDP);
+    return (ACPI_PTR_TO_PHYSADDR (&LocalRSDP));
 }
