@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2018, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,42 +111,6 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
 #include "acpixtract.h"
@@ -184,83 +148,6 @@ AxCheckAscii (
 }
 
 
-/*******************************************************************************
- *
- * FUNCTION:    AxIsFileAscii
- *
- * PARAMETERS:  Handle              - To open input file
- *
- * RETURN:      TRUE if file is entirely ASCII and printable
- *
- * DESCRIPTION: Verify that the input file is entirely ASCII.
- *
- ******************************************************************************/
-
-BOOLEAN
-AxIsFileAscii (
-    FILE                    *Handle)
-{
-    UINT8                   Byte;
-    UINT32                  Offset = 0;
-
-
-    /* Read the entire file */
-
-    fseek (Handle, 0, SEEK_SET);
-    while (fread (&Byte, 1, 1, Handle) == 1)
-    {
-        /*
-         * Ignore null characters. Some acpidump-type utilities insert
-         * a few of these, probably a bug in the utility. As long as these
-         * characters are in lines that are tossed (non-data), they
-         * won't cause a problem.
-         */
-        if (!Byte)
-        {
-            continue;
-        }
-
-        /* Check for an ASCII character */
-
-        if (!ACPI_IS_ASCII (Byte))
-        {
-            printf ("Found non-ascii char: %2.2X at file offset %u (0x%X)\n",
-                Byte, Offset, Offset);
-            if (!Gbl_ForceExtraction)
-            {
-                goto ErrorExit;
-            }
-        }
-
-        /* Ensure character is either printable or a "space" char */
-
-        else if (!isprint (Byte) && !isspace (Byte))
-        {
-            printf ("Found non-printable char: %2.2X at file offset %u (0x%X)\n",
-                Byte, Offset, Offset);
-            if (!Gbl_ForceExtraction)
-            {
-                goto ErrorExit;
-            }
-        }
-
-        Offset++;
-    }
-
-    /* File is OK (100% ASCII) */
-
-    fseek (Handle, 0, SEEK_SET);
-    return (TRUE);
-
-ErrorExit:
-
-    printf ("File appears to be binary "
-        "(contains non-text or non-ascii characters)\n");
-    fseek (Handle, 0, SEEK_SET);
-    return (FALSE);
-}
-
-
 /******************************************************************************
  *
  * FUNCTION:    AxIsEmptyLine
@@ -273,7 +160,7 @@ ErrorExit:
  *
  ******************************************************************************/
 
-BOOLEAN
+int
 AxIsEmptyLine (
     char                    *Buffer)
 {
@@ -285,9 +172,9 @@ AxIsEmptyLine (
         Buffer++;
     }
 
-    /* Line is empty when a Unix or DOS-style line terminator is found. */
+    /* If end-of-line, this line is empty */
 
-    if ((*Buffer == '\r') || (*Buffer == '\n'))
+    if (*Buffer == '\n')
     {
         return (1);
     }
@@ -296,96 +183,6 @@ AxIsEmptyLine (
 }
 
 
-/******************************************************************************
- *
- * FUNCTION:    AxIsHexDataLine
- *
- * PARAMETERS:  None
- *
- * RETURN:      Status. 1 if the table header is valid, 0 otherwise.
- *
- * DESCRIPTION: Check for a valid line of hex data of the form:
- *
- *  00a0: 0c 00 00 00 03 00 00 00 43 48 41 35 0c 00 00 00  ........CHA5....
- *
- ******************************************************************************/
-
-BOOLEAN
-AxIsHexDataLine (
-    void)
-{
-
-    if (AxIsEmptyLine (Gbl_LineBuffer) ||
-        (Gbl_LineBuffer[0] != ' '))
-    {
-        return (FALSE);
-    }
-
-    if (!strstr (Gbl_LineBuffer, ": "))
-    {
-        /* Not valid data line */
-
-        return (FALSE);
-    }
-
-    return (TRUE);
-}
-
-
-/******************************************************************************
- *
- * FUNCTION:    AxIsDataBlockHeader
- *
- * PARAMETERS:  None
- *
- * RETURN:      Status. 1 if the table header is valid, 0 otherwise.
- *
- * DESCRIPTION: Check if the ACPI table identifier in the input acpidump text
- *              file is valid (of the form: <sig> @ <addr>).
- *
- ******************************************************************************/
-
-BOOLEAN
-AxIsDataBlockHeader (
-    void)
-{
-
-    /* Ignore lines that are too short to be header lines */
-
-    if (strlen (Gbl_LineBuffer) < AX_MIN_BLOCK_HEADER_LENGTH)
-    {
-        return (FALSE);
-    }
-
-    /* Ignore empty lines and lines that start with a space */
-
-    if (AxIsEmptyLine (Gbl_LineBuffer) ||
-        (Gbl_LineBuffer[0] == ' '))
-    {
-        return (FALSE);
-    }
-
-    /*
-     * Ignore lines that are not headers of the form <sig> @ <addr>.
-     * Basically, just look for the '@' symbol, surrounded by spaces.
-     *
-     * Examples of headers that must be supported:
-     *
-     * DSDT @ 0x737e4000
-     * XSDT @ 0x737f2fff
-     * RSD PTR @ 0xf6cd0
-     * SSDT @ (nil)
-     */
-    if (!AX_IS_TABLE_BLOCK_HEADER)
-    {
-        return (FALSE);
-    }
-
-    AxNormalizeSignature (Gbl_LineBuffer);
-    return (TRUE);
-}
-
-
 /*******************************************************************************
  *
  * FUNCTION:    AxNormalizeSignature
@@ -412,7 +209,7 @@ AxNormalizeSignature (
 
 /******************************************************************************
  *
- * FUNCTION:    AxConvertToBinary
+ * FUNCTION:    AxConvertLine
  *
  * PARAMETERS:  InputLine           - One line from the input acpidump file
  *              OutputData          - Where the converted data is returned
@@ -421,38 +218,27 @@ AxNormalizeSignature (
  *
  * DESCRIPTION: Convert one line of ascii text binary (up to 16 bytes)
  *
- * NOTE: Assumes the input data line has been validated to be of the form:
- *
- *  0010: 48 53 57 55 4c 54 2d 52 01 00 00 00 49 4e 54 4c  HSWULT-R....INTL
- *
  ******************************************************************************/
 
-int
-AxConvertToBinary (
+size_t
+AxConvertLine (
     char                    *InputLine,
     unsigned char           *OutputData)
 {
-    char                    *ColonDelimiter;
+    char                    *End;
     int                     BytesConverted;
     int                     Converted[16];
     int                     i;
 
 
-    /*
-     * Terminate input line immediately after the data. Otherwise, the
-     * second line below will not scan correctly.
-     *
-     * This handles varying lengths for the offset: line prefix. This support
-     * for tables larger than 1mb was added 05/2018.
-     *
-     *    00b0: 03 00 00 00 43 48 41 36 0c 00 00 00 03 00 00 00  ....CHA6........
-     *    00c0: 43 48 41 37                                      CHA7
-     *
-     *    012340b0: 03 00 00 00 43 48 41 36 0c 00 00 00 03 00 00 00  ....CHA6........
-     *    012340c0: 43 48 41 37                                      CHA7
-     */
-    ColonDelimiter = strchr (InputLine, ':');
-    ColonDelimiter [AX_HEX_DATA_LENGTH] = 0;
+    /* Terminate the input line at the end of the actual data (for sscanf) */
+
+    End = strstr (InputLine + 2, "  ");
+    if (!End)
+    {
+        return (0); /* Don't understand the format */
+    }
+    *End = 0;
 
     /*
      * Convert one line of table data, of the form:
@@ -462,28 +248,66 @@ AxConvertToBinary (
      * 02C0: 5F 53 42 5F 4C 4E 4B 44 00 12 13 04 0C FF FF 08  _SB_LNKD........
      */
     BytesConverted = sscanf (InputLine,
-        "%*s %2X %2X %2X %2X %2X %2X %2X %2X %2X %2X %2X %2X %2X %2X %2X %2X",
+        "%*s %x %x %x %x %x %x %x %x %x %x %x %x %x %x %x %x",
         &Converted[0],  &Converted[1],  &Converted[2],  &Converted[3],
         &Converted[4],  &Converted[5],  &Converted[6],  &Converted[7],
         &Converted[8],  &Converted[9],  &Converted[10], &Converted[11],
         &Converted[12], &Converted[13], &Converted[14], &Converted[15]);
 
-    if (BytesConverted == EOF)
-    {
-        printf ("EOF while converting ASCII line to binary\n");
-        return (-1);
-    }
+    /* Pack converted data into a byte array */
 
-    /*
-     * Pack converted data into a byte array.
-     * Note: BytesConverted == 0 is acceptable.
-     */
     for (i = 0; i < BytesConverted; i++)
     {
         OutputData[i] = (unsigned char) Converted[i];
     }
 
-    return (BytesConverted);
+    return ((size_t) BytesConverted);
+}
+
+
+/******************************************************************************
+ *
+ * FUNCTION:    AxGetTableHeader
+ *
+ * PARAMETERS:  InputFile           - Handle for the input acpidump file
+ *              OutputData          - Where the table header is returned
+ *
+ * RETURN:      The actual number of bytes converted
+ *
+ * DESCRIPTION: Extract and convert an ACPI table header
+ *
+ ******************************************************************************/
+
+size_t
+AxGetTableHeader (
+    FILE                    *InputFile,
+    unsigned char           *OutputData)
+{
+    size_t                  BytesConverted;
+    size_t                  TotalConverted = 0;
+    int                     i;
+
+
+    /* Get the full 36 byte ACPI table header, requires 3 input text lines */
+
+    for (i = 0; i < 3; i++)
+    {
+        if (!fgets (Gbl_HeaderBuffer, AX_LINE_BUFFER_SIZE, InputFile))
+        {
+            return (TotalConverted);
+        }
+
+        BytesConverted = AxConvertLine (Gbl_HeaderBuffer, OutputData);
+        TotalConverted += BytesConverted;
+        OutputData += 16;
+
+        if (BytesConverted != 16)
+        {
+            return (TotalConverted);
+        }
+    }
+
+    return (TotalConverted);
 }
 
 
@@ -510,7 +334,7 @@ AxCountTableInstances (
     unsigned int            Instances = 0;
 
 
-    InputFile = fopen (InputPathname, "r");
+    InputFile = fopen (InputPathname, "rt");
     if (!InputFile)
     {
         printf ("Could not open input file %s\n", InputPathname);
@@ -607,42 +431,96 @@ AxGetNextInstance (
 
 /******************************************************************************
  *
- * FUNCTION:    AxConvertAndWrite
+ * FUNCTION:    AxIsDataBlockHeader
+ *
+ * PARAMETERS:  None
+ *
+ * RETURN:      Status. 1 if the table header is valid, 0 otherwise.
+ *
+ * DESCRIPTION: Check if the ACPI table identifier in the input acpidump text
+ *              file is valid (of the form: <sig> @ <addr>).
+ *
+ ******************************************************************************/
+
+int
+AxIsDataBlockHeader (
+    void)
+{
+
+    /* Ignore lines that are too short to be header lines */
+
+    if (strlen (Gbl_LineBuffer) < AX_MIN_BLOCK_HEADER_LENGTH)
+    {
+        return (0);
+    }
+
+    /* Ignore empty lines and lines that start with a space */
+
+    if (AxIsEmptyLine (Gbl_LineBuffer) ||
+        (Gbl_LineBuffer[0] == ' '))
+    {
+        return (0);
+    }
+
+    /*
+     * Ignore lines that are not headers of the form <sig> @ <addr>.
+     * Basically, just look for the '@' symbol, surrounded by spaces.
+     *
+     * Examples of headers that must be supported:
+     *
+     * DSDT @ 0x737e4000
+     * XSDT @ 0x737f2fff
+     * RSD PTR @ 0xf6cd0
+     * SSDT @ (nil)
+     */
+    if (!strstr (Gbl_LineBuffer, " @ "))
+    {
+        return (0);
+    }
+
+    AxNormalizeSignature (Gbl_LineBuffer);
+    return (1);
+}
+
+
+/******************************************************************************
+ *
+ * FUNCTION:    AxProcessOneTextLine
  *
  * PARAMETERS:  OutputFile              - Where to write the binary data
  *              ThisSignature           - Signature of current ACPI table
+ *              ThisTableBytesWritten   - Total count of data written
  *
  * RETURN:      Length of the converted line
  *
  * DESCRIPTION: Convert one line of input hex ascii text to binary, and write
  *              the binary data to the table output file.
  *
- * NOTE: Assumes the input data line has been validated to be of the form:
- *
- *  0010: 48 53 57 55 4c 54 2d 52 01 00 00 00 49 4e 54 4c  HSWULT-R....INTL
- *
  ******************************************************************************/
 
-int
-AxConvertAndWrite (
+long
+AxProcessOneTextLine (
     FILE                    *OutputFile,
-    char                    *ThisSignature)
+    char                    *ThisSignature,
+    unsigned int            ThisTableBytesWritten)
 {
-    int                     BytesWritten;
-    int                     BytesConverted;
+    size_t                  BytesWritten;
+    size_t                  BytesConverted;
 
 
+    /* Check for the end of this table data block */
+
+    if (AxIsEmptyLine (Gbl_LineBuffer) ||
+        (Gbl_LineBuffer[0] != ' '))
+    {
+        printf (AX_TABLE_INFO_FORMAT,
+            ThisSignature, ThisTableBytesWritten, Gbl_OutputFilename);
+        return (0);
+    }
+
     /* Convert one line of ascii hex data to binary */
 
-    BytesConverted = AxConvertToBinary (Gbl_LineBuffer, Gbl_BinaryData);
-    if (BytesConverted == EOF)
-    {
-        return (EOF);
-    }
-    if (!BytesConverted)
-    {
-        return (0);
-    }
+    BytesConverted = AxConvertLine (Gbl_LineBuffer, Gbl_BinaryData);
 
     /* Write the binary data */
 
@@ -655,107 +533,3 @@ AxConvertAndWrite (
 
     return (BytesWritten);
 }
-
-
-/******************************************************************************
- *
- * FUNCTION:    AxDumpTableHeader
- *
- * PARAMETERS:  Header          - A binary ACPI table header
- *
- * RETURN:      None
- *
- * DESCRIPTION: Display the contents of a standard ACPI table header
- *
- ******************************************************************************/
-
-void
-AxDumpTableHeader (
-    unsigned char           *Header)
-{
-    ACPI_TABLE_HEADER       *TableHeader = (ACPI_TABLE_HEADER *) (void *) Header;
-    ACPI_TABLE_RSDP         *Rsdp = (ACPI_TABLE_RSDP *) (void *) Header;
-    ACPI_TABLE_FACS         *Facs = (ACPI_TABLE_FACS *) (void *) Header;
-
-
-    /* RSDP has an oddball signature and header */
-
-    if (!strncmp (TableHeader->Signature, "RSD PTR ", 8))
-    {
-        AxCheckAscii ((char *) &Header[9], 6);
-
-        Gbl_TableCount++;
-        printf (" %.2u) %5.4s  0x%8.8X  0x%2.2X  \"%6.6s\"\n",
-            Gbl_TableCount, "RSDP", Rsdp->Length, Rsdp->Revision, Rsdp->OemId);
-        return;
-    }
-
-    if (!AcpiUtValidNameseg (TableHeader->Signature))
-    {
-        return;
-    }
-
-    /* Signature and Table length */
-
-    Gbl_TableCount++;
-    printf (" %.2u) %5.4s  0x%8.8X", Gbl_TableCount, TableHeader->Signature,
-        TableHeader->Length);
-
-    /* FACS has only signature and length */
-
-    if (ACPI_COMPARE_NAME (TableHeader->Signature, "FACS"))
-    {
-        printf ("  0x%2.2X\n", Facs->Version);
-        return;
-    }
-
-    /* OEM IDs and Compiler IDs */
-
-    AxCheckAscii (TableHeader->OemId, 6);
-    AxCheckAscii (TableHeader->OemTableId, 8);
-    AxCheckAscii (TableHeader->AslCompilerId, 4);
-
-    printf (
-        "  0x%2.2X  \"%6.6s\"  \"%8.8s\"  0x%8.8X"
-        "  \"%4.4s\"   0x%8.8X\n",
-        TableHeader->Revision, TableHeader->OemId,
-        TableHeader->OemTableId, TableHeader->OemRevision,
-        TableHeader->AslCompilerId, TableHeader->AslCompilerRevision);
-}
-
-
-#ifdef _AX_FUTURE_ENHANCEMENTS
-
-/* Possible enhancement to validate table lengths */
-
-void
-AxCheckTableLengths (
-    UINT32                  ByteCount,
-    UINT32                  AmlByteCount)
-{
-
-    if (AmlByteCount == 0)
-    {
-        return;
-    }
-
-    if (ByteCount == 0)
-    {
-        return;
-    }
-
-    if ((ByteCount < sizeof (ACPI_TABLE_HEADER)) &&
-        (ByteCount >= ACPI_NAME_SIZE))
-    {
-        printf ("  : (Table too short for an ACPI table)");
-    }
-
-    else if (ByteCount != AmlByteCount)
-    {
-        printf ("  : (Hex data length mismatch with AML length 0x%X)",
-            AmlByteCount);
-    }
-
-    printf ("\n");
-}
-#endif
