@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -113,7 +113,6 @@
  *
  *****************************************************************************/
 
-#define __EXAMPLES_C__
 #include "examples.h"
 
 #define _COMPONENT          ACPI_EXAMPLE
@@ -158,6 +157,22 @@ NotifyHandler (
     UINT32                  Value,
     void                    *Context);
 
+static ACPI_STATUS
+RegionHandler (
+    UINT32                  Function,
+    ACPI_PHYSICAL_ADDRESS   Address,
+    UINT32                  BitWidth,
+    UINT64                  *Value,
+    void                    *HandlerContext,
+    void                    *RegionContext);
+
+static ACPI_STATUS
+RegionInit (
+    ACPI_HANDLE             RegionHandle,
+    UINT32                  Function,
+    void                    *HandlerContext,
+    void                    **RegionContext);
+
 static void
 ExecuteMAIN (void);
 
@@ -209,7 +224,8 @@ main (
     ACPI_INFO        ((AE_INFO, "Example ACPICA info message"));
     ACPI_WARNING     ((AE_INFO, "Example ACPICA warning message"));
     ACPI_ERROR       ((AE_INFO, "Example ACPICA error message"));
-    ACPI_EXCEPTION   ((AE_INFO, AE_AML_OPERAND_TYPE, "Example ACPICA exception message"));
+    ACPI_EXCEPTION   ((AE_INFO, AE_AML_OPERAND_TYPE,
+        "Example ACPICA exception message"));
 
     ExecuteOSI ();
     ExecuteMAIN ();
@@ -232,6 +248,7 @@ InitializeFullAcpica (void)
 
     /* Initialize the ACPICA subsystem */
 
+    AcpiGbl_OverrideDefaultRegionHandlers = TRUE;
     Status = AcpiInitializeSubsystem ();
     if (ACPI_FAILURE (Status))
     {
@@ -250,15 +267,6 @@ InitializeFullAcpica (void)
         return (Status);
     }
 
-    /* Create the ACPI namespace from ACPI tables */
-
-    Status = AcpiLoadTables ();
-    if (ACPI_FAILURE (Status))
-    {
-        ACPI_EXCEPTION ((AE_INFO, Status, "While loading ACPI tables"));
-        return (Status);
-    }
-
     /* Install local handlers */
 
     Status = InstallHandlers ();
@@ -277,6 +285,15 @@ InitializeFullAcpica (void)
         return (Status);
     }
 
+    /* Create the ACPI namespace from ACPI tables */
+
+    Status = AcpiLoadTables ();
+    if (ACPI_FAILURE (Status))
+    {
+        ACPI_EXCEPTION ((AE_INFO, Status, "While loading ACPI tables"));
+        return (Status);
+    }
+
     /* Complete the ACPI namespace object initialization */
 
     Status = AcpiInitializeObjects (ACPI_FULL_INITIALIZATION);
@@ -339,6 +356,7 @@ InitializeAcpi (
 
     /* Initialize the ACPICA subsystem */
 
+    AcpiGbl_OverrideDefaultRegionHandlers = TRUE;
     Status = AcpiInitializeSubsystem ();
     if (ACPI_FAILURE (Status))
     {
@@ -353,14 +371,6 @@ InitializeAcpi (
         return (Status);
     }
 
-    /* Create the ACPI namespace from ACPI tables */
-
-    Status = AcpiLoadTables ();
-    if (ACPI_FAILURE (Status))
-    {
-        return (Status);
-    }
-
     /* Install local handlers */
 
     Status = InstallHandlers ();
@@ -378,6 +388,14 @@ InitializeAcpi (
         return (Status);
     }
 
+    /* Create the ACPI namespace from ACPI tables */
+
+    Status = AcpiLoadTables ();
+    if (ACPI_FAILURE (Status))
+    {
+        return (Status);
+    }
+
     /* Complete the ACPI namespace object initialization */
 
     Status = AcpiInitializeObjects (ACPI_FULL_INITIALIZATION);
@@ -407,6 +425,43 @@ NotifyHandler (
 }
 
 
+static ACPI_STATUS
+RegionInit (
+    ACPI_HANDLE                 RegionHandle,
+    UINT32                      Function,
+    void                        *HandlerContext,
+    void                        **RegionContext)
+{
+
+    if (Function == ACPI_REGION_DEACTIVATE)
+    {
+        *RegionContext = NULL;
+    }
+    else
+    {
+        *RegionContext = RegionHandle;
+    }
+
+    return (AE_OK);
+}
+
+
+static ACPI_STATUS
+RegionHandler (
+    UINT32                      Function,
+    ACPI_PHYSICAL_ADDRESS       Address,
+    UINT32                      BitWidth,
+    UINT64                      *Value,
+    void                        *HandlerContext,
+    void                        *RegionContext)
+{
+
+    ACPI_INFO ((AE_INFO, "Received a region access"));
+
+    return (AE_OK);
+}
+
+
 static ACPI_STATUS
 InstallHandlers (void)
 {
@@ -415,14 +470,22 @@ InstallHandlers (void)
 
     /* Install global notify handler */
 
-    Status = AcpiInstallNotifyHandler (ACPI_ROOT_OBJECT, ACPI_SYSTEM_NOTIFY,
-                                        NotifyHandler, NULL);
+    Status = AcpiInstallNotifyHandler (ACPI_ROOT_OBJECT,
+        ACPI_SYSTEM_NOTIFY, NotifyHandler, NULL);
     if (ACPI_FAILURE (Status))
     {
         ACPI_EXCEPTION ((AE_INFO, Status, "While installing Notify handler"));
         return (Status);
     }
 
+    Status = AcpiInstallAddressSpaceHandler (ACPI_ROOT_OBJECT,
+        ACPI_ADR_SPACE_SYSTEM_MEMORY, RegionHandler, RegionInit, NULL);
+    if (ACPI_FAILURE (Status))
+    {
+        ACPI_EXCEPTION ((AE_INFO, Status, "While installing an OpRegion handler"));
+        return (Status);
+    }
+
     return (AE_OK);
 }
 
@@ -492,7 +555,8 @@ ExecuteOSI (void)
         AcpiOsPrintf ("Invalid return type from _OSI, %.2X\n", Object->Type);
     }
 
-    ACPI_INFO ((AE_INFO, "_OSI returned 0x%8.8X", (UINT32) Object->Integer.Value));
+    ACPI_INFO ((AE_INFO, "_OSI returned 0x%8.8X",
+        (UINT32) Object->Integer.Value));
 
 
 ErrorExit:
@@ -548,7 +612,8 @@ ExecuteMAIN (void)
         Object = ReturnValue.Pointer;
         if (Object->Type == ACPI_TYPE_STRING)
         {
-            AcpiOsPrintf ("Method [MAIN] returned: \"%s\"\n", Object->String.Pointer);
+            AcpiOsPrintf ("Method [MAIN] returned: \"%s\"\n",
+                Object->String.Pointer);
         }
 
         ACPI_FREE (ReturnValue.Pointer);
